-- REM  MACHINERY INFORMATION MANAGEMENT OPEN SYSTEM ALLIANCE  (MIMOSA)
-- REM      COMMON, RELATIONAL INFORMATION SCHEMA (CRIS)
-- REM 
-- REM  V2.2 Production Relational Database Schema (CRIS V2-2 15-Apr-2002)
-- REM
-- REM  Last Updated On: 15-APR-2002
-- REM       Tested with Microsoft SQLServer 7.0 On: 15-APR-2002
-- REM
-- REM  
-- REM  This version of the schema utilizes the following nomenclature:
-- REM
-- REM		  
-- REM   DATA TYPES
-- REM   ==========
-- REM   SMALLINT := 2-byte unsigned integer (-32,676 to 32,675)
-- REM 
-- REM   INTEGER := 4-byte unsigned integer (-2147483648 to 2147483647)
-- REM 
-- REM   FLOAT := 8-byte floating point number
-- REM 
-- REM   CHAR(length) := fixed-length character string with exactly length 
-- REM                  	characters
-- REM 
-- REM   VARCHAR(maxlength) := variable-length character string with up to 
-- REM                  	maxlength characters
-- REM 
-- REM   IMAGE := variable-length binary data of unlimited length except
-- REM                  	as constrained by systems environment 
-- REM 
-- REM   TERMS
-- REM   =====
-- REM   column NOT NULL := a value must be specified for the column when 
-- REM              inserting a row and cannot be updated to be "NULL"
-- REM				(empty)
-- REM 
-- REM   CHECK (column in (valid_list)) := values for the column must exist 
-- REM				in the valid_list
-- REM 
-- REM   PRIMARY KEY(column_list) := column(s) specified create a unique 
-- REM				identifier for each row in the table
-- REM 
-- REM   FOREIGN KEY (curr_column_list) REFERENCES ref_table 
-- REM				(ref_column_list) := column(s) in the 
-- REM				curr_column_list in the current table are linked
-- REM 				back to ref_table's primary key columns or 
-- REM				unique index columns ref_column_list.  An 
-- REM				optional name for the foreign key may be 
-- REM				specified to differentiate between multiple 
-- REM				foreign keys which reference the same ref_table
-- REM
-- REM 
-- REM DISCLAIMER OF WARRANTIES AND TECHNICAL SUPPORT
-- REM ==============================================
-- REM 
-- REM This schema is provided to you free of charge, and on an "AS IS" 
-- REM basis, without any technical support or warranty of any kind from 
-- REM MIMOSA including, without limitation, a warranty of merchantability, 
-- REM fitness for a particular purpose and non-infringement.  Some states 
-- REM do not allow the exclusion of implied warranties, so the above 
-- REM exclusion may not apply to you.  You may also have other legal rights 
-- REM which vary from state to state. 
-- REM 
-- REM
-- REM LIMITATION OF DAMAGES
-- REM =====================
-- REM 
-- REM MIMOSA shall not be liable for any indirect, special, incidental or 
-- REM consequential damages or loss (including damages for loss of 
-- REM business, loss of profits, or the like), whether based on breach of 
-- REM contract, tort (including negligence), product liability or otherwise, 
-- REM even if MIMOSA or its representatives have been advised of the 
-- REM possibility of such damages. Some states do not allow the limitation 
-- REM or exclusion of liability for incidental or consequential damages, so 
-- REM this limitation or exclusion may not apply to you. The limited 
-- REM warranty, exclusive remedies and limited liability set forth above 
-- REM are fundamental elements of the basis of the bargain between MIMOSA 
-- REM and you. You agree that MIMOSA will not be able to provide this 
-- REM schema and any associated Software on an economic basis without such 
-- REM limitations.
-- REM  
-- REM 


-- REM #12 -- Row Status Type Code
-- REM
-- REM   The row status code is a foreign key in every other table to
-- REM   define the status of the row.  These codes will not change.
-- REM   The entries will include the following:
-- REM
-- REM                        1 = Active Row
-- REM                        2 = Inactive Row
-- REM                        3 = Soft Deleted Row
-- REM
-- REM   NOTE: MIMOSA populates and maintains this table.
-- REM         No user-defined entries are supported.
-- REM
-- REM   NOTE: The gmt_last_updated column is in every table to store the
-- REM         the date the row was inserted or updated.
-- REM
-- REM   NOTE: All time (gmt_XXX) fields are in the ISO 8601 DATETIME 
-- REM		   representation for Coordinated Universal Time (UTC) (also
-- REM		   Greenwich Mean Time) in the format
-- REM         YYYY-MM-DDTHH:MM:SS.fffffffff in 24-hour format like:
-- REM         format like: 1995-02-27T18:01:03.500000000 which is equivalent
-- REM         to 27-Feb-1995 6:01 PM at 3.5 seconds
-- REM
CREATE TABLE row_status_type (
 rstat_type_cod      SMALLINT     NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (rstat_type_cod)
 );

GO
-- REM #13 -- Site Table
-- REM
-- REM   The site table holds information about the physical location
-- REM   in the world where objects which are being monitored exist and
-- REM   databases reside.
-- REM
-- REM   NOTE: For all for-profit businesses, the site_code is the 
-- REM         D-U-N-S number of the location-- a randomly-generated
-- REM         nine-digit number assigned by Dunn & Bradstreet.
-- REM         The D-U-N-S number is based on a coding system called the
-- REM         Data Universal Numbering System, hence it's name "D-U-N-S".
-- REM         This code is used to identify 38 million current and former
-- REM         business locations throught the world.  Each location of
-- REM         a company is assigned a unique D-U-N-S number which does not
-- REM         change and will not be reassigned if the location closes.
-- REM         To locate your location's D-U-N-S number, please call Dun &
-- REM         Bradstreet Information Resources Customer Service at 
-- REM         1-800-333-0505.  This is a free service.
-- REM
-- REM   NOTE: The model stores the D-U-N-S number as an integer, which
-- REM         does not preserve the leading zeroes in the DUNS number.  To
-- REM         display the number to a user, left pad the number with zeroes
-- REM         to 9 digits.
-- REM
-- REM   NOTE: For non-profit and government locations, you will need to
-- REM         have a MIMOSA number assigned.  A group of numbers will
-- REM         be assigned to your corporate organization.  A representative
-- REM         from your corporate organization should e-mail Kenneth Bever
-- REM         at kenneth_bever@hsb.com with the name of your organization,
-- REM         the number of locations in our organization, your name,
-- REM         title, and phone number.  You will be sent a range of
-- REM         of MIMOSA numbers (all over 999,999,999) which you can
-- REM         then assign to each of your locations.
-- REM
-- REM   NOTE: A negative D-U-N-S number can be used for temporary
-- REM         assignment when no correct D-U-N-S number is available.
-- REM         This should not be used permanently because the integration
-- REM         of multiple site data will later be troublesome, i.e.,
-- REM         both sites export with the D-U-N-S number of -1.
-- REM
-- REM   NOTE: The last_upd_db_site,last_upd_db_id columns are included
-- REM         in all tables, except tables managed and populated by MIMOSA,
-- REM         to store the database site and the DB identifier which made the
-- REM         insert or last update to each row.  This is a foreign key to
-- REM         to the site_database table, but we cannot define this
-- REM         relationship because the table is not yet created.
-- REM
-- REM   NOTE: The optional field primary_sic relates to the primary Standard 
-- REM         Industry Code (SIC) for the site.  This code is linked in a SIC
-- REM         reference book to the type of industry the site is associated 
-- REM         with.
-- REM
-- REM   NOTE: On address lines, line breaks are denoted by a backslash "\" 
-- REM         character.
-- REM
CREATE TABLE site (
 site_code           INTEGER      NOT NULL,
 company_name        VARCHAR(254) NOT NULL,
 site_name           VARCHAR(254) NOT NULL,
 phys_addr           VARCHAR(254),
 phys_city_name      VARCHAR(60),
 phys_state_abbr     CHAR(2),
 phys_postal_code    VARCHAR(10),
 phys_country_abb    CHAR(3),
 mail_addr           VARCHAR(254),
 mail_city_name      VARCHAR(60),
 mail_state_abbr     CHAR(2),
 mail_postal_code    VARCHAR(10),
 mail_country_abb    CHAR(3),
 us_ph_number        CHAR(10),
 int_ph_contry_no    VARCHAR(3),
 int_ph_city_no      VARCHAR(5),
 int_ph_local_no     VARCHAR(10),
 us_fax_number       CHAR(10),
 int_fax_cntry_no    VARCHAR(3),
 int_fax_city_no     VARCHAR(5),
 int_fax_local_no    VARCHAR(10),
 business_desc       VARCHAR(254),
 primary_sic         VARCHAR(8),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (site_code),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #15 -- Site Database Table
-- REM
-- REM   This table holds information about the machinery databases
-- REM   located at the site.  It requires a unique db_id to exist
-- REM   for each database.  This allows for databases to be merged.
-- REM
-- REM   NOTE: The vendor of the database is stored as a foreign key
-- REM         in the mf_db_site, mf_db_id, mf_duns_code columns
-- REM         which relates to the MANUFACTURER table defined below.
-- REM         We cannot define it as a foreign key (though indeed it
-- REM         is) because the MANUFACTURER table has foreign keys to
-- REM         this table and thus can not be created before this one.
-- REM
CREATE TABLE site_database (
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 mf_db_site          INTEGER,
 mf_db_id            INTEGER,
 mf_duns_code        INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (db_site, db_id),
    FOREIGN KEY (db_site) REFERENCES site (site_code),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #16 -- Manufacturer Table
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) mf_db_site entries in this 
-- REM         table.  A database can add entries to this table, but must
-- REM         insert the database's primary key in mf_db_site and mf_db_id
-- REM         columns and then enter the Manfufacturer's corporate D-U-N-S
-- REM         number in the mf_duns_code column.  If this is not known,
-- REM         negative numbers can be generated.
-- REM
-- REM   NOTE: mf_duns_code is the D-U-N-S number of the corporate
-- REM         office of the manufacturer of the object
-- REM
-- REM   NOTE: The optional field primary_sic relates to the primary Standard 
-- REM         Industry Code (SIC) for the site.  This code is linked in a SIC
-- REM         reference book to the type of industry the site is associated 
-- REM         with.
-- REM
-- REM   NOTE: On address lines, line breaks are denoted by a backslash "\" 
-- REM         character.
-- REM
CREATE TABLE manufacturer (
 mf_db_site          INTEGER      NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 manuf_trade_name    VARCHAR(254) NOT NULL,
 company_name        VARCHAR(254) NOT NULL,
 phys_addr           VARCHAR(254),
 phys_city_name      VARCHAR(30),
 phys_state_abbr     CHAR(2),
 phys_postal_code    VARCHAR(10),
 phys_country_abbr   CHAR(3),
 mail_addr           VARCHAR(254),
 mail_city_name      VARCHAR(60),
 mail_state_abbr     CHAR(2),
 mail_postal_code    VARCHAR(10),
 mail_country_abbr   CHAR(3),
 us_ph_number        CHAR(10),
 int_ph_country_no   VARCHAR(3),
 int_ph_city_no      VARCHAR(5),
 int_ph_local_no     VARCHAR(10),
 us_fax_number       CHAR(10),
 int_fax_country_no  VARCHAR(3),
 int_fax_city_no     VARCHAR(5),
 int_fax_local_no    VARCHAR(10),
 business_desc       VARCHAR(254),
 primary_sic         VARCHAR(8),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY ( mf_db_site, mf_db_id, mf_duns_code),
    FOREIGN KEY ( mf_db_site, mf_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #17 -- Service Segment Type Table
-- REM
-- REM This table standardizes the names of service segments:  production
-- REM processes, their inputs and outputs, physical structures, systems,
-- REM mechanical devices, and mechanical device areas.  Many of these
-- REM segments appear on the engineering blueprints of the site.
-- REM These are referred to as "service segments" in this model.  Service segment 
-- REM types can be thought of as the labels which are used in plant layout 
-- REM drawings showing the process flow, machine trains, and physical buildings 
-- REM in a plant.
-- REM
-- REM   NOTE: MIMOSA Populates and maintains the sg_db_site Zero (0)
-- REM         entries in this Table
-- REM
-- REM
CREATE TABLE segment_type (
 sg_db_site          INTEGER      NOT NULL,
 sg_db_id            INTEGER      NOT NULL,
 sg_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 default_mnemonic    CHAR(3),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sg_db_site, sg_db_id, sg_type_code),
    FOREIGN KEY (sg_db_site, sg_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #98 -- Segment Type Child Table
-- REM
-- REM This table shows the parent-child relationships structure of
-- REM the logical taxonomy of segment types--from the general to more
-- REM specific.  This table will support various classification schemes
-- REM as desired by different MIMOSA databases.
-- REM
CREATE TABLE segment_type_child (
 sg_db_site          INTEGER      NOT NULL,
 sg_db_id            INTEGER      NOT NULL,
 sg_type_code        INTEGER      NOT NULL,
 child_sg_db_site    INTEGER      NOT NULL,
 child_sg_db_id      INTEGER      NOT NULL,
 child_sg_type_code  INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sg_db_site, sg_db_id, sg_type_code, child_sg_db_site, child_sg_db_id, child_sg_type_code),
    FOREIGN KEY (sg_db_site, sg_db_id, sg_type_code) REFERENCES segment_type (sg_db_site, sg_db_id, sg_type_code),
    FOREIGN KEY (child_sg_db_site, child_sg_db_id, child_sg_type_code) REFERENCES segment_type (sg_db_site, sg_db_id, sg_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #18 -- Service Segment Table
-- REM
-- REM This table stores all the service segments which have been designed
-- REM to perform a function at a site.  Service segments include production
-- REM processes, their inputs and outputs, physical structures, systems,
-- REM mechanical devices, and mechanical device areas.  Many of these
-- REM segments appear on the engineering blueprints of the site.  
-- REM These segments include components which perform a function 
-- REM (Turbine-driven Pump 1A, Motor outboard bearing, etc.) but do NOT 
-- REM describe the particular asset tracked by manufacturer,
-- REM model number, & serial number in the database.  This is done in the
-- REM asset table.  Some database track only data tied to service segments such
-- REM as a machine train component, but do not tie the measurement data
-- REM to the physical component assets installed at the time the data was 
-- REM taken.  These databases cannot track, for example, a physical motor 
-- REM which is taken out of one machine train, cleaned, and then later 
-- REM used in another train.  Other systems track physical assets and 
-- REM tie measurements to them.  In order to provide maximum flexibility, 
-- REM this model allows both functional segment objects at a site and 
-- REM physical objects at a site to be placed in the database and data
-- REM can be related to both as necessary.  Table #44 (ASSET_ON_SEGMENT)
-- REM stores the utilization of a particular asset on a given segment
-- REM with the time it was installed and removed.
-- REM
-- REM The Segment_Child Table shows the parent-child relationships
-- REM of segments to each other. For example, segment "Steam Turbine"
-- REM at site "ABC" is the child of segment "Turbine Generator #1" 
-- REM which is the child of segment "Power Generation Line #1". 
-- REM The model allows for more than one segment to be the child of
-- REM more than one segment.
-- REM
-- REM The segment_group_yn field when set to "Y" means that this segment
-- REM is really a segment composed of 2 or more segments of the same type.
-- REM If a count of total segments is made from the database, these group
-- REM segments should be ignored.
-- REM
-- REM   NOTE: Segment_id is used like a barcode--to assign a unique,
-- REM         non-changeable identifier since a primary key cannot change
-- REM         and must uniquely define the entity.  The user_tag_ident
-- REM         field is the identifier which is meaningful to the plant.
-- REM
-- REM         Computer systems monitoring or recording information on the 
-- REM         same segment should utilize the same segment_site, segment_id
-- REM         pair.
-- REM
-- REM         User_tag_ident is the user identification tag which
-- REM         follows the nomenclature of the plant.  This is normally
-- REM         an abbreviation or user-defined alpha-numeric code from which
-- REM         the plant derives meaning.  This column is mandatory.
-- REM
-- REM         The "name" column is an optional column which is a full
-- REM         description of the segment.
-- REM
CREATE TABLE segment (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 sg_db_site          INTEGER      NOT NULL,
 sg_db_id            INTEGER      NOT NULL,
 sg_type_code        INTEGER      NOT NULL,
 segment_group_yn    CHAR(1)      NOT NULL,
 user_tag_ident      VARCHAR(254) NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id),
    FOREIGN KEY (segment_site) REFERENCES site (site_code),
    FOREIGN KEY (sg_db_site, sg_db_id, sg_type_code) REFERENCES segment_type (sg_db_site, sg_db_id, sg_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (segment_group_yn in ('Y','N'))
 );
GO
-- REM #323 -- purchase_cond_type 
-- REM
-- REM Purchase Condition Type
-- REM
CREATE TABLE purchase_cond_type (
 pc_db_site          INTEGER      NOT NULL, 
 pc_db_id            INTEGER      NOT NULL,
 pc_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (pc_db_site, pc_db_id, pc_type_code),
    FOREIGN KEY (pc_db_site, pc_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #324 -- as_readiness_type
-- REM
-- REM Asset Readiness Type
-- REM
CREATE TABLE as_readiness_type (
 asr_db_site         INTEGER      NOT NULL, 
 asr_db_id           INTEGER      NOT NULL,
 asr_type_code       INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 description         VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asr_db_site, asr_db_id, asr_type_code),
    FOREIGN KEY (asr_db_site, asr_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #325 -- mloc_calc_type
-- REM
-- REM Measurement Location Data Calculation Type
-- REM
CREATE TABLE mloc_calc_type (
 mc_db_site          INTEGER      NOT NULL, 
 mc_db_id            INTEGER      NOT NULL,
 mc_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 description         VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (mc_db_site, mc_db_id, mc_type_code),
    FOREIGN KEY (mc_db_site, mc_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #19 -- Segment Child Table
-- REM
-- REM The Segment Child Table shows the parent-child relationships
-- REM of segments to each other. For example, segment "Steam Turbine"
-- REM at site "ABC" is the child of segment "Turbine Generator #1" 
-- REM which is the child of segment "Power Generation Line #1". 
-- REM The model allows for more than one segment to be the child of
-- REM more than one segment.
-- REM
-- REM The mandatory ordering sequence specifies the order in which child
-- REM segment will appear when an application requests "all children" of
-- REM a particular segment.  The ordering sequence of machine segments, 
-- REM coupling segments, and bearing segments on a rotating machine train 
-- REM should conform to the MIMOSA guidelines as specified in 
-- REM Document MIM-VB-001.
-- REM
CREATE TABLE segment_child (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 child_sg_site       INTEGER      NOT NULL,
 child_sg_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, child_sg_site, child_sg_id),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment (segment_site, segment_id),
    FOREIGN KEY (child_sg_site, child_sg_id) REFERENCES segment (segment_site, segment_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #22 -- Reference Unit Table
-- REM
-- REM   NOTE: MIMOSA populates and maintains this table.
-- REM         No user-defined entries are supported.
-- REM
CREATE TABLE ref_unit_type (
 ru_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 physics_descr       VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ru_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #23 -- Engineering Unit Table
-- REM
-- REM   NOTE: MIMOSA Populates and maintains the eu_db_site Zero (0)
-- REM         entries in this table.  To convert between units,
-- REM         a multiplication factor from reference plus an offset
-- REM         scalar is provided in the columns mult_fact_to_ref and
-- REM         refer_off_to_ref, respectively.
-- REM
-- REM             Y[eng units] = (X[ref units] * mult_fact_to_ref) +
-- REM                                  refer_off_to_ref
-- REM
-- REM             Y[ref units] = (X[eng units] - refer_off_to_ref) /
-- REM                                  mult_fact_to_ref
-- REM
CREATE TABLE eng_unit_type (
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 ru_type_code        INTEGER      NOT NULL,
 mult_fact_to_ref    FLOAT       NOT NULL,
 refer_off_to_ref    FLOAT       NOT NULL,
 name                VARCHAR(254) NOT NULL,
 abbrev              VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (ru_type_code) REFERENCES ref_unit_type (ru_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #24 -- Engineering Unit Enumerated List Table
-- REM
-- REM This table stores the alpha-numeric data names for engineering units
-- REM which are of reference unit type "Enumerated List".
-- REM
CREATE TABLE eng_unit_enum (
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          INTEGER      NOT NULL,
 data_name           VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (eu_db_site, eu_db_id, eu_type_code, data_value),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #25 -- Segment Numeric Data Type Table
-- REM
-- REM This table will define all the numeric data related to a segment
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
-- REM
CREATE TABLE sg_num_dat_type (
 sn_db_site          INTEGER      NOT NULL,
 sn_db_id            INTEGER      NOT NULL,
 sn_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 default_ru_type     INTEGER, 
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sn_db_site, sn_db_id, sn_type_code),
    FOREIGN KEY (sn_db_site, sn_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (default_ru_type) REFERENCES ref_unit_type (ru_type_code), 
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #26 -- Segment Character Data Type Table
-- REM
-- REM This table will define all the alpha-numeric character data related to 
-- REM a segment.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
-- REM
CREATE TABLE sg_chr_dat_type (
 sc_db_site          INTEGER      NOT NULL,
 sc_db_id            INTEGER      NOT NULL,
 sc_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 default_ru_type     INTEGER, 
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sc_db_site, sc_db_id, sc_type_code),
    FOREIGN KEY (sc_db_site, sc_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (default_ru_type) REFERENCES ref_unit_type (ru_type_code), 
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #27 -- Segment Numeric Data Table
-- REM
-- REM This table will hold all the numeric nameplate and composition
-- REM data related to a segment.
-- REM
-- REM
-- REM
CREATE TABLE segment_num_data (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 sn_db_site          INTEGER      NOT NULL,
 sn_db_id            INTEGER      NOT NULL,
 sn_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          FLOAT       NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, sn_db_site, sn_db_id, sn_type_code),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment (segment_site, segment_id),
    FOREIGN KEY (sn_db_site, sn_db_id, sn_type_code) REFERENCES sg_num_dat_type (sn_db_site, sn_db_id, sn_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #28 -- Segment Character Data Table
-- REM
-- REM This table will hold all the alpha-numeric data related to a segment.
-- REM
-- REM
CREATE TABLE segment_chr_data (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 sc_db_site          INTEGER      NOT NULL,
 sc_db_id            INTEGER      NOT NULL,
 sc_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, sc_db_site, sc_db_id, sc_type_code),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment (segment_site, segment_id),
    FOREIGN KEY (sc_db_site, sc_db_id, sc_type_code) REFERENCES sg_chr_dat_type (sc_db_site, sc_db_id, sc_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #29 -- Segment/Asset Event Type Table
-- REM
-- REM This table holds the different types of possible events for segments and
-- REM assets.  These include operating events and failure events.  An event
-- REM is NOT work performed by an entity, but a log of the actual events which
-- REM occurred at a service segment or asset over time.
-- REM
-- REM   NOTE: MIMOSA Populates and maintains the ev_db_site Zero (0)
-- REM         entries in this Table
-- REM
-- REM
CREATE TABLE sg_as_event_type (
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ev_db_site, ev_db_id, event_type_code),
    FOREIGN KEY (ev_db_site, ev_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #30 -- Segment Event Table
-- REM
-- REM This table holds the different events which occurred on segments.
-- REM These include operating events and failure events.  An event
-- REM is NOT work performed by an entity, but a log of the actual events which
-- REM occurred at a service segment over time.
-- REM
-- REM     NOTE: gmt_event_start, gmt_event_stop, and gmt_stored are Greenwich 
-- REM           Mean Time
-- REM
-- REM     NOTE: ev_loc_hr_delta is the the number of hours +/- GMT
-- REM           to calculate the correct local time for the event.
-- REM
-- REM     NOTE: st_loc_hr_delta is the the number of hours +/- GMT
-- REM           to calculate the correct local time for the date the
-- REM           event row was stored in the database.
-- REM
-- REM     NOTE: ev_loc_min_delta: If null, then assume local minute offset from GMT = 0
-- REM
-- REM     NOTE: st_loc_min_delta: If null, then assume local minute offset from GMT = 0
-- REM
CREATE TABLE segment_event (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     VARCHAR(29)  NOT NULL,
 gmt_event_stop      VARCHAR(29),
 ev_loc_hr_delta     SMALLINT,
 ev_loc_min_delta    SMALLINT,	
 gmt_stored          VARCHAR(29),
 st_loc_hr_delta     SMALLINT,
 st_loc_min_delta    SMALLINT,	
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment (segment_site, segment_id),
    FOREIGN KEY (ev_db_site, ev_db_id, event_type_code) REFERENCES sg_as_event_type (ev_db_site, ev_db_id, event_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #31 -- Asset Type Table
-- REM
-- REM   NOTE: MIMOSA Populates and maintains the as_db_site Zero (0)
-- REM         entries in this Table
-- REM
CREATE TABLE asset_type (
 as_db_site          INTEGER      NOT NULL,
 as_db_id            INTEGER      NOT NULL,
 as_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 default_mnemonic    CHAR(3),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (as_db_site, as_db_id, as_type_code),
    FOREIGN KEY (as_db_site, as_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #99 -- Asset Type Child Table
-- REM
-- REM This table shows the parent-child relationships structure of
-- REM the logical taxonomy of asset types--from the general to more
-- REM specific.  This table will support various classification schemes
-- REM as desired by different MIMOSA databases.
-- REM
CREATE TABLE asset_type_child (
 as_db_site          INTEGER      NOT NULL,
 as_db_id            INTEGER      NOT NULL,
 as_type_code        INTEGER      NOT NULL,
 child_as_db_site    INTEGER      NOT NULL,
 child_as_db_id      INTEGER      NOT NULL,
 child_as_type_code  INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (as_db_site, as_db_id, as_type_code, child_as_db_site, child_as_db_id, child_as_type_code),
    FOREIGN KEY (as_db_site, as_db_id, as_type_code) REFERENCES asset_type (as_db_site, as_db_id, as_type_code),
    FOREIGN KEY (child_as_db_site, child_as_db_id, child_as_type_code) REFERENCES asset_type (as_db_site, as_db_id, as_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #32 -- Model/Part Number Table (Model Asset)
-- REM
-- REM This table will store the unique manufacturer and model/part number for
-- REM a specific type of asset like a turbine, motor, bearing, etc.
-- REM
-- REM The revision number is part of the primary key and is used when
-- REM a model of a piece of equipment is modified by the manufacturer
-- REM and specifications will need to be tracked separately for each
-- REM revision.  If no revision information is known, then this field
-- REM should contain a zero.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) md_db_site entries in this table
-- REM         in order to provide standardized lists of known turbines,
-- REM         bearings, etc.
-- REM
-- REM
CREATE TABLE model (
 mf_db_site          INTEGER      NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 model_number        VARCHAR(254) NOT NULL,
 revision_number     INTEGER      NOT NULL,
 as_db_site          INTEGER      NOT NULL,
 as_db_id            INTEGER      NOT NULL,
 as_type_code        INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number),
    FOREIGN KEY (mf_db_site, mf_db_id, mf_duns_code) REFERENCES manufacturer ( mf_db_site, mf_db_id, mf_duns_code),
    FOREIGN KEY (as_db_site, as_db_id, as_type_code) REFERENCES asset_type (as_db_site, as_db_id, as_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #97 -- Model/Part Child Table
-- REM
-- REM The Model/Part Child Table shows the parent-child relationships
-- REM of model parts to each other.  This might be derived from the drawing 
-- REM schematic diagrams provided by an equipment manufacturer.
-- REM
-- REM The mandatory ordering sequence specifies the order in which child
-- REM asset will appear when an application requests "all children" of
-- REM a particular model.
-- REM
CREATE TABLE model_child (
 mf_db_site          INTEGER      NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 model_number        VARCHAR(254) NOT NULL,
 revision_number     INTEGER      NOT NULL,
 child_mf_db_site    INTEGER      NOT NULL,
 child_mf_db_id      INTEGER      NOT NULL,
 child_mf_duns_code  INTEGER      NOT NULL,
 child_model_num     VARCHAR(254) NOT NULL,
 child_revision_num  INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, child_mf_db_site, child_mf_db_id, child_mf_duns_code, child_model_num, child_revision_num),
    FOREIGN KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number) REFERENCES model (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number),
    FOREIGN KEY (child_mf_db_site, child_mf_db_id, child_mf_duns_code, child_model_num, child_revision_num) REFERENCES model (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #33 -- Asset Numeric Data Type Table
-- REM
-- REM This table will define all the numeric data related to a asset or a
-- REM model of an asset.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
-- REM
CREATE TABLE as_num_dat_type (
 an_db_site          INTEGER      NOT NULL,
 an_db_id            INTEGER      NOT NULL,
 an_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 default_ru_type     INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (an_db_site, an_db_id, an_type_code),
    FOREIGN KEY (an_db_site, an_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (default_ru_type) REFERENCES ref_unit_type (ru_type_code), 
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #34 -- Asset Character Data Type Table
-- REM
-- REM This table will define all the alpha-numeric character data related to 
-- REM an asset or a model of an asset.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
-- REM
CREATE TABLE as_chr_dat_type (
 ac_db_site          INTEGER      NOT NULL,
 ac_db_id            INTEGER      NOT NULL,
 ac_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 default_ru_type     INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ac_db_site, ac_db_id, ac_type_code),
    FOREIGN KEY (ac_db_site, ac_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (default_ru_type) REFERENCES ref_unit_type (ru_type_code), 
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #35 -- Model Numeric Data Table
-- REM
-- REM This table will hold all the numeric nameplate and composition
-- REM data related to a model.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
-- REM
-- REM
CREATE TABLE model_num_data (
 mf_db_site          INTEGER      NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 model_number        VARCHAR(254) NOT NULL,
 revision_number     INTEGER      NOT NULL,
 an_db_site          INTEGER      NOT NULL,
 an_db_id            INTEGER      NOT NULL,
 an_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          FLOAT       NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, an_db_site, an_db_id, an_type_code),
    FOREIGN KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number) REFERENCES model (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number),
    FOREIGN KEY (an_db_site, an_db_id, an_type_code) REFERENCES as_num_dat_type (an_db_site, an_db_id, an_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #36 -- Model Character Data Table
-- REM
-- REM This table will hold all the alpha-numeric nameplate and composition
-- REM data related to a model.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
-- REM
CREATE TABLE model_chr_data (
 mf_db_site          INTEGER      NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 model_number        VARCHAR(254) NOT NULL,
 revision_number     INTEGER      NOT NULL,
 ac_db_site          INTEGER      NOT NULL,
 ac_db_id            INTEGER      NOT NULL,
 ac_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, ac_db_site, ac_db_id, ac_type_code),
    FOREIGN KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number) REFERENCES model (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number),
    FOREIGN KEY (ac_db_site, ac_db_id, ac_type_code) REFERENCES as_chr_dat_type (ac_db_site, ac_db_id, ac_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #37 -- Asset Table
-- REM
-- REM This table stores any asset at any site.  These
-- REM might include actual motors, turbines, bearings, data collectors,
-- REM transudcers, etc.  Optionally,one can associate this physical asset
-- REM with a service segment of the same type as the asset in a 1 to 1 
-- REM association.  For example, asset "Induction Motor Model XYZ" with
-- REM a specific manufacturer can currently be installed
-- REM on segment "Induction Motor" at site #343434323.
-- REM
-- REM The model allows for more than one asset to be the child of
-- REM more than 1 parent asset through the Asset_Child table.
-- REM
-- REM   NOTE: Asset_org_site is the ORIGINAL site the object was
-- REM         installed at and always remains part of the primary key.
-- REM         This asset may move to another site, but the asset_org_site
-- REM         and asset_id should remain the same.  This relates to the
-- REM         Vehicle ID Number (VIN) on an automobile.  The car may
-- REM         change owners by the VIN number does not change.
-- REM
-- REM         Asset_id is used like a barcode--to assign a unique,
-- REM         non-changeable identifier since a primary key cannot change
-- REM         and must uniquely define the entity.  The user_tag_ident
-- REM         field is the identifier which is meaningful to the plant.
-- REM
-- REM         Computer systems monitoring or recording information on the 
-- REM         same asset should utilize the same asset_org_site, asset_id
-- REM         pair.
-- REM
-- REM         User_tag_ident is the user identification tag which
-- REM         follows the nomenclature of the plant.  This is normally
-- REM         an abbreviation or user-defined alpha-numeric code from which
-- REM         the plant derives meaning.  This column is mandatory.
-- REM
-- REM         The "name" column is an optional column which is a full
-- REM         description of the asset.
-- REM
CREATE TABLE asset (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 as_db_site          INTEGER      NOT NULL,
 as_db_id            INTEGER      NOT NULL,
 as_type_code        INTEGER      NOT NULL,
 user_tag_ident      VARCHAR(254) NOT NULL,
 name                VARCHAR(254),
 mf_db_site          INTEGER,
 mf_db_id            INTEGER,
 mf_duns_code        INTEGER,
 model_number        VARCHAR(254),
 revision_number     INTEGER,
 serial_number       VARCHAR(254),
 asr_db_site         INTEGER,
 asr_db_id           INTEGER,
 asr_type_code       INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id),
    FOREIGN KEY (asset_org_site) REFERENCES site (site_code),
    FOREIGN KEY (as_db_site, as_db_id, as_type_code) REFERENCES asset_type (as_db_site, as_db_id, as_type_code),
    FOREIGN KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number) REFERENCES model (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number),
    FOREIGN KEY (asr_db_site, asr_db_id, asr_type_code) REFERENCES as_readiness_type (asr_db_site, asr_db_id, asr_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #38 -- Asset Child Table
-- REM
-- REM The Asset Child Table shows the parent-child relationships
-- REM of assets to each other. The model allows for more than one asset to 
-- REM be the child of more than one asset.
-- REM
-- REM The mandatory ordering sequence specifies the order in which child
-- REM asset will appear when an application requests "all children" of
-- REM a particular asset.  The ordering sequence of machine assets, 
-- REM coupling assets, and bearing assets on a rotating machine train 
-- REM should conform to the MIMOSA guidelines as specified in 
-- REM Document MIM-VB-001.
-- REM
CREATE TABLE asset_child (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 child_as_site       INTEGER      NOT NULL,
 child_as_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, child_as_site, child_as_id),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset (asset_org_site, asset_id),
    FOREIGN KEY (child_as_site, child_as_id) REFERENCES asset (asset_org_site, asset_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #41 -- Asset Numeric Data Table
-- REM
-- REM This table will hold all the current numeric data related to an asset.
-- REM
-- REM
CREATE TABLE asset_num_data (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 an_db_site          INTEGER      NOT NULL,
 an_db_id            INTEGER      NOT NULL,
 an_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          FLOAT       NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, an_db_site, an_db_id, an_type_code),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset (asset_org_site, asset_id),
    FOREIGN KEY (an_db_site, an_db_id, an_type_code) REFERENCES as_num_dat_type (an_db_site, an_db_id, an_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #42 -- Asset Character Data Table
-- REM
-- REM This table will hold all the current alpha-numeric character data 
-- REM related to an asset.
-- REM
-- REM
CREATE TABLE asset_chr_data (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 ac_db_site          INTEGER      NOT NULL,
 ac_db_id            INTEGER      NOT NULL,
 ac_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, ac_db_site, ac_db_id, ac_type_code),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset (asset_org_site, asset_id),
    FOREIGN KEY (ac_db_site, ac_db_id, ac_type_code) REFERENCES as_chr_dat_type (ac_db_site, ac_db_id, ac_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #43 -- Asset Event Table
-- REM
-- REM This table holds the different types of possible events for assets.
-- REM These include operating events and failure events.  An event
-- REM is NOT work performed by an entity, but a log of the actual events which
-- REM occurred at an asset over time.
-- REM
-- REM     NOTE: gmt_event_start, gmt_event_stop, and gmt_stored are Greenwich 
-- REM           Mean Time
-- REM
-- REM     NOTE: ev_loc_hr_delta is the the number of hours +/- GMT
-- REM           to calculate the correct local time for the event.
-- REM
-- REM     NOTE: st_loc_hr_delta is the the number of hours +/- GMT
-- REM           to calculate the correct local time for the date the
-- REM           event row was stored in the database.
-- REM
-- REM     NOTE: ev_loc_min_delta If null, then assume local minute offset from GMT = 0
-- REM
-- REM     NOTE: st_loc_min_delta If null, then assume local minute offset from GMT = 0
-- REM
CREATE TABLE asset_event (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     VARCHAR(29)  NOT NULL,
 gmt_event_stop      VARCHAR(29),
 ev_loc_hr_delta     SMALLINT,
 ev_loc_min_delta    SMALLINT,
 gmt_stored          VARCHAR(29),
 st_loc_hr_delta     SMALLINT,
 st_loc_min_delta    SMALLINT,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset (asset_org_site, asset_id),
    FOREIGN KEY (ev_db_site, ev_db_id, event_type_code) REFERENCES sg_as_event_type (ev_db_site, ev_db_id, event_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #44 -- Asset Utilization on Segment History Table
-- REM
-- REM This table stores when a particular asset was utilized on a given
-- REM segment and uses the date installed as part of the primary key.
-- REM If not known when installed, a date of "0000-00-00 00:00:00-000000000"
-- REM should be used.
-- REM
CREATE TABLE asset_on_segment (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 gmt_installed       VARCHAR(29)  NOT NULL, 
 gmt_removed         VARCHAR(29),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, segment_site, segment_id, gmt_installed),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset (asset_org_site, asset_id),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment (segment_site, segment_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #45 -- Asset Owner History Table
-- REM
-- REM This table stores the owner of a particular asset over time and
-- REM stores the date purchased as part of the primary key.
-- REM If not known when purchased, a date of "0000-00-00 00:00:00-000000000"
-- REM should be used.  If these assets are not currently active in the
-- REM asset_on_segment table, then they could be considered "spares".
-- REM
CREATE TABLE asset_owner (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 gmt_purchased       VARCHAR(29)  NOT NULL,
 sold_to_site        INTEGER      NOT NULL,
 purch_from_site     INTEGER,
 pc_db_site          INTEGER,
 pc_db_id            INTEGER,
 pc_type_code        INTEGER,
 asr_db_site         INTEGER,
 asr_db_id           INTEGER,
 asr_type_code       INTEGER,
 gmt_sold            VARCHAR(29),
 gmt_discarded       VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, gmt_purchased),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset (asset_org_site, asset_id),
    FOREIGN KEY (purch_from_site) REFERENCES site (site_code),
    FOREIGN KEY (sold_to_site) REFERENCES site (site_code),
    FOREIGN KEY (pc_db_site, pc_db_id, pc_type_code) REFERENCES purchase_cond_type (pc_db_site, pc_db_id, pc_type_code),
    FOREIGN KEY (asr_db_site, asr_db_id, asr_type_code) REFERENCES as_readiness_type (asr_db_site, asr_db_id, asr_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #55 -- Measurement Location Type Table
-- REM
-- REM This table stores all the various types of measurement locations.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
-- REM
CREATE TABLE meas_loc_type (
 ml_db_site          INTEGER      NOT NULL,
 ml_db_id            INTEGER      NOT NULL,
 ml_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ml_db_site, ml_db_id, ml_type_code),
    FOREIGN KEY (ml_db_site, ml_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #51 -- Data Source Type Table
-- REM
-- REM This table stores all the various types of data sources.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
-- REM
CREATE TABLE data_source_type (
 ds_db_site          INTEGER      NOT NULL,
 ds_db_id            INTEGER      NOT NULL,
 ds_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ds_db_site, ds_db_id, ds_type_code),
    FOREIGN KEY (ds_db_site, ds_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #53 -- Transducer Type Table
-- REM
-- REM A subset of the asset type table which defines the types of assets
-- REM which are valid types of transducers.
-- REM
-- REM The tr_type_abbrev is an optional 2-character abbrev for the tranducer 
-- REM type as defined for vibration in MIMOSA Document MIM-VB-001.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
CREATE TABLE trans_type (
 tr_db_site          INTEGER      NOT NULL,
 tr_db_id            INTEGER      NOT NULL,
 tr_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 tr_type_abbrev      CHAR(2),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (tr_db_site, tr_db_id, tr_type_code),
    FOREIGN KEY (tr_db_site, tr_db_id, tr_type_code) REFERENCES asset_type (as_db_site, as_db_id, as_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #46 -- Transducer Sensitive Axis Direction Type Table
-- REM
-- REM This table stores types of sensitive axis directions which 
-- REM relate to tranducers placed at measurement locations on machinery.  
-- REM The axis direction to use for monitoring rotating machinery should 
-- REM conform to the MIMOSA guidelines as specified in Document MIM-VB-001.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
CREATE TABLE tr_axis_dir_type (
 ta_db_site          INTEGER      NOT NULL,
 ta_db_id            INTEGER      NOT NULL,
 ta_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ta_db_site, ta_db_id, ta_type_code),
    FOREIGN KEY (ta_db_site, ta_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #47 -- Measurement Location Table
-- REM
-- REM This table is used to identify the location where actual measurements 
-- REM will be taken, along with the type of measurement location, the source 
-- REM of the measurement data, the type of transducer which will be used
-- REM (if applicable), the degree of the tranducer's angular orientation 
-- REM (if applicable), the corresponding transducer sensitive axis direction 
-- REM code (if applicable), and to which segment or asset the location is 
-- REM associated.  
-- REM
-- REM The meas_loc_id should be assigned by a plant to be the same across 
-- REM all database systems.  This allows data from one collection system 
-- REM to be merged with another collection system for the same location.
-- REM
-- REM Although this table does not physically restrict it, a measurement 
-- REM location must be assigned to either a segment or an asset in this 
-- REM table, as indicated by the segment_or_asset column, but not both.
-- REM
-- REM The degree of the tranducer's angular orientation (column ta_orient_deg)
-- REM (0-360) and the corresponding tranducer sensitive axis direction code, 
-- REM if applicable, is stored in this table.
-- REM
-- REM The specification of the MIMOSA Vibration Measurement Location Code,
-- REM as specified in Document MIM-VB-001, is based on appending the following
-- REM columns together to form a 14-character unique MIMOSA Location code.
-- REM The following columns from this table are used directly or as foreign key
-- REM references to create this code:
-- REM
-- REM   Component Part => mim_user_prefix (4 characters of XXXX if null)
-- REM   Bearing Housing Location on Machine System =>
-- REM         mim_loc_seq (3 digits with leading zeroes)
-- REM   Transducer Type Code => TRANS_TYPE.tr_type_abbrev (2 characters
-- REM         referenced by tr_db_site, tr_db_id, tr_type_code or XX if null)
-- REM   Angular Orientation => ta_oreint_deg (3 digits with leading zeroes
-- REM         or XXX if null)
-- REM   Transducer Sensitive Axis Direction => 1st character from
-- REM         TR_AXIS_DIR_TYPE.name referenced by ta_db_site, ta_db_id,
-- REM         ta_type_code
-- REM   Direction of Motion => motion_direction (1 character of X if null)
-- REM
-- REM   NOTE: meas_loc_id is used like a barcode--to assign a unique,
-- REM         non-changeable identifier since a primary key key cannot change
-- REM         and must uniquely define the entity.  The user_tag_ident field
-- REM         is the identifier which is meaningful to the plant.
-- REM
-- REM         Computer systems monitoring or recording information on the 
-- REM         same location should utilize the same meas_loc_site, meas_loc_id
-- REM         pair.
-- REM         
-- REM         User_tag_ident is the user identification tag which
-- REM         follows the nomenclature of the plant.  This is normally
-- REM         an abbreviation or user-defined alpha-numeric code from which
-- REM         the plant derives meaning.  This column is mandatory.
-- REM
-- REM
CREATE TABLE meas_location (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 ml_db_site          INTEGER      NOT NULL,
 ml_db_id            INTEGER      NOT NULL,
 ml_type_code        INTEGER      NOT NULL,
 segment_or_asset    CHAR(1)      NOT NULL,
 segment_site        INTEGER,
 segment_id          INTEGER,
 asset_org_site      INTEGER,
 asset_id            INTEGER,
 ds_db_site          INTEGER,
 ds_db_id            INTEGER,
 ds_type_code        INTEGER,
 tr_db_site          INTEGER,
 tr_db_id            INTEGER,
 tr_type_code        INTEGER,
 ta_orient_deg       INTEGER,
 ta_db_site          INTEGER,
 ta_db_id            INTEGER,
 ta_type_code        INTEGER,
 mim_loc_seq         INTEGER,
 motion_direction    CHAR(1),
 mim_user_prefix     CHAR(4),
 mc_db_site          INTEGER,
 mc_db_id            INTEGER,
 mc_type_code        INTEGER,
 mc_calc_size        INTEGER,
 update_interval     REAL,
 int_eu_db_site      INTEGER,
 int_eu_db_id        INTEGER,
 int_eu_type_code    INTEGER,
 collect_duration    REAL,
 dur_eu_db_site      INTEGER,
 dur_eu_db_id        INTEGER,
 dur_eu_type_code    INTEGER,
 user_tag_ident      VARCHAR(254) NOT NULL,
 barcode             VARCHAR(254),
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id),
    FOREIGN KEY (meas_loc_site) REFERENCES site (site_code),
    FOREIGN KEY (ml_db_site, ml_db_id, ml_type_code) REFERENCES meas_loc_type (ml_db_site, ml_db_id, ml_type_code),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment (segment_site, segment_id),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset (asset_org_site, asset_id),
    FOREIGN KEY (ds_db_site, ds_db_id, ds_type_code) REFERENCES data_source_type (ds_db_site, ds_db_id, ds_type_code),
    FOREIGN KEY (tr_db_site, tr_db_id, tr_type_code) REFERENCES trans_type (tr_db_site, tr_db_id, tr_type_code),
    FOREIGN KEY (ta_db_site, ta_db_id, ta_type_code) REFERENCES tr_axis_dir_type (ta_db_site, ta_db_id, ta_type_code),
    FOREIGN KEY (mc_db_site, mc_db_id, mc_type_code) REFERENCES mloc_calc_type (mc_db_site, mc_db_id, mc_type_code),
    FOREIGN KEY (int_eu_db_site, int_eu_db_id, int_eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (dur_eu_db_site, dur_eu_db_id, dur_eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (segment_or_asset in ('S','A')),
    CHECK (motion_direction in ('N','R'))
 );
GO
-- REM #48 -- Ordered List Table
-- REM
-- REM This table is used to identify the name an ordered list for a database.
-- REM
-- REM   NOTE: ord_list_id should be a non-changeable, unique
-- REM         identifier since a primary key cannot change and
-- REM         must uniquely define the entity.  System-assigned
-- REM         "hidden" ord_list_id's are strongly recommended.
-- REM
CREATE TABLE ordered_list (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 name                VARCHAR(254),
 user_tag_ident      VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #49 -- Ordered List of Measurement Locations Table
-- REM
-- REM This table is used to store the measurement locations for a
-- REM a given ordered list.
-- REM
-- REM
CREATE TABLE meas_loc_list (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id) REFERENCES ordered_list (ord_list_db_site, ord_list_db_id, ord_list_id),
    FOREIGN KEY (meas_loc_site, meas_loc_id) REFERENCES meas_location (meas_loc_site, meas_loc_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #50 -- Ordered List of Eng. Units at Measurement Locations Table
-- REM
-- REM This table is used to store the measurement location with associated
-- REM engineering units and channel number (set to 1 if not a multi-channel 
-- REM input) which has been requested for data collection / reporting at a 
-- REM certain place (ordering_seq) on an ordered list.
-- REM
-- REM
CREATE TABLE mloc_unit_list (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 channel_number      INTEGER      NOT NULL,
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq, channel_number),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id) REFERENCES ordered_list (ord_list_db_site, ord_list_db_id, ord_list_id),
    FOREIGN KEY (meas_loc_site, meas_loc_id) REFERENCES meas_location (meas_loc_site, meas_loc_id),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #52 -- Data Source Asset Table  (Subset of Asset Table)
-- REM
-- REM This table is a subset of the asset table and catalogs all 
-- REM the data asset sources (collectors, monitoring systems, etc.) 
-- REM used to take measurements.
-- REM
-- REM Measurements can be stored in the measurement event table, however,
-- REM without data source information, so entries in this 
-- REM table are not required.
-- REM
-- REM
CREATE TABLE data_source (
 ds_asset_site       INTEGER      NOT NULL,
 ds_asset_id         INTEGER      NOT NULL,
 ds_db_site          INTEGER      NOT NULL,
 ds_db_id            INTEGER      NOT NULL,
 ds_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ds_asset_site, ds_asset_id),
    FOREIGN KEY (ds_asset_site, ds_asset_id) REFERENCES asset (asset_org_site, asset_id),
    FOREIGN KEY (ds_db_site, ds_db_id, ds_type_code) REFERENCES data_source_type (ds_db_site, ds_db_id, ds_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #54 -- Transducer Asset Table  (Subset of Asset Table)
-- REM
-- REM This table is a subset of the asset table and catalogs all the 
-- REM transducers used to take measurements.  The output amplitude and
-- REM output amplitude units are the raw analog output signal which comes from
-- REM the transducer (i.e. 200 millivolts) representing 1 resulting
-- REM engineering unit (the "per" engineering unit fields, i.e. MIL). 
-- REM
-- REM Measurements can be stored in the measurement event table, however,
-- REM without transducer information, so entries in this table are not
-- REM required.
-- REM
CREATE TABLE transducer (
 tr_asset_site       INTEGER      NOT NULL,
 tr_asset_id         INTEGER      NOT NULL,
 tr_db_site          INTEGER      NOT NULL,
 tr_db_id            INTEGER      NOT NULL,
 tr_type_code        INTEGER      NOT NULL,
 out_eu_db_site      INTEGER,
 out_eu_db_id        INTEGER,
 out_eu_type_code    INTEGER,
 out_amplitude       FLOAT,
 per_eu_db_site      INTEGER,
 per_eu_db_id        INTEGER,
 per_eu_type_code    INTEGER,
 gmt_last_calib      VARCHAR(29),
 self_powered_yn     CHAR(1),
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (tr_asset_site, tr_asset_id),
    FOREIGN KEY (tr_asset_site, tr_asset_id) REFERENCES asset (asset_org_site, asset_id),
    FOREIGN KEY (tr_db_site, tr_db_id, tr_type_code) REFERENCES trans_type (tr_db_site, tr_db_id, tr_type_code),
    FOREIGN KEY (out_eu_db_site, out_eu_db_id, out_eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (per_eu_db_site, per_eu_db_id, per_eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (self_powered_yn in (NULL,'Y','N'))
 );
GO
-- REM
-- REM #88 -- Data Quality Type Table
-- REM
-- REM   The data quality type defines the various quality states which
-- REM   data in tables can be classified.  These come from the ISO 9000-2
-- REM   status guidelines:
-- REM
-- REM                        1 = Not Inspected, Quality Unknown
-- REM                        2 = Inspected and Accepted, Quality Good
-- REM                        3 = Inspected and On Hold, Quality Under Review
-- REM                        4 = Inspected and Rejected, Quality Bad
-- REM
-- REM   NOTE: MIMOSA populates and maintains this table.
-- REM         No user-defined entries are supported.
-- REM
CREATE TABLE data_qual_type (
 dqual_type_code     SMALLINT     NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (dqual_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #56 -- Measurement Event History Table
-- REM
-- REM This table is a history of data collection events occurring at
-- REM measurement locations.  This event could have recorded a single 
-- REM numeric value of a certain type, or a group of related signal 
-- REM processed measurements.  Each measurement event relates back to one
-- REM measurement location.  
-- REM
-- REM Foreign keys are defined to the segment, asset, 
-- REM data collection source, and transducer tables in order for a system to 
-- REM track which segment and/or which asset and which data collection 
-- REM source and transducer the measurement is tied to at at this 
-- REM particular instance in time.  This table does not contain the actual
-- REM data, but the fact that on a given time, at a measurement location
-- REM which was then associated with a physical object and/or a functional
-- REM object, a measurement of a certain location type was taken.
-- REM
-- REM     NOTE: The non-mandatory segment_site,segment_id columns are for 
-- REM           measurement locations on assets where the actual segment 
-- REM           where the asset is installed needs to be captured with 
-- REM           the measurement event.
-- REM
-- REM     NOTE: The non-mandatory asset_org_site,asset_id columns are for 
-- REM           measurement locations on segments where the actual asset
-- REM           installed on the segment needs to be captured with 
-- REM           the measurement event.
-- REM
-- REM     NOTE: ev_loc_hr_delta is the the number of hours +/- GMT
-- REM           to calculate the correct local time for the event.
-- REM
-- REM     NOTE: st_loc_hr_delta is the the number of hours +/- GMT
-- REM           to calculate the correct local time for the date the
-- REM           event row was stored in the database.
-- REM
-- REM     NOTE: ev_loc_min_delta: If null, then assume local minute offset from GMT = 0
-- REM 
-- REM     NOTE: st_loc_min_delta: If null, then assume local minute offset from GMT = 0
-- REM
-- REM     NOTE:  confid_percent: Confidence in measurement accuracy (0=no confidence, 100=complete confidence)
-- REM
CREATE TABLE meas_event (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 ev_loc_hr_delta     SMALLINT,
 ev_loc_min_delta    SMALLINT, 
 gmt_stored          VARCHAR(29),
 st_loc_hr_delta     SMALLINT,
 st_loc_min_delta    SMALLINT,
 segment_site        INTEGER,
 segment_id          INTEGER,
 asset_org_site      INTEGER,
 asset_id            INTEGER,
 ds_asset_site       INTEGER,
 ds_asset_id         INTEGER,
 tr_asset_site       INTEGER,
 tr_asset_id         INTEGER,
 dqual_type_code     SMALLINT     NOT NULL,
 ml_db_site          INTEGER,
 ml_db_id            INTEGER,
 ml_type_code        INTEGER,
 mc_db_site          INTEGER,
 mc_db_id            INTEGER,
 mc_type_code        INTEGER,
 mc_calc_size        INTEGER,
 collect_duration    REAL,
 dur_eu_db_site      INTEGER,
 dur_eu_db_id        INTEGER,
 dur_eu_type_code    INTEGER,
 confid_percent      SMALLINT,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (meas_loc_site, meas_loc_id) REFERENCES meas_location (meas_loc_site, meas_loc_id),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment (segment_site, segment_id),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset (asset_org_site, asset_id),
    FOREIGN KEY (ds_asset_site, ds_asset_id) REFERENCES data_source (ds_asset_site, ds_asset_id),
    FOREIGN KEY (tr_asset_site, tr_asset_id) REFERENCES transducer (tr_asset_site, tr_asset_id),
    FOREIGN KEY (dqual_type_code) REFERENCES data_qual_type (dqual_type_code),
    FOREIGN KEY (ml_db_site, ml_db_id, ml_type_code) REFERENCES meas_loc_type (ml_db_site, ml_db_id, ml_type_code),
    FOREIGN KEY (mc_db_site, mc_db_id, mc_type_code) REFERENCES mloc_calc_type (mc_db_site, mc_db_id, mc_type_code),
    FOREIGN KEY (dur_eu_db_site, dur_eu_db_id, dur_eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #100 -- Measurement Event Associations
-- REM
-- REM This table contains measurement events which are related to one
-- REM another.  This is used in vibration to associate a vibration
-- REM measurement event to its corresponding tachometer signal measurement
-- REM event and for multi-channel data which are related to each other.
-- REM
CREATE TABLE meas_event_assoc (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 related_mloc_site   INTEGER      NOT NULL,
 related_mloc_id     INTEGER      NOT NULL,
 related_gmt_event   VARCHAR(29)  NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, related_mloc_site, related_mloc_id, related_gmt_event),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES meas_event (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (related_mloc_site, related_mloc_id, related_gmt_event) REFERENCES meas_event (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #57 -- Measurement Event Remarks Table 
-- REM
-- REM This table is where each measurement event textual remarks are 
-- REM recorded.  This table is for an operator or analyst to put in
-- REM free-form notes about why this measurement event was recorded, etc.
-- REM
-- REM This table should NOT store measurement event alpha-numeric
-- REM character data like dates or user identifiers which should be tracked
-- REM over time.  These should be stored in the measurement event character 
-- REM value table #59 (MEVENT_CHR_VALUE) with a specific engineering unit 
-- REM associated with it.
-- REM
CREATE TABLE meas_event_rem (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 remark_text         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES meas_event (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #58 -- Measurement Event Numeric Data Table 
-- REM
-- REM This table is where all simple numeric data values which are related to
-- REM to a measurement event for non-signal processed data is stored.
-- REM
-- REM This table could store simple pressures, temperatures, tachometer voltages,
-- REM load readings, etc. which do not need additional information to interpret.
-- REM
-- REM Do NOT store frequency-related overall vibration amplitude data in this table, 
-- REM which should be stored in the signal-processed, single amplitude value/vector
-- REM table (SP_AMPL_DATA).
-- REM
-- REM Do NOT store fluid/gas test data nor electrical test data which require a 
-- REM "test type" in order to comprehend.  Version 1.1 of CRIS will provide specific
-- REM tables for this type of data.
-- REM
CREATE TABLE mevent_num_data (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          FLOAT       NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES meas_event (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #59 -- Measurement Event Character Data Table 
-- REM
-- REM This table is where all alpha-numeric data values which are related to
-- REM to a measurement event for non-signal processed data is stored.
-- REM
-- REM This table stores measurement location data which needs to
-- REM be tracked over time and contains an alpha-numeric code or date.
-- REM
CREATE TABLE mevent_chr_data (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES meas_event (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #60 -- Alarm Severity Table
-- REM
-- REM This table stores the entries possible for alarm severity.
-- REM
-- REM   NOTE: MIMOSA populates and maintains this table.
-- REM         No user-defined entries are supported.
-- REM
CREATE TABLE alarm_severity (
 al_severity_rank    SMALLINT     NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (al_severity_rank),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #61 -- Alarm Type Table
-- REM
-- REM This table stores the different types of alarms used by a database,
-- REM along with its severity ranking and name.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
CREATE TABLE alarm_type (
 al_db_site          INTEGER      NOT NULL,
 al_db_id            INTEGER      NOT NULL,
 al_type_code        INTEGER      NOT NULL,
 al_severity_rank    SMALLINT     NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (al_db_site, al_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (al_severity_rank) REFERENCES alarm_severity (al_severity_rank),
    FOREIGN KEY  (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #317 -- Num_Alarm_Reg
-- REM 
-- REM Measurement Location Numeric Alarm Regions
-- REM
CREATE TABLE num_alarm_reg (
 alarm_db_site       INTEGER      NOT NULL, 
 alarm_db_id         INTEGER      NOT NULL, 
 meas_loc_site       INTEGER      NOT NULL, 
 meas_loc_id         INTEGER      NOT NULL, 
 ordering_seq        INTEGER      NOT NULL, 
 ml_db_site          INTEGER      NOT NULL, 
 ml_db_id            INTEGER      NOT NULL, 
 ml_type_code        INTEGER      NOT NULL, 
 mc_db_site          INTEGER      NOT NULL, 
 mc_db_id            INTEGER      NOT NULL, 
 mc_type_code        INTEGER      NOT NULL, 
 al_db_site          INTEGER      NOT NULL, 
 al_db_id            INTEGER      NOT NULL, 
 al_type_code        INTEGER      NOT NULL, 
 eu_db_site          INTEGER      NOT NULL, 
 eu_db_id            INTEGER      NOT NULL, 
 eu_type_code        INTEGER      NOT NULL, 
 gmt_alarm_start     VARCHAR(29)  NOT NULL,
 st_loc_hr_delta     SMALLINT,
 st_loc_min_delta    SMALLINT,
 min_amplitude       FLOAT       NOT NULL,
 max_amplitude       FLOAT       NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (alarm_db_site, alarm_db_id, meas_loc_site, meas_loc_id, ordering_seq),
    FOREIGN KEY (alarm_db_site, alarm_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (meas_loc_site, meas_loc_id) REFERENCES meas_location (meas_loc_site, meas_loc_id),
    FOREIGN KEY (ml_db_site, ml_db_id, ml_type_code) REFERENCES meas_loc_type (ml_db_site, ml_db_id, ml_type_code),
    FOREIGN KEY (mc_db_site, mc_db_id, mc_type_code) REFERENCES mloc_calc_type (mc_db_site, mc_db_id, mc_type_code),
    FOREIGN KEY (al_db_site, al_db_id, al_type_code) REFERENCES alarm_type (al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 ); 
GO
-- REM #109 -- agent_type
-- REM
-- REM  
-- REM
CREATE TABLE agent_type (
 agent_db_site       INTEGER      NOT NULL,
 agent_db_id         INTEGER      NOT NULL,
 agent_type_code     INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (agent_db_site, agent_db_id, agent_type_code),
    FOREIGN KEY (agent_db_site, agent_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY  (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #117 -- agent
-- REM
-- REM Organization, Group, Individual, Intelligent Agent, System
-- REM
-- REM NOTE: org_agent_site: Original agent site (home site)
-- REM
CREATE TABLE agent (
 org_agent_site      INTEGER      NOT NULL,
 agent_id            INTEGER      NOT NULL,
 agent_db_site       INTEGER      NOT NULL,
 agent_db_id         INTEGER      NOT NULL,
 agent_type_code     INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (org_agent_site, agent_id),
    FOREIGN KEY (org_agent_site) REFERENCES site(site_code),
    FOREIGN KEY (agent_db_site, agent_db_id, agent_type_code) REFERENCES agent_type(agent_db_site, agent_db_id, agent_type_code),
    FOREIGN KEY  (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #73 -- Source Signal Detector Type Table
-- REM
-- REM This table stores different source signal detector types.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
CREATE TABLE src_detect_type (
 src_dt_db_site      INTEGER      NOT NULL,
 src_dt_db_id        INTEGER      NOT NULL,
 src_dt_type_code    INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (src_dt_db_site, src_dt_db_id, src_dt_type_code),
    FOREIGN KEY (src_dt_db_site, src_dt_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #74 -- Post-Processed Signal Processing Scaling Mode Table
-- REM
-- REM This table stores different types of signal processing scaling methods.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
CREATE TABLE post_scaling_type (
 pst_sc_db_site      INTEGER      NOT NULL,
 pst_sc_db_id        INTEGER      NOT NULL,
 pst_sc_type_code    INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code),
    FOREIGN KEY (pst_sc_db_site, pst_sc_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #63 -- Measurement Event Numeric Data Alarm Table 
-- REM
-- REM This table stores all the alarms triggered by the numeric value
-- REM stored in the MEVENT_NUM_DATA table.  If data is available in the
-- REM Measurement Location Numeric Data Alarm Region Table, then the alarm
-- REM data in this table can be derived and does not need to be stored here.
-- REM However, some systems do not send all the alarm region data, and we 
-- REM need to store the fact that an alarm was triggered.
-- REM
-- REM org_agent_site, agent_id - Agent which acknowleged the alarm
-- REM
CREATE TABLE mevent_num_alarm (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 al_db_site          INTEGER      NOT NULL,
 al_db_id            INTEGER      NOT NULL,
 al_type_code        INTEGER      NOT NULL,
 gmt_acknowledged    VARCHAR(29),
 ack_loc_hr_delta    SMALLINT, 
 ack_loc_min_delta   SMALLINT, 
 org_agent_site      INTEGER, 
 agent_id            INTEGER, 
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, eu_db_site, eu_db_id, eu_type_code, al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, eu_db_site, eu_db_id, eu_type_code) REFERENCES mevent_num_data (meas_loc_site, meas_loc_id, gmt_event, eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (al_db_site, al_db_id, al_type_code) REFERENCES alarm_type (al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (org_agent_site, agent_id) REFERENCES agent (org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #318 -- num_al_assoc_reg 
-- REM
-- REM Numeric Alarm Associated Regions in Alarm
-- REM
CREATE TABLE num_al_assoc_reg (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 al_db_site          INTEGER      NOT NULL,
 al_db_id            INTEGER      NOT NULL,
 al_type_code        INTEGER      NOT NULL,
 alarm_db_site       INTEGER      NOT NULL,
 alarm_db_id         INTEGER      NOT NULL,
 al_meas_loc_site    INTEGER      NOT NULL,
 al_meas_loc_id      INTEGER      NOT NULL,
 al_ordering_seq        INTEGER      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, eu_db_site, eu_db_id, eu_type_code, al_db_site, al_db_id, al_type_code, alarm_db_site, alarm_db_id, al_meas_loc_site, al_meas_loc_id, al_ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, eu_db_site, eu_db_id, eu_type_code, al_db_site, al_db_id, al_type_code) REFERENCES mevent_num_alarm (meas_loc_site, meas_loc_id, gmt_event, eu_db_site, eu_db_id, eu_type_code, al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (alarm_db_site, alarm_db_id, al_meas_loc_site, al_meas_loc_id, al_ordering_seq) REFERENCES num_alarm_reg (alarm_db_site, alarm_db_id, meas_loc_site, meas_loc_id, ordering_seq),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #319 -- spa_alarm_reg 
-- REM
-- REM Signal-processed Amplitudes Alarm Regions
-- REM
CREATE TABLE spa_alarm_reg (
 alarm_db_site       INTEGER      NOT NULL, 
 alarm_db_id         INTEGER      NOT NULL, 
 meas_loc_site       INTEGER      NOT NULL, 
 meas_loc_id         INTEGER      NOT NULL, 
 ordering_seq        INTEGER      NOT NULL, 
 ml_db_site          INTEGER      NOT NULL, 
 ml_db_id            INTEGER      NOT NULL, 
 ml_type_code        INTEGER      NOT NULL, 
 mc_db_site          INTEGER      NOT NULL, 
 mc_db_id            INTEGER      NOT NULL, 
 mc_type_code        INTEGER      NOT NULL, 
 al_db_site          INTEGER      NOT NULL, 
 al_db_id            INTEGER      NOT NULL, 
 al_type_code        INTEGER      NOT NULL, 
 freq_or_order       CHAR(1)      NOT NULL,
 min_in_hz_or_ord    FLOAT       NOT NULL,
 max_in_hz_or_ord    FLOAT       NOT NULL,
 gmt_alarm_start     VARCHAR(29)  NOT NULL,
 st_loc_hr_delta     SMALLINT,
 st_loc_min_delta    SMALLINT, 
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 pst_sc_db_site      INTEGER      NOT NULL,
 pst_sc_db_id        INTEGER      NOT NULL,
 pst_sc_type_code    INTEGER      NOT NULL,
 src_dt_db_site      INTEGER,
 src_dt_db_id        INTEGER,
 src_dt_type_code    INTEGER,
 min_amplitude       FLOAT       NOT NULL,
 max_amplitude       FLOAT       NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (alarm_db_site, alarm_db_id, meas_loc_site, meas_loc_id, ordering_seq),
    FOREIGN KEY (alarm_db_site, alarm_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (meas_loc_site, meas_loc_id) REFERENCES meas_location (meas_loc_site, meas_loc_id),
    FOREIGN KEY (ml_db_site, ml_db_id, ml_type_code) REFERENCES meas_loc_type (ml_db_site, ml_db_id, ml_type_code),
    FOREIGN KEY (mc_db_site, mc_db_id, mc_type_code) REFERENCES mloc_calc_type (mc_db_site, mc_db_id, mc_type_code),
    FOREIGN KEY (al_db_site, al_db_id, al_type_code) REFERENCES alarm_type (al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code) REFERENCES post_scaling_type (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code),
    FOREIGN KEY (src_dt_db_site, src_dt_db_id, src_dt_type_code) REFERENCES src_detect_type (src_dt_db_site, src_dt_db_id, src_dt_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (freq_or_order in ('F','O'))
 );

GO
-- REM #64 -- Signal Process Type Table
-- REM
-- REM This table stores all the various types of signal processing that
-- REM could be defined.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
-- REM
CREATE TABLE signal_proc_type (
 sp_db_site          INTEGER      NOT NULL,
 sp_db_id            INTEGER      NOT NULL,
 sp_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sp_db_site, sp_db_id, sp_type_code),
    FOREIGN KEY (sp_db_site, sp_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #65 -- Signal Process Block Table
-- REM
-- REM This table will store all the signal process block entries specified  
-- REM in a given database, each of a specified signal processing type and  
-- REM assigns each a unique signal_proc_id to each entry in each database.
-- REM
CREATE TABLE signal_proc_blk (
 sp_blk_db_site      INTEGER      NOT NULL,
 sp_blk_db_id        INTEGER      NOT NULL,
 sp_block_id         INTEGER      NOT NULL,
 sp_db_site          INTEGER      NOT NULL,
 sp_db_id            INTEGER      NOT NULL,
 sp_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sp_blk_db_site, sp_blk_db_id, sp_block_id),
    FOREIGN KEY (sp_blk_db_site, sp_blk_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (sp_db_site, sp_db_id, sp_type_code) REFERENCES signal_proc_type (sp_db_site, sp_db_id, sp_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #66 -- Signal Process Block Numeric Data Type Table
-- REM
-- REM This table stores all the various types of numeric data associated
-- REM with signal process blocks.  Data associated with averaging, 
-- REM source detection, and windows can optionally be stored here, but should
-- REM be specified when data is stored in the actual time  waveform, FFT, CPB,
-- REM or single amplitude value/vector data tables.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
CREATE TABLE sp_num_dat_type (
 spn_db_site         INTEGER      NOT NULL,
 spn_db_id           INTEGER      NOT NULL,
 spn_type_code       INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (spn_db_site, spn_db_id, spn_type_code),
    FOREIGN KEY (spn_db_site, spn_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #67 -- Signal Process Block Numeric Data Table
-- REM
-- REM This table will store the numeric data related to an entry in the 
-- REM the signal process block table. 
-- REM
-- REM   NOTE:  Care must be taken not to change the numeric data of blocks used
-- REM          in a signal process stream if measurements have been stored 
-- REM          for the stream.
-- REM
CREATE TABLE sp_blk_num_data (
 sp_blk_db_site      INTEGER      NOT NULL,
 sp_blk_db_id        INTEGER      NOT NULL,
 sp_block_id         INTEGER      NOT NULL,
 spn_db_site         INTEGER      NOT NULL,
 spn_db_id           INTEGER      NOT NULL,
 spn_type_code       INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          FLOAT       NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sp_blk_db_site, sp_blk_db_id, sp_block_id, spn_db_site, spn_db_id, spn_type_code),
    FOREIGN KEY (sp_blk_db_site, sp_blk_db_id, sp_block_id) REFERENCES signal_proc_blk (sp_blk_db_site, sp_blk_db_id, sp_block_id),
    FOREIGN KEY (spn_db_site, spn_db_id, spn_type_code) REFERENCES sp_num_dat_type (spn_db_site, spn_db_id, spn_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #261 -- sp_stream_type
-- REM
-- REM Signal Process Stream Type
-- REM
CREATE TABLE sp_stream_type (
 sps_type_db_site    INTEGER      NOT NULL,
 sps_type_db_id      INTEGER      NOT NULL,
 sps_type_code       INTEGER      NOT NULL,
 name		         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sps_type_db_site, sps_type_db_id, sps_type_code),
    FOREIGN KEY (sps_type_db_site, sps_type_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #68 -- Signal Process Stream Table
-- REM
-- REM This table will store the signal process streams for a given database.
-- REM These streams will contain sequences of signal process blocks which
-- REM define the processing sequence which data passed through.
-- REM
-- REM Actual single amplitude value/vector data, FFT data, time waveform data,
-- REM and CPB data can optionally be associated with an entry in this table.
-- REM
CREATE TABLE sp_stream (
 sp_str_db_site      INTEGER      NOT NULL,
 sp_str_db_id        INTEGER      NOT NULL,
 sp_stream_id        INTEGER      NOT NULL,
 sps_type_db_site    INTEGER	  NOT NULL,
 sps_type_db_id      INTEGER      NOT NULL,
 sps_type_code       INTEGER      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (sps_type_db_site, sps_type_db_id, sps_type_code) REFERENCES sp_stream_type (sps_type_db_site, sps_type_db_id, sps_type_code),  
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #69 -- Signal Process Stream Blocks Table
-- REM
-- REM This table details the sequence of signal process blocks for each
-- REM signal process stream.
-- REM
-- REM   NOTE:  Care must be taken not to change the sequence of blocks in
-- REM          a stream if measurements have been stored for the stream.
-- REM          Normally, a new stream should be defined instead of 
-- REM          updating the original stream.
-- REM          
-- REM
CREATE TABLE sp_stream_block (
 sp_str_db_site      INTEGER      NOT NULL,
 sp_str_db_id        INTEGER      NOT NULL,
 sp_stream_id        INTEGER      NOT NULL,
 sp_blk_db_site      INTEGER      NOT NULL,
 sp_blk_db_id        INTEGER      NOT NULL,
 sp_block_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sp_str_db_site, sp_str_db_id, sp_stream_id, sp_blk_db_site, sp_blk_db_id, sp_block_id),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id) REFERENCES sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY (sp_blk_db_site, sp_blk_db_id, sp_block_id) REFERENCES signal_proc_blk (sp_blk_db_site, sp_blk_db_id, sp_block_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #70 -- Average Type Table
-- REM
-- REM This table stores different types of signal processing averaging methods.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
CREATE TABLE average_type (
 ave_db_site         INTEGER      NOT NULL,
 ave_db_id           INTEGER      NOT NULL,
 ave_type_code       INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ave_db_site, ave_db_id, ave_type_code),
    FOREIGN KEY (ave_db_site, ave_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #71 -- Average Weight Type Table
-- REM
-- REM This table stores different types of signal processing average
-- REM weighting methods.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
CREATE TABLE ave_weight_type (
 ave_wt_db_site      INTEGER      NOT NULL,
 ave_wt_db_id        INTEGER      NOT NULL,
 ave_wt_type_code    INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code),
    FOREIGN KEY (ave_wt_db_site, ave_wt_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #72 -- Average Synchronization Type Table
-- REM
-- REM This table stores different types of signal processing averaging 
-- REM synchronization methods.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
CREATE TABLE ave_synch_type (
 ave_sy_db_site      INTEGER      NOT NULL,
 ave_sy_db_id        INTEGER      NOT NULL,
 ave_sy_type_code    INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code),
    FOREIGN KEY (ave_sy_db_site, ave_sy_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #75 -- Signal-Processed Frequency/Order Single Amplitude/Vector Data
-- REM        Table
-- REM
-- REM This table will store 1 or more single amplitudes AND/OR single vectors
-- REM which are related to frequency or order ranges which resulted as an 
-- REM output of a measurement event.
-- REM
-- REM A vector can be stored by placing the angle in degrees in the
-- REM column angle_in_degrees.
-- REM
-- REM  NOTE: If the source signal detector type is "FFT Power RMS", then the 
-- REM        amplitude field is calculated from the spectra by taking the 
-- REM        square root of the sum of all amplitude values squared which is 
-- REM        then divided by the window factor.
-- REM
-- REM
CREATE TABLE sp_ampl_data (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 pst_sc_db_site      INTEGER      NOT NULL,
 pst_sc_db_id        INTEGER      NOT NULL,
 pst_sc_type_code    INTEGER      NOT NULL,
 freq_or_order       CHAR(1)      NOT NULL,
 min_in_hz_or_ord    FLOAT       NOT NULL,
 max_in_hz_or_ord    FLOAT       NOT NULL,
 src_dt_db_site      INTEGER,
 src_dt_db_id        INTEGER,
 src_dt_type_code    INTEGER,
 sp_str_db_site      INTEGER,
 sp_str_db_id        INTEGER,
 sp_stream_id        INTEGER,
 assoc_rpm_in_hz     FLOAT,
 amplitude           FLOAT       NOT NULL,
 angle_in_degrees    FLOAT,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES meas_event (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code) REFERENCES post_scaling_type (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code),
    FOREIGN KEY (src_dt_db_site, src_dt_db_id, src_dt_type_code) REFERENCES src_detect_type (src_dt_db_site, src_dt_db_id, src_dt_type_code),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id) REFERENCES sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (freq_or_order in ('F','O'))
 );
GO
-- REM #79 -- Signal-Processed Frequency/Order Single Amplitude Data Alarm Table
-- REM
-- REM This table stores all the alarms triggered by the signal-processed
-- REM single amplitudes stored in the SP_AMPL_DATA table. If data is 
-- REM available in the Measurement Location Signal-processed Single 
-- REM Amplitude Alarm Region Table, then the alarm data in this table can 
-- REM be derived and does not need to be stored here.
-- REM However, some systems do not send all the alarm region data, and we 
-- REM need to store the fact that an alarm was triggered.
-- REM
-- REM org_agent_site, agent_id - Agent which acknowleged the alarm
-- REM
CREATE TABLE sp_ampl_alarm (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 al_db_site          INTEGER      NOT NULL,
 al_db_id            INTEGER      NOT NULL,
 al_type_code        INTEGER      NOT NULL,
 gmt_acknowledged    VARCHAR(29),
 ack_loc_hr_delta    SMALLINT, 
 ack_loc_min_delta   SMALLINT, 
 org_agent_site      INTEGER, 
 agent_id            INTEGER, 
 name                VARCHAR(254), 	 
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, ordering_seq, al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, ordering_seq) REFERENCES sp_ampl_data (meas_loc_site, meas_loc_id, gmt_event, ordering_seq),
    FOREIGN KEY (al_db_site, al_db_id, al_type_code) REFERENCES alarm_type (al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (org_agent_site, agent_id) REFERENCES agent (org_agent_site, agent_id), 
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #320 -- spa_al_assoc_reg 
-- REM
-- REM Signal-Processed Amplitude Associated Regions in Alarm
-- REM
CREATE TABLE spa_al_assoc_reg (
 meas_loc_site       INTEGER      NOT NULL, 
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 al_db_site          INTEGER      NOT NULL,
 al_db_id            INTEGER      NOT NULL,
 al_type_code        INTEGER      NOT NULL,
 alarm_db_site       INTEGER      NOT NULL,
 alarm_db_id         INTEGER      NOT NULL,
 al_meas_loc_site    INTEGER      NOT NULL,
 al_meas_loc_id      INTEGER      NOT NULL,
 al_ordering_seq     INTEGER      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, ordering_seq, al_db_site, al_db_id, al_type_code, alarm_db_site, alarm_db_id, al_meas_loc_site, al_meas_loc_id, al_ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, ordering_seq, al_db_site, al_db_id, al_type_code) REFERENCES sp_ampl_alarm (meas_loc_site, meas_loc_id, gmt_event, ordering_seq, al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (alarm_db_site, alarm_db_id, al_meas_loc_site, al_meas_loc_id, al_ordering_seq) REFERENCES spa_alarm_reg (alarm_db_site, alarm_db_id, meas_loc_site, meas_loc_id, ordering_seq),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #80 -- Window Type Table
-- REM
-- REM This table stores different types of FFT and time waveform windows.
-- REM The pf_multiplier column is the power factor multiplier for the
-- REM window.
-- REM
-- REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
-- REM
CREATE TABLE window_type (
 win_db_site         INTEGER      NOT NULL,
 win_db_id           INTEGER      NOT NULL,
 win_type_code       INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 pf_multiplier       FLOAT       NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (win_db_site, win_db_id, win_type_code),
    FOREIGN KEY (win_db_site, win_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #81 -- Signal-Processed, Real/Complex Linear Frequency/Order FFT Spectrum
-- REM        Data Table
-- REM
-- REM This table will store real-only or complex FFT data which
-- REM is related to a frequency or order range which resulted as an output of
-- REM a measurement event.
-- REM
-- REM   NOTE: Spectrum_data is a variable-length binary field, first containing
-- REM         4-byte IEEE float real values for each line of resolution in the 
-- REM         spectra.  If the complex_yn field = 'Y', then the imaginary
-- REM         float values in 4-byte IEEE format follow the set of real
-- REM         values.  
-- REM
-- REM         The IEEE format is:
-- REM         
-- REM                 --> Low-Order Byte First
-- REM                      bits  0-22 --> Mantissa
-- REM                      bits 23-30 --> Exponent
-- REM                      bit  31    --> Sign
-- REM
-- REM   NOTE: The bin width = (max_in_hz_or_ord - min_in_hz_or_ord) /
-- REM                         resolution_lines
-- REM
-- REM   NOTE: The frequency/order associated with the first line of the 
-- REM         spectrum = min_in_hz_or_ord + bin_width
-- REM
-- REM   NOTE: The ave_overlap_pct column is an percentage ranging from 
-- REM         0 -- 100 of the average overlap percentage used.
-- REM
CREATE TABLE sp_fft_data (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 pst_sc_db_site      INTEGER      NOT NULL,
 pst_sc_db_id        INTEGER      NOT NULL,
 pst_sc_type_code    INTEGER      NOT NULL,
 freq_or_order       CHAR(1)      NOT NULL,
 min_in_hz_or_ord    FLOAT       NOT NULL,
 max_in_hz_or_ord    FLOAT       NOT NULL,
 resolution_lines    INTEGER      NOT NULL,
 win_db_site         INTEGER      NOT NULL,
 win_db_id           INTEGER      NOT NULL,
 win_type_code       INTEGER      NOT NULL,
 ave_db_site         INTEGER,
 ave_db_id           INTEGER,
 ave_type_code       INTEGER,
 ave_wt_db_site      INTEGER,
 ave_wt_db_id        INTEGER,
 ave_wt_type_code    INTEGER,
 ave_sy_db_site      INTEGER,
 ave_sy_db_id        INTEGER,
 ave_sy_type_code    INTEGER,
 ave_overlap_pct     FLOAT,
 num_of_averages     INTEGER,
 sp_str_db_site      INTEGER,
 sp_str_db_id        INTEGER,
 sp_stream_id        INTEGER,
 assoc_rpm_in_hz     FLOAT,
 name                VARCHAR(254),
 dc_level            FLOAT,
 complex_yn          CHAR(1)      NOT NULL,
 spectrum_data       IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES meas_event (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code) REFERENCES post_scaling_type (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code),
    FOREIGN KEY (win_db_site, win_db_id, win_type_code) REFERENCES window_type (win_db_site, win_db_id, win_type_code),
    FOREIGN KEY (ave_db_site, ave_db_id, ave_type_code) REFERENCES average_type (ave_db_site, ave_db_id, ave_type_code),
    FOREIGN KEY (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code) REFERENCES ave_weight_type (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code),
    FOREIGN KEY (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code) REFERENCES ave_synch_type (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id) REFERENCES sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (freq_or_order in ('F','O')),
    CHECK (complex_yn in ('Y','N'))
 );
GO
-- REM #83 -- Signal-Processed, Real/Complex Linear Time Waveform Data Table
-- REM
-- REM This table will store real-only or complex time waveform data which 
-- REM resulted as an output of a measurement event.  A complex time waveform
-- REM is obtained when you have a decimated signal over a certain frequency range.
-- REM
-- REM   NOTE: Waveform_data is a variable-length binary field, first containing
-- REM         4-byte IEEE float real values of length number_of_samples in
-- REM         length.  If the complex_yn field = 'Y', then the imaginary
-- REM         float values in 4-byte IEEE format follow the real set of values.
-- REM
-- REM         The IEEE format is:
-- REM         
-- REM                 --> Low-Order Byte First
-- REM                      bits  0-22 --> Mantissa
-- REM                      bits 23-30 --> Exponent
-- REM                      bit  31    --> Sign
-- REM
-- REM   NOTE: The off_secs_or_revs column is the delta offset start time
-- REM         in seconds or offset number of revolutions from gmt_event 
-- REM         time when the sample started.
-- REM
-- REM   NOTE: The ave_overlap_pct column is an percentage ranging from 
-- REM         0 -- 100 of the average overlap percentage used.
-- REM
CREATE TABLE sp_time_data (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 secs_or_revs        CHAR(1)      NOT NULL,
 off_secs_or_revs    FLOAT       NOT NULL,
 max_secs_or_revs    FLOAT       NOT NULL,
 number_of_samples   FLOAT       NOT NULL,
 win_db_site         INTEGER      NOT NULL,
 win_db_id           INTEGER      NOT NULL,
 win_type_code       INTEGER      NOT NULL,
 ave_db_site         INTEGER,
 ave_db_id           INTEGER,
 ave_type_code       INTEGER,
 ave_wt_db_site      INTEGER,
 ave_wt_db_id        INTEGER,
 ave_wt_type_code    INTEGER,
 ave_sy_db_site      INTEGER,
 ave_sy_db_id        INTEGER,
 ave_sy_type_code    INTEGER,
 ave_overlap_pct     FLOAT,
 num_of_averages     INTEGER,
 sp_str_db_site      INTEGER,
 sp_str_db_id        INTEGER,
 sp_stream_id        INTEGER,
 assoc_rpm_in_hz     FLOAT,
 name                VARCHAR(254),
 complex_yn          CHAR(1)      NOT NULL,
 waveform_data       IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES meas_event (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (win_db_site, win_db_id, win_type_code) REFERENCES window_type (win_db_site, win_db_id, win_type_code),
    FOREIGN KEY (ave_db_site, ave_db_id, ave_type_code) REFERENCES average_type (ave_db_site, ave_db_id, ave_type_code),
    FOREIGN KEY (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code) REFERENCES ave_weight_type (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code),
    FOREIGN KEY (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code) REFERENCES ave_synch_type (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id) REFERENCES sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (secs_or_revs in ('S','R')),
    CHECK (complex_yn in ('Y','N'))
 );
GO
-- REM #85 -- Signal-Processed, Real Linear Constant Percentage Band Spectrum 
-- REM        Table
-- REM
-- REM This table will store real CPB spectrum data which resulted as an 
-- REM output of a measurement event.
-- REM
-- REM   NOTE: Spectrum_data is a variable-length binary field, containing
-- REM         4-byte IEEE float real values for each band in the 
-- REM         spectra.  The IEEE format is:
-- REM         
-- REM                 --> Low-Order Byte First
-- REM                      bits  0-22 --> Mantissa
-- REM                      bits 23-30 --> Exponent
-- REM                      bit  31    --> Sign
-- REM
-- REM The width_pct_or_oct column stores a "P" for percent band width (0-100)
-- REM or an "O" for octave width associated with the band_width column.
-- REM
-- REM The field center_in_hz_1bd is the first band's center frequency in
-- REM hertz.
-- REM
CREATE TABLE sp_cpb_data (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 pst_sc_db_site      INTEGER      NOT NULL,
 pst_sc_db_id        INTEGER      NOT NULL,
 pst_sc_type_code    INTEGER      NOT NULL,
 number_of_bands     INTEGER      NOT NULL,
 center_in_hz_1bd    FLOAT       NOT NULL,
 width_pct_or_oct    CHAR(1)      NOT NULL,
 band_width          FLOAT       NOT NULL,
 ave_db_site         INTEGER,
 ave_db_id           INTEGER,
 ave_type_code       INTEGER,
 ave_wt_db_site      INTEGER,
 ave_wt_db_id        INTEGER,
 ave_wt_type_code    INTEGER,
 ave_sy_db_site      INTEGER,
 ave_sy_db_id        INTEGER,
 ave_sy_type_code    INTEGER,
 ave_overlap_pct     FLOAT,
 num_of_averages     INTEGER,
 sp_str_db_site      INTEGER,
 sp_str_db_id        INTEGER,
 sp_stream_id        INTEGER,
 assoc_rpm_in_hz     FLOAT,
 name                VARCHAR(254),
 spectrum_data       IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES meas_event (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code) REFERENCES post_scaling_type (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code),
    FOREIGN KEY (ave_db_site, ave_db_id, ave_type_code) REFERENCES average_type (ave_db_site, ave_db_id, ave_type_code),
    FOREIGN KEY (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code) REFERENCES ave_weight_type (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code),
    FOREIGN KEY (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code) REFERENCES ave_synch_type (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id) REFERENCES sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (width_pct_or_oct in ('P','O'))
 );
GO
-- REM #89 -- Collection Setup Parameters for Signal-processed Frequency/Order
-- REM        Single Amplitude/Vector Data Table
-- REM
-- REM This table stores the setup parameters used to capture frequency/order
-- REM single amplitudes (or vectors) for a given database.  These setup id's
-- REM can then be referenced in the MLOC_ULIST_SP_AMPL table to associate the 
-- REM ordered list's measurement location unit with the signal processing 
-- REM parameters needed to capture the unit in a specified manner.
-- REM
-- REM
CREATE TABLE sp_ampl_setup (
 spa_setup_db_site   INTEGER      NOT NULL,
 spa_setup_db_id     INTEGER      NOT NULL,
 spa_setup_id        INTEGER      NOT NULL,
 pst_sc_db_site      INTEGER      NOT NULL,
 pst_sc_db_id        INTEGER      NOT NULL,
 pst_sc_type_code    INTEGER      NOT NULL,
 freq_or_order       CHAR(1)      NOT NULL,
 min_in_hz_or_ord    FLOAT        NOT NULL,
 max_in_hz_or_ord    FLOAT        NOT NULL,
 src_dt_db_site      INTEGER,
 src_dt_db_id        INTEGER,
 src_dt_type_code    INTEGER,
 sp_str_db_site      INTEGER,
 sp_str_db_id        INTEGER,
 sp_stream_id        INTEGER,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (spa_setup_db_site, spa_setup_db_id, spa_setup_id),
    FOREIGN KEY (spa_setup_db_site, spa_setup_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code) REFERENCES post_scaling_type (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code),
    FOREIGN KEY (src_dt_db_site, src_dt_db_id, src_dt_type_code) REFERENCES src_detect_type (src_dt_db_site, src_dt_db_id, src_dt_type_code),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id) REFERENCES sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY(last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (freq_or_order in ('F','O'))
 );
GO
-- REM #90 -- Collection Setup Parameters for Signal-processed Real/Complex 
-- REM        Linear Frequency/Order FFT Spectrum Data Table
-- REM
-- REM This table stores the setup parameters used to capture real/complex
-- REM linear frequency/order FFT spectrum data for a given database.  These 
-- REM setup id's can then be referenced in the MLOC_ULIST_SP_FFT table 
-- REM to associate the ordered list's measurement location unit with the 
-- REM signal processing parameters needed to capture the unit in a 
-- REM specified manner.
-- REM
-- REM
CREATE TABLE sp_fft_setup (
 spf_setup_db_site   INTEGER      NOT NULL,
 spf_setup_db_id     INTEGER      NOT NULL,
 spf_setup_id        INTEGER      NOT NULL,
 pst_sc_db_site      INTEGER      NOT NULL,
 pst_sc_db_id        INTEGER      NOT NULL,
 pst_sc_type_code    INTEGER      NOT NULL,
 freq_or_order       CHAR(1)      NOT NULL,
 min_in_hz_or_ord    FLOAT        NOT NULL,
 max_in_hz_or_ord    FLOAT        NOT NULL,
 resolution_lines    INTEGER      NOT NULL,
 win_db_site         INTEGER      NOT NULL,
 win_db_id           INTEGER      NOT NULL,
 win_type_code       INTEGER      NOT NULL,
 ave_db_site         INTEGER,
 ave_db_id           INTEGER,
 ave_type_code       INTEGER,
 ave_wt_db_site      INTEGER,
 ave_wt_db_id        INTEGER,
 ave_wt_type_code    INTEGER,
 ave_sy_db_site      INTEGER,
 ave_sy_db_id        INTEGER,
 ave_sy_type_code    INTEGER,
 ave_overlap_pct     FLOAT,
 num_of_averages     INTEGER,
 sp_str_db_site      INTEGER,
 sp_str_db_id        INTEGER,
 sp_stream_id        INTEGER,
 complex_yn          CHAR(1)      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (spf_setup_db_site, spf_setup_db_id, spf_setup_id),
    FOREIGN KEY (spf_setup_db_site, spf_setup_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code) REFERENCES post_scaling_type (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code),
    FOREIGN KEY (win_db_site, win_db_id, win_type_code) REFERENCES window_type (win_db_site, win_db_id, win_type_code),
    FOREIGN KEY (ave_db_site, ave_db_id, ave_type_code) REFERENCES average_type (ave_db_site, ave_db_id, ave_type_code),
    FOREIGN KEY (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code) REFERENCES ave_weight_type (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code),
    FOREIGN KEY (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code) REFERENCES ave_synch_type (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id) REFERENCES sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (freq_or_order in ('F','O')),
    CHECK (complex_yn in ('Y','N'))
 );
GO
-- REM #91 -- Collection Setup Parameters for Signal-processed Real/Complex 
-- REM        Linear Time Waveform Data Table
-- REM
-- REM This table stores the setup parameters used to capture real/complex
-- REM linear time waveform data for a given database.  These 
-- REM setup id's can then be referenced in the MLOC_ULIST_SP_TIME table 
-- REM to associate the ordered list's measurement location unit with the 
-- REM signal processing parameters needed to capture the unit in a 
-- REM specified manner.
-- REM
-- REM
CREATE TABLE sp_time_setup (
 spt_setup_db_site   INTEGER      NOT NULL,
 spt_setup_db_id     INTEGER      NOT NULL,
 spt_setup_id        INTEGER      NOT NULL,
 secs_or_revs        CHAR(1)      NOT NULL,
 off_secs_or_revs    FLOAT        NOT NULL,
 max_secs_or_revs    FLOAT        NOT NULL,
 number_of_samples   FLOAT        NOT NULL,
 win_db_site         INTEGER      NOT NULL,
 win_db_id           INTEGER      NOT NULL,
 win_type_code       INTEGER      NOT NULL,
 ave_db_site         INTEGER,
 ave_db_id           INTEGER,
 ave_type_code       INTEGER,
 ave_wt_db_site      INTEGER,
 ave_wt_db_id        INTEGER,
 ave_wt_type_code    INTEGER,
 ave_sy_db_site      INTEGER,
 ave_sy_db_id        INTEGER,
 ave_sy_type_code    INTEGER,
 ave_overlap_pct     FLOAT,
 num_of_averages     INTEGER,
 sp_str_db_site      INTEGER,
 sp_str_db_id        INTEGER,
 sp_stream_id        INTEGER,
 complex_yn          CHAR(1)      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (spt_setup_db_site, spt_setup_db_id, spt_setup_id),
    FOREIGN KEY (spt_setup_db_site, spt_setup_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (win_db_site, win_db_id, win_type_code) REFERENCES window_type (win_db_site, win_db_id, win_type_code),
    FOREIGN KEY (ave_db_site, ave_db_id, ave_type_code) REFERENCES average_type (ave_db_site, ave_db_id, ave_type_code),
    FOREIGN KEY (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code) REFERENCES ave_weight_type (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code),
    FOREIGN KEY (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code) REFERENCES ave_synch_type (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id) REFERENCES sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY  (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (secs_or_revs in ('S','R')),
    CHECK (complex_yn in ('Y','N'))
 );
GO
-- REM #92 -- Collection Setup Parameters for Signal-processed Real Linear 
-- REM        Constant Percentage Band Data Table
-- REM
-- REM This table stores the setup parameters used to capture real CPB
-- REM spectrum data for a given database.  These setup id's can then be 
-- REM referenced in the MLOC_ULIST_SP_CPB table to associate the ordered 
-- REM list's measurement location unit with the  signal processing 
-- REM parameters needed to capture the unit in a specified manner.
-- REM
-- REM
CREATE TABLE sp_cpb_setup (
 spc_setup_db_site   INTEGER      NOT NULL,
 spc_setup_db_id     INTEGER      NOT NULL,
 spc_setup_id        INTEGER      NOT NULL,
 pst_sc_db_site      INTEGER      NOT NULL,
 pst_sc_db_id        INTEGER      NOT NULL,
 pst_sc_type_code    INTEGER      NOT NULL,
 number_of_bands     INTEGER      NOT NULL,
 center_in_hz_1bd    FLOAT        NOT NULL,
 width_pct_or_oct    CHAR(1)      NOT NULL,
 band_width          FLOAT        NOT NULL,
 ave_db_site         INTEGER,
 ave_db_id           INTEGER,
 ave_type_code       INTEGER,
 ave_wt_db_site      INTEGER,
 ave_wt_db_id        INTEGER,
 ave_wt_type_code    INTEGER,
 ave_sy_db_site      INTEGER,
 ave_sy_db_id        INTEGER,
 ave_sy_type_code    INTEGER,
 ave_overlap_pct     FLOAT,
 num_of_averages     INTEGER,
 sp_str_db_site      INTEGER,
 sp_str_db_id        INTEGER,
 sp_stream_id        INTEGER,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (spc_setup_db_site, spc_setup_db_id, spc_setup_id),
    FOREIGN KEY (spc_setup_db_site, spc_setup_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code) REFERENCES post_scaling_type (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code),
    FOREIGN KEY (ave_db_site, ave_db_id, ave_type_code) REFERENCES average_type (ave_db_site, ave_db_id, ave_type_code),
    FOREIGN KEY (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code) REFERENCES ave_weight_type (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code),
    FOREIGN KEY (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code) REFERENCES ave_synch_type (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id) REFERENCES sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (width_pct_or_oct in ('P','O'))
 );
GO
-- REM #93 -- Collection Setup Parameters Needed to Collect Amplitude Data 
-- REM        in the Ordered List of Eng. Units at Measurement Locations Table
-- REM
-- REM This table stores the associated collection setup parameter to be used
-- REM to capture amplitude data for the engineering unit referenced in the 
-- REM ordered list measurement location unit table. 
-- REM
-- REM
CREATE TABLE mloc_ulist_sp_ampl (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 channel_number      INTEGER      NOT NULL,
 spa_setup_db_site   INTEGER      NOT NULL,
 spa_setup_db_id     INTEGER      NOT NULL,
 spa_setup_id        INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq, channel_number, spa_setup_db_site, spa_setup_db_id, spa_setup_id),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq, channel_number) REFERENCES mloc_unit_list (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq, channel_number),
    FOREIGN KEY (spa_setup_db_site, spa_setup_db_id, spa_setup_id) REFERENCES sp_ampl_setup (spa_setup_db_site, spa_setup_db_id, spa_setup_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #94 -- Collection Setup Parameters Needed to Collect FFT Spectrum Data 
-- REM        in the Ordered List of Eng. Units at Measurement Locations Table
-- REM
-- REM This table stores the associated collection setup parameter to be used
-- REM to capture FFT spectrum data for the engineering unit referenced in the 
-- REM ordered list measurement location unit table. 
-- REM
-- REM
CREATE TABLE mloc_ulist_sp_fft (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 channel_number      INTEGER      NOT NULL,
 spf_setup_db_site   INTEGER      NOT NULL,
 spf_setup_db_id     INTEGER      NOT NULL,
 spf_setup_id        INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq, channel_number, spf_setup_db_site, spf_setup_db_id, spf_setup_id),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq, channel_number) REFERENCES mloc_unit_list (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq, channel_number),
    FOREIGN KEY (spf_setup_db_site, spf_setup_db_id, spf_setup_id) REFERENCES sp_fft_setup (spf_setup_db_site, spf_setup_db_id, spf_setup_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #95 -- Collection Setup Parameters Needed to Collect Time Waveform Data 
-- REM        in the Ordered List of Eng. Units at Measurement Locations Table
-- REM
-- REM This table stores the associated collection setup parameter to be used
-- REM to capture time waveform data for the engineering unit referenced in the 
-- REM ordered list measurement location unit table. 
-- REM
-- REM
CREATE TABLE mloc_ulist_sp_time (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 channel_number      INTEGER      NOT NULL,
 spt_setup_db_site   INTEGER      NOT NULL,
 spt_setup_db_id     INTEGER      NOT NULL,
 spt_setup_id        INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq, channel_number, spt_setup_db_site, spt_setup_db_id, spt_setup_id),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq, channel_number) REFERENCES mloc_unit_list (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq, channel_number),
    FOREIGN KEY (spt_setup_db_site, spt_setup_db_id, spt_setup_id) REFERENCES sp_time_setup (spt_setup_db_site, spt_setup_db_id, spt_setup_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #96 -- Collection Setup Parameters Needed to Collect CPB Spectrum Data 
-- REM        in the Ordered List of Eng. Units at Measurement Locations Table
-- REM
-- REM This table stores the associated collection setup parameter to be used
-- REM to capture CPB spectrum data for the engineering unit referenced in the 
-- REM ordered list measurement location unit table. 
-- REM
-- REM
CREATE TABLE mloc_ulist_sp_cpb (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 channel_number      INTEGER      NOT NULL,
 spc_setup_db_site   INTEGER      NOT NULL,
 spc_setup_db_id     INTEGER      NOT NULL,
 spc_setup_id        INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq, channel_number, spc_setup_db_site, spc_setup_db_id, spc_setup_id),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq, channel_number) REFERENCES mloc_unit_list (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq, channel_number),
    FOREIGN KEY (spc_setup_db_site, spc_setup_db_id, spc_setup_id) REFERENCES sp_cpb_setup (spc_setup_db_site, spc_setup_db_id, spc_setup_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

GO
-- REM #215 -- mim_tech_type
-- REM
-- REM Types of MIMOSA Technology
-- REM
CREATE TABLE mim_tech_type (
 tech_type_code      INTEGER      NOT NULL,
 abbrev              VARCHAR(40),
 name		         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (tech_type_code),
    FOREIGN KEY  (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #216 -- mim_support_type
-- REM
-- REM MIMOSA Support Levels
-- REM
CREATE TABLE mim_support_type (
 supp_type_code      INTEGER      NOT NULL,
 abbrev              VARCHAR(40),
 name		         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (supp_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #217 -- mim_data_cat_type
-- REM
-- REM MIMOSA Data Categories
-- REM
CREATE TABLE mim_data_cat_type (
 dcat_type_code      INTEGER      NOT NULL,
 abbrev              VARCHAR(10),
 name		         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (dcat_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #326 -- mim_func_type
-- REM
-- REM MIMOSA Functionality Type
-- REM
CREATE TABLE mim_func_type (
 func_type_code      INTEGER      NOT NULL,
 name		         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (func_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #327 -- mim_interface_type
-- REM
-- REM MIMOSA Interface Type
-- REM
-- REM NOTE: subversion_supp: Subversion supported

CREATE TABLE mim_interface_type (
 interf_type_code    INTEGER      NOT NULL,
 dcat_type_code      INTEGER      NOT NULL,
 supp_type_code      INTEGER      NOT NULL,
 func_type_code      INTEGER      NOT NULL,
 tech_type_code      INTEGER      NOT NULL,
 version_supported   SMALLINT     NOT NULL,
 subversion_supp     SMALLINT     NOT NULL,
 name		     VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (interf_type_code),
    FOREIGN KEY (dcat_type_code) REFERENCES mim_data_cat_type(dcat_type_code),
    FOREIGN KEY (supp_type_code) REFERENCES mim_support_type(supp_type_code),
    FOREIGN KEY (func_type_code) REFERENCES mim_func_type(func_type_code),
    FOREIGN KEY (tech_type_code) REFERENCES mim_tech_type(tech_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #283 -- network_type
-- REM
-- REM Network Type
-- REM
CREATE TABLE network_type (
 nt_db_site     INTEGER      NOT NULL,
 nt_db_id       INTEGER      NOT NULL,
 nt_type_code   INTEGER      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (nt_db_site, nt_db_id, nt_type_code),
    FOREIGN KEY (nt_db_site, nt_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #121 -- event_type_child
-- REM
-- REM Segment,Asset Logged Operating Events , Failure Modes , Failure Effects , Failure Mechanisms , Defect Events ,  Abnormal Situations , Alarm Events  Parent,Child Types
-- REM
CREATE TABLE event_type_child (
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 child_ev_db_site    INTEGER      NOT NULL,
 child_ev_db_id      INTEGER      NOT NULL,
 child_ev_type_code  INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ev_db_site, ev_db_id, event_type_code, child_ev_db_site, child_ev_db_id, child_ev_type_code),
    FOREIGN KEY (ev_db_site, ev_db_id, event_type_code) REFERENCES sg_as_event_type(ev_db_site, ev_db_id, event_type_code),
    FOREIGN KEY (child_ev_db_site, child_ev_db_id, child_ev_type_code) REFERENCES sg_as_event_type(ev_db_site, ev_db_id, event_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #160 -- sample_test_type
-- REM
-- REM Types of Oil,Water,Fluid,Air,Gas,Solid Sample Tests
-- REM
CREATE TABLE sample_test_type (
 stt_db_site         INTEGER      NOT NULL,
 stt_db_id           INTEGER      NOT NULL,
 stt_code            INTEGER      NOT NULL,
 abbrev              VARCHAR(254),
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (stt_db_site, stt_db_id, stt_code),
    FOREIGN KEY (stt_db_site, stt_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #212 -- sample_ndata_type
-- REM
-- REM Sample Numeric Data Type
-- REM
CREATE TABLE sample_ndata_type (
 snum_db_site        INTEGER      NOT NULL,
 snum_db_id          INTEGER      NOT NULL,
 snum_type_code      INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (snum_db_site, snum_db_id, snum_type_code),
    FOREIGN KEY (snum_db_site, snum_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #290 -- sample_cdata_type
-- REM
-- REM Sample Character Data Type
-- REM
CREATE TABLE sample_cdata_type (
 schr_db_site        INTEGER      NOT NULL,
 schr_db_id          INTEGER      NOT NULL,
 schr_type_code      INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (schr_db_site, schr_db_id, schr_type_code),
    FOREIGN KEY (schr_db_site, schr_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #161 -- test_result_ntype
-- REM
-- REM Oil,Water,Fluid,Air,Gas,Solid,Electrical Test Results Numeric Data Type
-- REM
CREATE TABLE test_result_ntype (
 strn_db_site        INTEGER      NOT NULL,
 strn_db_id          INTEGER      NOT NULL,
 str_num_type_code   INTEGER      NOT NULL,
 abbrev              VARCHAR(254),
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (strn_db_site, strn_db_id, str_num_type_code),
    FOREIGN KEY (strn_db_site, strn_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #286 -- test_result_ctype
-- REM
-- REM Oil,Water,Fluid,Air,Gas,Solid,Electrical Test Results Char Data Type
-- REM
CREATE TABLE test_result_ctype (
 strc_db_site        INTEGER      NOT NULL,
 strc_db_id          INTEGER      NOT NULL,
 str_chr_type_code   INTEGER      NOT NULL,
 abbrev              VARCHAR(254),
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (strc_db_site, strc_db_id, str_chr_type_code),
    FOREIGN KEY (strc_db_site, strc_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #167 -- test_result_btype
-- REM
-- REM Oil,Water,Fluid,Air,Gas,Solid Test Results Binary Large Object Data Type
-- REM
CREATE TABLE test_result_btype (
 strb_db_site        INTEGER      NOT NULL,
 strb_db_id          INTEGER      NOT NULL,
 str_blob_type_code  INTEGER      NOT NULL,
 abbrev              VARCHAR(254),
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (strb_db_site, strb_db_id, str_blob_type_code),
    FOREIGN KEY (strb_db_site, strb_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #162 -- blob_data_type
-- REM
-- REM Binary Large Object such as a Bitmapped Drawing or Image, Ferrographic Image, Thermographic Image, Digitized Video Clip, Document, etc.
-- REM
CREATE TABLE blob_data_type (
 bd_db_site          INTEGER      NOT NULL,
 bd_db_id            INTEGER      NOT NULL,
 bd_type_code        INTEGER      NOT NULL,
 abbrev              VARCHAR(254),
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (bd_db_site, bd_db_id, bd_type_code),
    FOREIGN KEY (bd_db_site, bd_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #333 -- Blob Content Type Table
-- REM
-- REM This table stores the content type of Binary Large object Data for
-- REM Segments, Assets, Models and Ordered Lists.
-- REM
-- REM   NOTE: MIMOSA Populates and maintains the sg_db_site Zero (0)
-- REM         entries in this Table
-- REM
-- REM
CREATE TABLE blob_content_type (
 blct_db_site        INTEGER      NOT NULL,
 blct_db_id          INTEGER      NOT NULL,
 blc_type_code       INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 default_mnemonic    CHAR(3),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (blct_db_site, blct_db_id, blc_type_code),
    FOREIGN KEY (blct_db_site, blct_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #291 -- mevent_blob_type
-- REM
-- REM Measurement Event Binary Large Object Type
-- REM
CREATE TABLE mevent_blob_type (
 mebt_db_site        INTEGER      NOT NULL,
 mebt_db_id          INTEGER      NOT NULL,
 meb_type_code       INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (mebt_db_site, mebt_db_id, meb_type_code),
    FOREIGN KEY (mebt_db_site, mebt_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #292 -- highlight_type
-- REM
-- REM Highlight Area Type for Drawing Attention to Certain Locations, now used for BLOB Areas
-- REM
CREATE TABLE highlight_type (
 high_db_site        INTEGER      NOT NULL,
 high_db_id          INTEGER      NOT NULL,
 high_type_code      INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (high_db_site, high_db_id, high_type_code),
    FOREIGN KEY (high_db_site, high_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #110 -- agent_role_type
-- REM
-- REM Manager, Owner, Employer, Buyer, Operator
-- REM
CREATE TABLE agent_role_type (
 ag_role_db_site     INTEGER      NOT NULL,
 ag_role_db_id       INTEGER      NOT NULL,
 ag_role_type_code   INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ag_role_db_site, ag_role_db_id, ag_role_type_code),
    FOREIGN KEY (ag_role_db_site, ag_role_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #107 -- ev_num_data_type
-- REM
-- REM Segment,Asset Event Numeric Data Type
-- REM
CREATE TABLE ev_num_data_type (
 en_db_site          INTEGER      NOT NULL,
 en_db_id            INTEGER      NOT NULL,
 en_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (en_db_site, en_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #103 -- severity_type
-- REM
-- REM Severity Types
-- REM
CREATE TABLE severity_type (
 severity_rank       INTEGER      NOT NULL,
 name		         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (severity_rank),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #104 -- health_grade_type
-- REM
-- REM Health Grade Type
-- REM
CREATE TABLE health_grade_type (
 hgrade_type_code    INTEGER      NOT NULL,
 name		         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (hgrade_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #106 -- priority_type
-- REM
-- REM Levels of Priority for Recommendations , Work Requests
-- REM
CREATE TABLE priority_type (
 priority_type_code  INTEGER      NOT NULL,
 name		         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (priority_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #128 -- work_manage_type
-- REM
-- REM Types of Work Management Work Requests and Work Orders
-- REM
CREATE TABLE work_manage_type (
 wm_type_db_site     INTEGER      NOT NULL,
 wm_type_db_id       INTEGER      NOT NULL,
 wm_type_code        INTEGER      NOT NULL,
 name		         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (wm_type_db_site, wm_type_db_id, wm_type_code),
    FOREIGN KEY (wm_type_db_site, wm_type_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #108 -- work_task_type
-- REM
-- REM Types of Work Tasks,Steps,Actions,Activities
-- REM
CREATE TABLE work_task_type (
 task_db_site        INTEGER      NOT NULL,
 task_db_id          INTEGER      NOT NULL,
 task_type_code      INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (task_db_site, task_db_id, task_type_code),
    FOREIGN KEY (task_db_site, task_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #150 -- wtask_type_child
-- REM
-- REM Work Task Parent Child Taxonomy
-- REM
CREATE TABLE wtask_type_child (
 task_db_site        INTEGER      NOT NULL,
 task_db_id          INTEGER      NOT NULL,
 task_type_code      INTEGER      NOT NULL,
 child_tk_db_site    INTEGER      NOT NULL,
 child_tk_db_id      INTEGER      NOT NULL,
 child_tk_type_code  INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (task_db_site, task_db_id, task_type_code, child_tk_db_site, child_tk_db_id, child_tk_type_code),
    FOREIGN KEY (task_db_site, task_db_id, task_type_code) REFERENCES work_task_type(task_db_site, task_db_id, task_type_code),
    FOREIGN KEY (child_tk_db_site, child_tk_db_id, child_tk_type_code) REFERENCES work_task_type(task_db_site, task_db_id, task_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #151 -- change_patt_type
-- REM
-- REM Type of change pattern observed in problems
-- REM
CREATE TABLE change_patt_type (
 ch_patt_db_site     INTEGER      NOT NULL,
 ch_patt_db_id       INTEGER      NOT NULL,
 ch_patt_type_code   INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ch_patt_db_site, ch_patt_db_id, ch_patt_type_code),
    FOREIGN KEY (ch_patt_db_site, ch_patt_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #119 -- work_audit_type
-- REM
-- REM Work Request,Order,Order Steps Audit Types
-- REM
CREATE TABLE work_audit_type (
 waudit_db_site      INTEGER      NOT NULL,
 waudit_db_id        INTEGER      NOT NULL,
 waudit_type_code    INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (waudit_db_site, waudit_db_id, waudit_type_code),
    FOREIGN KEY (waudit_db_site, waudit_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #170 -- work_num_data_type
-- REM
-- REM Work Request,Work Order,Work Order Steps Numeric Data Type
-- REM
CREATE TABLE work_num_data_type (
 wn_db_site          INTEGER      NOT NULL,
 wn_db_id            INTEGER      NOT NULL,
 wn_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (wn_db_site, wn_db_id, wn_type_code),
    FOREIGN KEY (wn_db_site, wn_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #171 -- work_chr_data_type
-- REM
-- REM Work Request,Work Order,Work Order Steps Char. Data Type
-- REM
CREATE TABLE work_chr_data_type (
 wc_db_site          INTEGER      NOT NULL,
 wc_db_id            INTEGER      NOT NULL,
 wc_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (wc_db_site, wc_db_id, wc_type_code),
    FOREIGN KEY (wc_db_site, wc_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #182 -- solution_pack_type
-- REM
-- REM Solution Package Type
-- REM
CREATE TABLE solution_pack_type (
 sol_db_site         INTEGER      NOT NULL,
 sol_db_id           INTEGER      NOT NULL,
 sol_type_code       INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sol_db_site, sol_db_id, sol_type_code),
    FOREIGN KEY (sol_db_site, sol_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #284 -- network
-- REM
-- REM 
-- REM
CREATE TABLE network (
 network_db_site     INTEGER      NOT NULL,
 network_db_id       INTEGER      NOT NULL,
 network_id          INTEGER      NOT NULL,
 nt_db_site          INTEGER      NOT NULL,
 nt_db_id            INTEGER      NOT NULL,
 nt_type_code        INTEGER      NOT NULL,
 user_tag_ident      INTEGER      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (network_db_site, network_db_id, network_id),
    FOREIGN KEY (network_db_site, network_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (nt_db_site, nt_db_id, nt_type_code) REFERENCES network_type(nt_db_site, nt_db_id, nt_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #308 -- sg_network_connect
-- REM
-- REM 
-- REM
CREATE TABLE sg_network_connect (
 network_db_site     INTEGER      NOT NULL,
 network_db_id       INTEGER      NOT NULL,
 network_id          INTEGER      NOT NULL,
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 output_sg_site      INTEGER      NOT NULL,
 output_sg_id        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 gmt_stream_config   VARCHAR(29),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (network_db_site, network_db_id, network_id, segment_site, segment_id, output_sg_site, output_sg_id, ordering_seq),
    FOREIGN KEY (network_db_site, network_db_id, network_id) REFERENCES network(network_db_site, network_db_id, network_id),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment(segment_site, segment_id),
    FOREIGN KEY (output_sg_site, output_sg_id) REFERENCES segment(segment_site, segment_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #309 -- as_network_connect
-- REM
-- REM 
-- REM
CREATE TABLE as_network_connect (
 network_db_site     INTEGER      NOT NULL,
 network_db_id       INTEGER      NOT NULL,
 network_id          INTEGER      NOT NULL,
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 output_as_site      INTEGER      NOT NULL,
 output_as_id        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 gmt_stream_config   VARCHAR(29),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (network_db_site, network_db_id, network_id, asset_org_site, asset_id, output_as_site, output_as_id, ordering_seq),
    FOREIGN KEY (network_db_site, network_db_id, network_id) REFERENCES network(network_db_site, network_db_id, network_id),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset(asset_org_site, asset_id),
    FOREIGN KEY (output_as_site, output_as_id) REFERENCES asset(asset_org_site, asset_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #118 -- agent_role
-- REM
-- REM Agent Roles
-- REM
CREATE TABLE agent_role (
 org_agent_site      INTEGER      NOT NULL,
 agent_id            INTEGER      NOT NULL,
 ag_role_db_site     INTEGER      NOT NULL,
 ag_role_db_id       INTEGER      NOT NULL,
 ag_role_type_code   INTEGER      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (org_agent_site, agent_id, ag_role_db_site, ag_role_db_id, ag_role_type_code),
    FOREIGN KEY (org_agent_site, agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (ag_role_db_site, ag_role_db_id, ag_role_type_code) REFERENCES agent_role_type(ag_role_db_site, ag_role_db_id, ag_role_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #223 -- agent_role_with_agent
-- REM
-- REM Agent in Defined Role With Associated Agent
-- REM
-- REM NOTE: org_agent_site, agent_id ,ag_role_db_site, ag_role_db_id, ag_role_db_id: Manager Of, Owner Of, 
-- REM       Employer Of, Buyer From, etc.
-- REM NOTE: other_org_agent_site, other_agent_id: Associated Agent
-- REM
CREATE TABLE agent_role_with_agent (
 org_agent_site      INTEGER      NOT NULL,
 agent_id            INTEGER      NOT NULL,
 ag_role_db_site     INTEGER      NOT NULL,
 ag_role_db_id       INTEGER      NOT NULL,
 ag_role_type_code   INTEGER      NOT NULL,
 other_org_agent_site INTEGER      NOT NULL,
 other_agent_id      INTEGER      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (org_agent_site, agent_id, ag_role_db_site, ag_role_db_id, ag_role_type_code, other_org_agent_site, other_agent_id),
    FOREIGN KEY (ag_role_db_site, ag_role_db_id, ag_role_type_code) REFERENCES agent_role_type(ag_role_db_site, ag_role_db_id, ag_role_type_code),
    FOREIGN KEY (other_org_agent_site, other_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #310 -- mloc_test_alrm_rg
-- REM
-- REM Alarm Regions for Measurement Location Sample Test Numeric Results
-- REM
CREATE TABLE mloc_test_alrm_rg (
 alarm_db_site       INTEGER      NOT NULL,
 alarm_db_id         INTEGER      NOT NULL,
 meas_loc_site       INTEGER      NOT NULL, 
 meas_loc_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 ml_db_site          INTEGER      NOT NULL, 
 ml_db_id            INTEGER      NOT NULL, 
 ml_type_code        INTEGER      NOT NULL, 
 mc_db_site          INTEGER      NOT NULL, 
 mc_db_id            INTEGER      NOT NULL, 
 mc_type_code        INTEGER      NOT NULL, 
 stt_db_site         INTEGER      NOT NULL,
 stt_db_id           INTEGER      NOT NULL,
 stt_code            INTEGER      NOT NULL,
 al_db_site          INTEGER      NOT NULL,
 al_db_id            INTEGER      NOT NULL,
 al_type_code        INTEGER      NOT NULL,
 strn_db_site        INTEGER      NOT NULL,
 strn_db_id          INTEGER      NOT NULL,
 str_num_type_code   INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 gmt_alarm_start     VARCHAR(29)  NOT NULL,
 st_loc_hr_delta     SMALLINT,
 st_loc_min_delta    SMALLINT,
 min_data_value      FLOAT        NOT NULL,
 max_data_value      FLOAT        NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (alarm_db_site, alarm_db_id, meas_loc_site, meas_loc_id, ordering_seq),
    FOREIGN KEY (alarm_db_site, alarm_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (meas_loc_site, meas_loc_id) REFERENCES meas_location (meas_loc_site, meas_loc_id),
    FOREIGN KEY (ml_db_site, ml_db_id, ml_type_code) REFERENCES meas_loc_type (ml_db_site, ml_db_id, ml_type_code),
    FOREIGN KEY (mc_db_site, mc_db_id, mc_type_code) REFERENCES mloc_calc_type (mc_db_site, mc_db_id, mc_type_code),
    FOREIGN KEY (stt_db_site, stt_db_id, stt_code) REFERENCES sample_test_type(stt_db_site, stt_db_id, stt_code),
    FOREIGN KEY (al_db_site, al_db_id, al_type_code) REFERENCES alarm_type(al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (strn_db_site, strn_db_id, str_num_type_code) REFERENCES test_result_ntype(strn_db_site, strn_db_id, str_num_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #166 -- meas_sample
-- REM
-- REM Measurement Sample
-- REM
-- REM NOTE: user_tag_ident - Alpha-numeric Sample Number
-- REM
CREATE TABLE meas_sample (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 sample_order_seq    INTEGER      NOT NULL,
 user_tag_ident      VARCHAR(254) NOT NULL,
 by_agent_site       INTEGER,
 by_agent_id         INTEGER,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES meas_event(meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #163 -- meas_sample_child
-- REM
-- REM Measurement Sample Master To Subsequent Child Sub-Samples
-- REM
CREATE TABLE meas_sample_child (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 sample_order_seq    INTEGER      NOT NULL,
 child_mloc_site     INTEGER      NOT NULL,
 child_mloc_id       INTEGER      NOT NULL,
 child_gmt_event     VARCHAR(29)  NOT NULL,
 child_sam_ord_seq   INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, child_mloc_site, child_mloc_id, child_gmt_event, child_sam_ord_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq) REFERENCES meas_sample(meas_loc_site, meas_loc_id, gmt_event, sample_order_seq),
    FOREIGN KEY (child_mloc_site, child_mloc_id, child_gmt_event, child_sam_ord_seq) REFERENCES meas_sample(meas_loc_site, meas_loc_id, gmt_event, sample_order_seq),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #213 -- sample_num_data
-- REM
-- REM Measurement Sample Numeric Data
-- REM
CREATE TABLE sample_num_data (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 sample_order_seq    INTEGER      NOT NULL,
 snum_db_site        INTEGER      NOT NULL,
 snum_db_id          INTEGER      NOT NULL,
 snum_type_code      INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          FLOAT       NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, snum_db_site, snum_db_id, snum_type_code),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq) REFERENCES meas_sample(meas_loc_site, meas_loc_id, gmt_event, sample_order_seq),
    FOREIGN KEY (snum_db_site, snum_db_id, snum_type_code) REFERENCES sample_ndata_type(snum_db_site, snum_db_id, snum_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #288 -- sample_chr_data
-- REM
-- REM Measurement Sample Character Data
-- REM
CREATE TABLE sample_chr_data (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 sample_order_seq    INTEGER      NOT NULL,
 schr_db_site        INTEGER      NOT NULL,
 schr_db_id          INTEGER      NOT NULL,
 schr_type_code      INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, schr_db_site, schr_db_id, schr_type_code),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq) REFERENCES meas_sample(meas_loc_site, meas_loc_id, gmt_event, sample_order_seq),
    FOREIGN KEY (schr_db_site, schr_db_id, schr_type_code) REFERENCES sample_cdata_type(schr_db_site, schr_db_id, schr_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #289 -- sample_remark
-- REM
-- REM Measurement Sample Remark
-- REM
CREATE TABLE sample_remark (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 sample_order_seq    INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 remark_text         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq) REFERENCES meas_sample(meas_loc_site, meas_loc_id, gmt_event, sample_order_seq),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #122 -- meas_sample_test
-- REM
-- REM Measurement Sample Test
-- REM
CREATE TABLE meas_sample_test (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 sample_order_seq    INTEGER      NOT NULL,
 test_order_seq      INTEGER      NOT NULL,
 stt_db_site         INTEGER      NOT NULL,
 stt_db_id           INTEGER      NOT NULL,
 stt_code            INTEGER      NOT NULL,
 user_tag_ident      VARCHAR(254) NOT NULL,
 name                VARCHAR(254),
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 test_asset_site     INTEGER,
 test_asset_id       INTEGER,
 gmt_started         VARCHAR(29),
 st_loc_hr_delta     SMALLINT,
 st_loc_min_delta    SMALLINT,
 gmt_ended           VARCHAR(29),
 end_loc_hr_delta    SMALLINT,
 end_loc_min_delta   SMALLINT,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq) REFERENCES meas_sample(meas_loc_site, meas_loc_id, gmt_event, sample_order_seq),
    FOREIGN KEY (stt_db_site, stt_db_id, stt_code) REFERENCES sample_test_type(stt_db_site, stt_db_id, stt_code),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (test_asset_site, test_asset_id) REFERENCES asset(asset_org_site, asset_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #164 -- test_num_results
-- REM
-- REM Measurement Sample Test Numeric Results
-- REM
CREATE TABLE test_num_results (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 sample_order_seq    INTEGER      NOT NULL,
 test_order_seq      INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 strn_db_site        INTEGER      NOT NULL,
 strn_db_id          INTEGER      NOT NULL,
 str_num_type_code   INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 real_data_value     FLOAT        NOT NULL,
 imag_data_value     FLOAT,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq, ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq) REFERENCES meas_sample_test(meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq),
    FOREIGN KEY (strn_db_site, strn_db_id, str_num_type_code) REFERENCES test_result_ntype(strn_db_site, strn_db_id, str_num_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #285 -- test_chr_results
-- REM
-- REM Measurement Sample Test Character Results
-- REM
CREATE TABLE test_chr_results (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 sample_order_seq    INTEGER      NOT NULL,
 test_order_seq      INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 strc_db_site        INTEGER      NOT NULL,
 strc_db_id          INTEGER      NOT NULL,
 str_chr_type_code   INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq, ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq) REFERENCES meas_sample_test(meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq),
    FOREIGN KEY (strc_db_site, strc_db_id, str_chr_type_code) REFERENCES test_result_ctype(strc_db_site, strc_db_id, str_chr_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #287 -- test_remark
-- REM
-- REM Measurement Sample Test Remark
-- REM
CREATE TABLE test_remark (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 sample_order_seq    INTEGER      NOT NULL,
 test_order_seq      INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 remark_text         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq, ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq) REFERENCES meas_sample_test(meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #214 -- test_histogram
-- REM
-- REM Measurement Sample Test Histogram NOTE: The constant screen width = [max_screen_in_eu - min_screen_in_eu] , resolution_lines.  The screen size of the first histogram value in histogram_data = min_screen_in_eu  + constant screen width. Histogram_data is a variable-length binary field, containing 4-byte IEEE float real values for each line of resolution in the histogram.
-- REM
-- REM NOTE: The constant screen width = (max_screen_in_eu - min_screen_in_eu) 
-- REM       resolution_lines.  The screen size of the first histogram value in 
-- REM       histogram_data = min_screen_in_eu  + constant screen width.
-- REM       Histogram_data is a variable-length binary field, containing 4-byte IEEE 
-- REM       float real values for each line of resolution in the histogram.
-- REM
CREATE TABLE test_histogram (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 sample_order_seq    INTEGER      NOT NULL,
 test_order_seq      INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 strn_db_site        INTEGER      NOT NULL,
 strn_db_id          INTEGER      NOT NULL,
 str_num_type_code   INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 min_screen_in_eu    INTEGER      NOT NULL,
 max_screen_in_eu    INTEGER      NOT NULL,
 resolution_lines    INTEGER      NOT NULL,
 name                VARCHAR(254),
 histogram_data      IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq, ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq) REFERENCES meas_sample_test(meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq),
    FOREIGN KEY (strn_db_site, strn_db_id, str_num_type_code) REFERENCES test_result_ntype(strn_db_site, strn_db_id, str_num_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #191 -- test_nres_alarm
-- REM
-- REM Measurement Sample Test Numeric Result Alarms
-- REM
-- REM org_agent_site, agent_id - Agent which acknowleged the alarm
-- REM
CREATE TABLE test_nres_alarm (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 sample_order_seq    INTEGER      NOT NULL,
 test_order_seq      INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 al_db_site          INTEGER      NOT NULL,
 al_db_id            INTEGER      NOT NULL,
 al_type_code        INTEGER      NOT NULL,
 gmt_acknowledged    VARCHAR(29),
 ack_loc_hr_delta    SMALLINT, 
 ack_loc_min_delta   SMALLINT, 
 org_agent_site      INTEGER, 
 agent_id            INTEGER, 
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq, ordering_seq, al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq, ordering_seq) REFERENCES test_num_results(meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq, ordering_seq),
    FOREIGN KEY (al_db_site, al_db_id, al_type_code) REFERENCES alarm_type(al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (org_agent_site, agent_id) REFERENCES agent (org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #321 -- test_al_assoc_reg 
-- REM
-- REM Sample Test Alarm Associated Regions in Alarm
-- REM
CREATE TABLE test_al_assoc_reg (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL, 
 sample_order_seq    INTEGER      NOT NULL,
 test_order_seq      INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 al_db_site          INTEGER      NOT NULL, 
 al_db_id            INTEGER      NOT NULL,
 al_type_code        INTEGER      NOT NULL,
 alarm_db_site       INTEGER      NOT NULL,
 alarm_db_id         INTEGER      NOT NULL,
 al_meas_loc_site    INTEGER      NOT NULL, 
 al_meas_loc_id      INTEGER      NOT NULL,
 al_ordering_seq     INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq, ordering_seq, al_db_site, al_db_id, al_type_code, alarm_db_site, alarm_db_id, al_meas_loc_site, al_meas_loc_id, al_ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq, ordering_seq, al_db_site, al_db_id, al_type_code) REFERENCES test_nres_alarm (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq, ordering_seq, al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (alarm_db_site, alarm_db_id, al_meas_loc_site, al_meas_loc_id, al_ordering_seq) REFERENCES mloc_test_alrm_rg (alarm_db_site, alarm_db_id, meas_loc_site, meas_loc_id, ordering_seq),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #168 -- test_blob_results
-- REM
-- REM Measurement Sample Test Binary Results For Ferrography,Etc.
-- REM
CREATE TABLE test_blob_results (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 sample_order_seq    INTEGER      NOT NULL,
 test_order_seq      INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 strb_db_site        INTEGER      NOT NULL,
 strb_db_id          INTEGER      NOT NULL,
 str_blob_type_code  INTEGER      NOT NULL,
 bd_db_site          INTEGER      NOT NULL,
 bd_db_id            INTEGER      NOT NULL,
 bd_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254),
 assoc_file_name     VARCHAR(254),
 image_data          IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq, ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq) REFERENCES meas_sample_test(meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq),
    FOREIGN KEY (strb_db_site, strb_db_id, str_blob_type_code) REFERENCES test_result_btype(strb_db_site, strb_db_id, str_blob_type_code),
    FOREIGN KEY (bd_db_site, bd_db_id, bd_type_code) REFERENCES blob_data_type(bd_db_site, bd_db_id, bd_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

GO
-- REM #192 -- test_bres_alarm
-- REM
-- REM Measurement Sample Test BLOB Result Alarms
-- REM
-- REM org_agent_site, agent_id - Agent which acknowleged the alarm
-- REM
CREATE TABLE test_bres_alarm (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 sample_order_seq    INTEGER      NOT NULL,
 test_order_seq      INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 al_db_site          INTEGER      NOT NULL,
 al_db_id            INTEGER      NOT NULL,
 al_type_code        INTEGER      NOT NULL,
 gmt_acknowledged    VARCHAR(29)  NOT NULL,
 ack_loc_hr_delta    SMALLINT, 
 ack_loc_min_delta   SMALLINT, 
 org_agent_site      INTEGER,
 agent_id            INTEGER,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT, 
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq, ordering_seq, al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq, ordering_seq) REFERENCES test_blob_results (meas_loc_site, meas_loc_id, gmt_event, sample_order_seq, test_order_seq, ordering_seq),
    FOREIGN KEY (al_db_site, al_db_id, al_type_code) REFERENCES alarm_type(al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (org_agent_site, agent_id) REFERENCES agent (org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

-- REM ///////////////////////////////////////////////////////////////////////
-- REM
-- REM BLOB Drawing/Photographic/Thermographic Image/Document Tables
-- REM
-- REM ///////////////////////////////////////////////////////////////////////

GO
-- REM #224 -- sg_type_blob_data
-- REM
-- REM Segment Type Binary Data Related To a Specific Database
-- REM
CREATE TABLE sg_type_blob_data (
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 sg_db_site          INTEGER      NOT NULL,
 sg_db_id            INTEGER      NOT NULL,
 sg_type_code        INTEGER      NOT NULL,
 bd_db_site          INTEGER      NOT NULL,
 bd_db_id            INTEGER      NOT NULL,
 bd_type_code        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 blct_db_site        INTEGER      NOT NULL,
 blct_db_id          INTEGER      NOT NULL,
 blc_type_code       INTEGER      NOT NULL,
 name                VARCHAR(254),
 assoc_file_name     VARCHAR(254),
 image_data          IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (db_site, db_id, sg_db_site, sg_db_id, sg_type_code, bd_db_site, bd_db_id, bd_type_code, ordering_seq),
    FOREIGN KEY (db_site, db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (sg_db_site, sg_db_id, sg_type_code) REFERENCES segment_type(sg_db_site, sg_db_id, sg_type_code),
    FOREIGN KEY (bd_db_site, bd_db_id, bd_type_code) REFERENCES blob_data_type(bd_db_site, bd_db_id, bd_type_code),
    FOREIGN KEY (blct_db_site, blct_db_id, blc_type_code) REFERENCES blob_content_type(blct_db_site, blct_db_id, blc_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #188 -- segment_blob_data
-- REM
-- REM Segment Binary Data Related To a Specific Database
-- REM
CREATE TABLE segment_blob_data (
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 bd_db_site          INTEGER      NOT NULL,
 bd_db_id            INTEGER      NOT NULL,
 bd_type_code        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 blct_db_site        INTEGER      NOT NULL,
 blct_db_id          INTEGER      NOT NULL,
 blc_type_code       INTEGER      NOT NULL,
 name                VARCHAR(254),
 assoc_file_name     VARCHAR(254),
 image_data          IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (db_site, db_id, segment_site, segment_id, bd_db_site, bd_db_id, bd_type_code, ordering_seq),
    FOREIGN KEY (db_site, db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment(segment_site, segment_id),
    FOREIGN KEY (bd_db_site, bd_db_id, bd_type_code) REFERENCES blob_data_type(bd_db_site, bd_db_id, bd_type_code),
    FOREIGN KEY (blct_db_site, blct_db_id, blc_type_code) REFERENCES blob_content_type(blct_db_site, blct_db_id, blc_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #220 -- model_blob_data
-- REM
-- REM Model Binary Data Related to a Specific Database
-- REM
CREATE TABLE model_blob_data (
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 mf_db_site          INTEGER      NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 model_number        VARCHAR(254) NOT NULL,
 revision_number     INTEGER      NOT NULL,
 bd_db_site          INTEGER      NOT NULL,
 bd_db_id            INTEGER      NOT NULL,
 bd_type_code        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 blct_db_site        INTEGER      NOT NULL,
 blct_db_id          INTEGER      NOT NULL,
 blc_type_code       INTEGER      NOT NULL,
 name                VARCHAR(254),
 assoc_file_name     VARCHAR(254),
 image_data          IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (db_site, db_id, mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, bd_db_site, bd_db_id, bd_type_code, ordering_seq),
    FOREIGN KEY (db_site, db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number) REFERENCES model(mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number),
    FOREIGN KEY (bd_db_site, bd_db_id, bd_type_code) REFERENCES blob_data_type(bd_db_site, bd_db_id, bd_type_code),
    FOREIGN KEY (blct_db_site, blct_db_id, blc_type_code) REFERENCES blob_content_type(blct_db_site, blct_db_id, blc_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #225 -- as_type_blob_data
-- REM
-- REM Asset Type Binary Data Related to a Specific Database
-- REM
CREATE TABLE as_type_blob_data (
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 as_db_site          INTEGER      NOT NULL,
 as_db_id            INTEGER      NOT NULL,
 as_type_code        INTEGER      NOT NULL,
 bd_db_site          INTEGER      NOT NULL,
 bd_db_id            INTEGER      NOT NULL,
 bd_type_code        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 blct_db_site        INTEGER      NOT NULL,
 blct_db_id          INTEGER      NOT NULL,
 blc_type_code       INTEGER      NOT NULL,
 name                VARCHAR(254),
 assoc_file_name     VARCHAR(254),
 image_data          IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (db_site, db_id, as_db_site, as_db_id, as_type_code, bd_db_site, bd_db_id, bd_type_code, ordering_seq),
    FOREIGN KEY (db_site, db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (as_db_site, as_db_id, as_type_code) REFERENCES asset_type(as_db_site, as_db_id, as_type_code),
    FOREIGN KEY (bd_db_site, bd_db_id, bd_type_code) REFERENCES blob_data_type(bd_db_site, bd_db_id, bd_type_code),
    FOREIGN KEY (blct_db_site, blct_db_id, blc_type_code) REFERENCES blob_content_type(blct_db_site, blct_db_id, blc_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #189 -- asset_blob_data
-- REM
-- REM Asset Binary Data Related To a Specific Database
-- REM
CREATE TABLE asset_blob_data (
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 bd_db_site          INTEGER      NOT NULL,
 bd_db_id            INTEGER      NOT NULL,
 bd_type_code        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 blct_db_site        INTEGER      NOT NULL,
 blct_db_id          INTEGER      NOT NULL,
 blc_type_code       INTEGER      NOT NULL,
 name                VARCHAR(254),
 assoc_file_name     VARCHAR(254),
 image_data          IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (db_site, db_id, asset_org_site, asset_id, bd_db_site, bd_db_id, bd_type_code, ordering_seq),
    FOREIGN KEY (db_site, db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset(asset_org_site, asset_id),
    FOREIGN KEY (bd_db_site, bd_db_id, bd_type_code) REFERENCES blob_data_type(bd_db_site, bd_db_id, bd_type_code),
    FOREIGN KEY (blct_db_site, blct_db_id, blc_type_code) REFERENCES blob_content_type(blct_db_site, blct_db_id, blc_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #190 -- olist_blob_data
-- REM
-- REM Ordered List Binary Data Related to a Specific Database
-- REM
CREATE TABLE olist_blob_data (
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 bd_db_site          INTEGER      NOT NULL,
 bd_db_id            INTEGER      NOT NULL,
 bd_type_code        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 blct_db_site        INTEGER      NOT NULL,
 blct_db_id          INTEGER      NOT NULL,
 blc_type_code       INTEGER      NOT NULL,
 name                VARCHAR(254),
 assoc_file_name     VARCHAR(254),
 image_data          IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (db_site, db_id, ord_list_db_site, ord_list_db_id, ord_list_id, bd_db_site, bd_db_id, bd_type_code, ordering_seq),
    FOREIGN KEY (db_site, db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id) REFERENCES ordered_list(ord_list_db_site, ord_list_db_id, ord_list_id),
    FOREIGN KEY (bd_db_site, bd_db_id, bd_type_code) REFERENCES blob_data_type(bd_db_site, bd_db_id, bd_type_code),
    FOREIGN KEY (blct_db_site, blct_db_id, blc_type_code) REFERENCES blob_content_type(blct_db_site, blct_db_id, blc_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #165 -- mevent_blob_data
-- REM
-- REM Measurement Event Binary Data
-- REM
CREATE TABLE mevent_blob_data (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 mebt_db_site        INTEGER      NOT NULL,
 mebt_db_id          INTEGER      NOT NULL,
 meb_type_code       INTEGER      NOT NULL,
 bd_db_site          INTEGER      NOT NULL,
 bd_db_id            INTEGER      NOT NULL,
 bd_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254),
 assoc_file_name     VARCHAR(254),
 image_data          IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, mebt_db_site, mebt_db_id, meb_type_code),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES meas_event(meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (mebt_db_site, mebt_db_id, meb_type_code) REFERENCES mevent_blob_type(mebt_db_site, mebt_db_id, meb_type_code),
    FOREIGN KEY (bd_db_site, bd_db_id, bd_type_code) REFERENCES blob_data_type(bd_db_site, bd_db_id, bd_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #221 -- blob_grid_data
-- REM
-- REM A 2-D Linear Rectangular Grid of Numeric Data Associated With Measurement 
-- REM Event BLOB Data. - Used for Radiological Data in Thermography, Thickness 
-- REM Data in Ultrasonic Testing, etc.
-- REM
-- REM NOTE: x_resolution, y_resolution - Total dimensions of the rectangular 
-- REM       grid related to the BLOB image  (grid resolution)
-- REM
-- REM NOTE: data_origin_x, data_origin_y - X,Y coordinates of the origin of the 
-- REM       0-based rectangular grid for the  "data rectangle" (top left-most 
-- REM       corner)
-- REM
-- REM NOTE: data_end_x, data_end_y - X,Y coordinates of the end of the 0-based 
-- REM       rectangular grid for the "data rectangle" (lower right-most corner)
-- REM
-- REM NOTE: float_data - Stored as a stream of 4-byte IEEE float values
-- REM       (low-order byte first), starting with coordinates (data_origin_x, 
-- REM       data_origin_y) and progressing vertically  downward (increment y) 
-- REM       until data_end_y is exceeded, whereupon y is then set to 
-- REM       data_origin_y and x is incremented until (data_end_x, data_end_y) 
-- REM       is reached.
-- REM
CREATE TABLE blob_grid_data (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 mebt_db_site        INTEGER      NOT NULL,
 mebt_db_id          INTEGER      NOT NULL,
 meb_type_code       INTEGER      NOT NULL,
 grid_seq            INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 x_resolution        INTEGER      NOT NULL,
 y_resolution        INTEGER      NOT NULL,
 data_origin_x       INTEGER      NOT NULL,
 data_origin_y       INTEGER      NOT NULL,
 data_end_x          INTEGER      NOT NULL,
 data_end_y          INTEGER      NOT NULL,
 name                VARCHAR(254),
 float_data          IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, mebt_db_site, mebt_db_id, meb_type_code, grid_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, mebt_db_site, mebt_db_id, meb_type_code) REFERENCES mevent_blob_data(meas_loc_site, meas_loc_id, gmt_event, mebt_db_site, mebt_db_id, meb_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #120 -- blob_alarm
-- REM
-- REM Measurement Event BLOB Data Alarm
-- REM
-- REM org_agent_site, agent_id - Agent which acknowleged the alarm
-- REM
CREATE TABLE blob_alarm (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 mebt_db_site        INTEGER      NOT NULL,
 mebt_db_id          INTEGER      NOT NULL,
 meb_type_code       INTEGER      NOT NULL,
 al_db_site          INTEGER      NOT NULL,
 al_db_id            INTEGER      NOT NULL,
 al_type_code        INTEGER      NOT NULL,
 gmt_acknowledged    VARCHAR(29)  NOT NULL,
 ack_loc_hr_delta    SMALLINT, 
 ack_loc_min_delta   SMALLINT, 
 org_agent_site      INTEGER,
 agent_id            INTEGER,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, mebt_db_site, mebt_db_id, meb_type_code, al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, mebt_db_site, mebt_db_id, meb_type_code) REFERENCES mevent_blob_data(meas_loc_site, meas_loc_id, gmt_event, mebt_db_site, mebt_db_id, meb_type_code),
    FOREIGN KEY (al_db_site, al_db_id, al_type_code) REFERENCES alarm_type(al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (org_agent_site, agent_id) REFERENCES agent (org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

GO
-- REM #293 -- blob_area_alarm
-- REM
-- REM Measurement Event BLOB Data Area in Alarm
-- REM
-- REM org_agent_site, agent_id - Agent which acknowleged the alarm
-- REM
CREATE TABLE blob_area_alarm (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 mebt_db_site        INTEGER      NOT NULL,
 mebt_db_id          INTEGER      NOT NULL,
 meb_type_code       INTEGER      NOT NULL,
 area_seq            INTEGER      NOT NULL,
 x_resolution        INTEGER      NOT NULL,
 y_resolution        INTEGER      NOT NULL,
 high_db_site        INTEGER      NOT NULL,
 high_db_id          INTEGER      NOT NULL,
 high_type_code      INTEGER      NOT NULL,
 data_origin_x       INTEGER      NOT NULL,
 data_origin_y       INTEGER      NOT NULL,
 data_end_x          INTEGER      NOT NULL,
 data_end_y          INTEGER      NOT NULL,
 al_db_site          INTEGER      NOT NULL,
 al_db_id            INTEGER      NOT NULL,
 al_type_code        INTEGER      NOT NULL,
 gmt_acknowledged    VARCHAR(29)  NOT NULL,
 ack_loc_hr_delta    SMALLINT, 
 ack_loc_min_delta   SMALLINT, 
 org_agent_site      INTEGER,
 agent_id            INTEGER,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, mebt_db_site, mebt_db_id, meb_type_code, area_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, mebt_db_site, mebt_db_id, meb_type_code) REFERENCES mevent_blob_data(meas_loc_site, meas_loc_id, gmt_event, mebt_db_site, mebt_db_id, meb_type_code),
    FOREIGN KEY (high_db_site, high_db_id, high_type_code) REFERENCES highlight_type(high_db_site, high_db_id, high_type_code),
    FOREIGN KEY (al_db_site, al_db_id, al_type_code) REFERENCES alarm_type(al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (org_agent_site, agent_id) REFERENCES agent (org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

-- REM ////////////////////////////////////////////
-- REM
-- REM Function Data Tables
-- REM
-- REM ////////////////////////////////////////////
GO
-- REM #226 -- segment_function
-- REM
-- REM Function Codes,Descriptions of a Service Segment
-- REM
CREATE TABLE segment_function (
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 user_tag_id         VARCHAR(254) NOT NULL,
 name                VARCHAR(254),
 gmt_created         VARCHAR(29),
 cr_loc_hr_delta     SMALLINT,
 cr_loc_min_delta    SMALLINT,
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (db_site, db_id, segment_site, segment_id, ordering_seq),
    FOREIGN KEY (db_site, db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment(segment_site, segment_id),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #227 -- asset_function
-- REM
-- REM Function Codes,Descriptions of an Asset
-- REM
CREATE TABLE asset_function (
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 user_tag_id         VARCHAR(254) NOT NULL,
 name                VARCHAR(254),
 gmt_created         VARCHAR(29),
 cr_loc_hr_delta     SMALLINT,
 cr_loc_min_delta    SMALLINT,
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (db_site, db_id, asset_org_site, asset_id, ordering_seq),
    FOREIGN KEY (db_site, db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset(asset_org_site, asset_id),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #264 -- sg_type_function
-- REM
-- REM Function Codes,Descriptions of a Service Segment Type
-- REM
CREATE TABLE sg_type_function (
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 sg_db_site          INTEGER      NOT NULL,
 sg_db_id            INTEGER      NOT NULL,
 sg_type_code        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 user_tag_id         VARCHAR(254) NOT NULL,
 name                VARCHAR(254),
 gmt_created         VARCHAR(29),
 cr_loc_hr_delta     SMALLINT,
 cr_loc_min_delta    SMALLINT,
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (db_site, db_id, sg_db_site, sg_db_id, sg_type_code, ordering_seq),
    FOREIGN KEY (db_site, db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (sg_db_site, sg_db_id, sg_type_code) REFERENCES segment_type(sg_db_site, sg_db_id, sg_type_code),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #265 -- as_type_function
-- REM
-- REM Function Codes,Descriptions of a Asset Type
-- REM
CREATE TABLE as_type_function (
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 as_db_site          INTEGER      NOT NULL,
 as_db_id            INTEGER      NOT NULL,
 as_type_code        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 user_tag_id         VARCHAR(254) NOT NULL,
 name                VARCHAR(254),
 gmt_created         VARCHAR(29),
 cr_loc_hr_delta     SMALLINT,
 cr_loc_min_delta    SMALLINT,
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (db_site, db_id, as_db_site, as_db_id, as_type_code, ordering_seq),
    FOREIGN KEY (db_site, db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (as_db_site, as_db_id, as_type_code) REFERENCES asset_type(as_db_site, as_db_id, as_type_code),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #268 -- model_function
-- REM
-- REM Function Codes,Descriptions of a Model
-- REM
CREATE TABLE model_function (
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 mf_db_site          INTEGER      NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 model_number        VARCHAR(254) NOT NULL,
 revision_number     INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 user_tag_id         VARCHAR(254) NOT NULL,
 name                VARCHAR(254),
 gmt_created         VARCHAR(29),
 cr_loc_hr_delta     SMALLINT,
 cr_loc_min_delta    SMALLINT,
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (db_site, db_id, mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, ordering_seq),
    FOREIGN KEY (db_site, db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number) REFERENCES model(mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #228 -- sg_ev_sg_func_link
-- REM
-- REM Segment Events Linked to Functions Affected
-- REM
CREATE TABLE sg_ev_sg_func_link (
 ev_segment_site     INTEGER      NOT NULL,
 ev_segment_id       INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     VARCHAR(29)  NOT NULL,
 fn_db_site          INTEGER      NOT NULL,
 fn_db_id            INTEGER      NOT NULL,
 fn_segment_site     INTEGER      NOT NULL,
 fn_segment_id       INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 name                VARCHAR(254),
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ev_segment_site, ev_segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start, fn_db_site, fn_db_id, fn_segment_site, fn_segment_id, ordering_seq),
    FOREIGN KEY (ev_segment_site, ev_segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start) REFERENCES segment_event(segment_site, segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (fn_db_site, fn_db_id, fn_segment_site, fn_segment_id, ordering_seq) REFERENCES segment_function(db_site, db_id, segment_site, segment_id, ordering_seq),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #229 -- as_ev_as_func_link
-- REM
-- REM Asset Events Linked to Functions Affected
-- REM
CREATE TABLE as_ev_as_func_link (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     VARCHAR(29)  NOT NULL,
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 fc_as_org_site      INTEGER      NOT NULL,
 fc_as_id            INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 name                VARCHAR(254),
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start, db_site, db_id, fc_as_org_site, fc_as_id, ordering_seq),
    FOREIGN KEY (asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start) REFERENCES asset_event(asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (db_site, db_id, fc_as_org_site, fc_as_id, ordering_seq) REFERENCES asset_function(db_site, db_id, asset_org_site, asset_id, ordering_seq),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
 
-- REM ///////////////////////////////////////////////////////////
-- REM
-- REM Actual Event/Hypothesized Event/Proposed Event Tables 
-- REM Event Causal Networks Tables 
-- REM
-- REM ///////////////////////////////////////////////////////////

GO
-- REM #111 -- sg_event_num_data
-- REM
-- REM Segment Event Numeric Data
-- REM
CREATE TABLE sg_event_num_data (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     VARCHAR(29)  NOT NULL,
 en_db_site          INTEGER      NOT NULL,
 en_db_id            INTEGER      NOT NULL,
 en_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          FLOAT        NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start, en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (segment_site, segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start) REFERENCES segment_event(segment_site, segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (en_db_site, en_db_id, en_type_code) REFERENCES ev_num_data_type(en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #113 -- as_event_num_data
-- REM
-- REM Asset Event Numeric Data
-- REM
CREATE TABLE as_event_num_data (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     VARCHAR(29)  NOT NULL,
 en_db_site          INTEGER      NOT NULL,
 en_db_id            INTEGER      NOT NULL,
 en_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          FLOAT        NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start, en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start) REFERENCES asset_event(asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (en_db_site, en_db_id, en_type_code) REFERENCES ev_num_data_type(en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #294 -- sg_ev_meas_event
-- REM
-- REM Segment Events Associated With Measurement Events Which Substantiate the Actual Event
-- REM
CREATE TABLE sg_ev_meas_event (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     VARCHAR(29)  NOT NULL,
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 name                VARCHAR(254),
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start, meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (segment_site, segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start) REFERENCES segment_event(segment_site, segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES meas_event(meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #295 -- as_ev_meas_event
-- REM
-- REM Asset Events Associated With Measurement Events Which Substantiate the Actual Event
-- REM
CREATE TABLE as_ev_meas_event (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     VARCHAR(29)  NOT NULL,
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 name                VARCHAR(254),
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start, meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start) REFERENCES asset_event(asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES meas_event(meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #152 -- segment_event_link
-- REM
-- REM Segment Event Cause,Effect Links in an Event Causal Network
-- REM
CREATE TABLE segment_event_link (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     VARCHAR(29)  NOT NULL,
 caused_sg_site      INTEGER      NOT NULL,
 caused_sg_id        INTEGER      NOT NULL,
 caused_ev_db_site   INTEGER      NOT NULL,
 caused_ev_db_id     INTEGER      NOT NULL,
 caused_ev_code      INTEGER      NOT NULL,
 caused_gmt          VARCHAR(29)  NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start, caused_sg_site, caused_sg_id, caused_ev_db_site, caused_ev_db_id, caused_ev_code, caused_gmt),
    FOREIGN KEY (segment_site, segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start) REFERENCES segment_event(segment_site, segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (caused_sg_site, caused_sg_id, caused_ev_db_site, caused_ev_db_id, caused_ev_code, caused_gmt) REFERENCES segment_event(segment_site, segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #153 -- asset_event_link
-- REM
-- REM Asset Event Cause,Effect Links in an Event Causal Network
-- REM
CREATE TABLE asset_event_link (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     VARCHAR(29)  NOT NULL,
 caused_as_site      INTEGER      NOT NULL,
 caused_as_id        INTEGER      NOT NULL,
 caused_ev_db_site   INTEGER      NOT NULL,
 caused_ev_db_id     INTEGER      NOT NULL,
 caused_ev_code      INTEGER      NOT NULL,
 caused_gmt          VARCHAR(29)  NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start, caused_as_site, caused_as_id, caused_ev_db_site, caused_ev_db_id, caused_ev_code, caused_gmt),
    FOREIGN KEY (asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start) REFERENCES asset_event(asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (caused_as_site, caused_as_id, caused_ev_db_site, caused_ev_db_id, caused_ev_code, caused_gmt) REFERENCES asset_event(asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #230 -- sg_hyp_event
-- REM
-- REM Hypothetical Segment Events , Possible Failure Modes , Possible Failure Mechanisms
-- REM
-- REM NOTE: associated_blob - Associated document, drawing, etc.
-- REM
CREATE TABLE sg_hyp_event (
 sg_hyp_db_site      INTEGER      NOT NULL,
 sg_hyp_db_id        INTEGER      NOT NULL,
 sg_hyp_event_id     INTEGER      NOT NULL,
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 severity_rank       INTEGER,
 gmt_created         VARCHAR(29),
 cr_loc_hr_delta     SMALLINT,
 cr_loc_min_delta    SMALLINT,
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 name                VARCHAR(254),
 associated_blob     IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id),
    FOREIGN KEY (sg_hyp_db_site, sg_hyp_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment(segment_site, segment_id),
    FOREIGN KEY (ev_db_site, ev_db_id, event_type_code) REFERENCES sg_as_event_type(ev_db_site, ev_db_id, event_type_code),
    FOREIGN KEY (severity_rank) REFERENCES severity_type(severity_rank),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #231 -- as_hyp_event
-- REM
-- REM Hypothetical Asset Events , Possible Failure Modes , Possible Failure Mechanisms
-- REM
-- REM
-- REM NOTE: associated_blob - Associated document, drawing, etc.
-- REM
CREATE TABLE as_hyp_event (
 as_hyp_db_site      INTEGER      NOT NULL,
 as_hyp_db_id        INTEGER      NOT NULL,
 as_hyp_event_id     INTEGER      NOT NULL,
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 severity_rank       INTEGER,
 gmt_created         VARCHAR(29),
 cr_loc_hr_delta     SMALLINT,
 cr_loc_min_delta    SMALLINT,
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 name                VARCHAR(254),
 associated_blob     IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (as_hyp_db_site, as_hyp_db_id, as_hyp_event_id),
    FOREIGN KEY (as_hyp_db_site, as_hyp_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset(asset_org_site, asset_id),
    FOREIGN KEY (ev_db_site, ev_db_id, event_type_code) REFERENCES sg_as_event_type(ev_db_site, ev_db_id, event_type_code),
    FOREIGN KEY (severity_rank) REFERENCES severity_type(severity_rank),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #240 -- sg_typ_hyp_event
-- REM
-- REM Hypothetical Segment Type Events , Possible Failure Modes , Possible Failure Mechanisms
-- REM
-- REM
-- REM NOTE: associated_blob - Associated document, drawing, etc.
-- REM
CREATE TABLE sg_typ_hyp_event (
 sgt_hyp_db_site     INTEGER      NOT NULL,
 sgt_hyp_db_id       INTEGER      NOT NULL,
 sgt_hyp_event_id    INTEGER      NOT NULL,
 sg_db_site          INTEGER      NOT NULL,
 sg_db_id            INTEGER      NOT NULL,
 sg_type_code        INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 severity_rank       INTEGER,
 gmt_created         VARCHAR(29),
 cr_loc_hr_delta     SMALLINT,
 cr_loc_min_delta    SMALLINT,
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 name                VARCHAR(254),
 associated_blob     IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sgt_hyp_db_site, sgt_hyp_db_id, sgt_hyp_event_id),
    FOREIGN KEY (sgt_hyp_db_site, sgt_hyp_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (sg_db_site, sg_db_id, sg_type_code) REFERENCES segment_type(sg_db_site, sg_db_id, sg_type_code),
    FOREIGN KEY (ev_db_site, ev_db_id, event_type_code) REFERENCES sg_as_event_type(ev_db_site, ev_db_id, event_type_code),
    FOREIGN KEY (severity_rank) REFERENCES severity_type(severity_rank),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #241 -- as_typ_hyp_event
-- REM
-- REM Hypothetical Asset Type Events , Possible Failure Modes , Possible Failure Mechanisms
-- REM
-- REM
-- REM NOTE: associated_blob - Associated document, drawing, etc.
-- REM
CREATE TABLE as_typ_hyp_event (
 ast_hyp_db_site     INTEGER      NOT NULL,
 ast_hyp_db_id       INTEGER      NOT NULL,
 ast_hyp_event_id    INTEGER      NOT NULL,
 as_db_site          INTEGER      NOT NULL,
 as_db_id            INTEGER      NOT NULL,
 as_type_code        INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 severity_rank       INTEGER,
 gmt_created         VARCHAR(29),
 cr_loc_hr_delta     SMALLINT,
 cr_loc_min_delta    SMALLINT,
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 name                VARCHAR(254),
 associated_blob     IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ast_hyp_db_site, ast_hyp_db_id, ast_hyp_event_id),
    FOREIGN KEY (ast_hyp_db_site, ast_hyp_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (as_db_site, as_db_id, as_type_code) REFERENCES asset_type(as_db_site, as_db_id, as_type_code),
    FOREIGN KEY (ev_db_site, ev_db_id, event_type_code) REFERENCES sg_as_event_type(ev_db_site, ev_db_id, event_type_code),
    FOREIGN KEY (severity_rank) REFERENCES severity_type(severity_rank),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #246 -- model_hyp_event
-- REM
-- REM Hypothetical Model Events , Possible Failure Modes , Possible Failure Mechanisms
-- REM
-- REM
-- REM NOTE: associated_blob - Associated document, drawing, etc.
-- REM
CREATE TABLE model_hyp_event (
 mod_hyp_db_site     INTEGER      NOT NULL,
 mod_hyp_db_id       INTEGER      NOT NULL,
 mod_hyp_event_id    INTEGER      NOT NULL,
 mf_db_site          INTEGER      NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 model_number        VARCHAR(254) NOT NULL,
 revision_number     INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 severity_rank       INTEGER,
 gmt_created         VARCHAR(29),
 cr_loc_hr_delta     SMALLINT,
 cr_loc_min_delta    SMALLINT,
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 name                VARCHAR(254),
 associated_blob     IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (mod_hyp_db_site, mod_hyp_db_id, mod_hyp_event_id),
    FOREIGN KEY (mod_hyp_db_site, mod_hyp_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number) REFERENCES model(mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number),
    FOREIGN KEY (ev_db_site, ev_db_id, event_type_code) REFERENCES sg_as_event_type(ev_db_site, ev_db_id, event_type_code),
    FOREIGN KEY (severity_rank) REFERENCES severity_type(severity_rank),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #232 -- sg_hyp_event_link
-- REM
-- REM Hypothetical Segment Event Cause,Effect Links in an Event Causal Network
-- REM
-- REM likelihood_prob - Likelihood probability between 0 and 1
-- REM
CREATE TABLE sg_hyp_event_link (
 sg_hyp_db_site      INTEGER      NOT NULL,
 sg_hyp_db_id        INTEGER      NOT NULL,
 sg_hyp_event_id     INTEGER      NOT NULL,
 caused_db_site      INTEGER      NOT NULL,
 caused_db_id        INTEGER      NOT NULL,
 caused_event_id     INTEGER      NOT NULL,
 likelihood_prob     FLOAT,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id, caused_db_site, caused_db_id, caused_event_id),
    FOREIGN KEY (sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id) REFERENCES sg_hyp_event(sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id),
    FOREIGN KEY (caused_db_site, caused_db_id, caused_event_id) REFERENCES sg_hyp_event(sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #233 -- as_hyp_event_link
-- REM
-- REM Hypothetical Asset Event Cause,Effect Links in an Event Causal Network
-- REM
-- REM
-- REM likelihood_prob - Likelihood probability between 0 and 1
-- REM
CREATE TABLE as_hyp_event_link (
 as_hyp_db_site      INTEGER      NOT NULL,
 as_hyp_db_id        INTEGER      NOT NULL,
 as_hyp_event_id     INTEGER      NOT NULL,
 caused_db_site      INTEGER      NOT NULL,
 caused_db_id        INTEGER      NOT NULL,
 caused_event_id     INTEGER      NOT NULL,
 likelihood_prob     FLOAT,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (as_hyp_db_site, as_hyp_db_id, as_hyp_event_id, caused_db_site, caused_db_id, caused_event_id),
    FOREIGN KEY (as_hyp_db_site, as_hyp_db_id, as_hyp_event_id) REFERENCES as_hyp_event(as_hyp_db_site, as_hyp_db_id, as_hyp_event_id),
    FOREIGN KEY (caused_db_site, caused_db_id, caused_event_id) REFERENCES as_hyp_event(as_hyp_db_site, as_hyp_db_id, as_hyp_event_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #242 -- sg_typ_hyp_ev_link
-- REM
-- REM Hypothetical Segment Type Event Cause,Effect Links in an Event Causal Network
-- REM
-- REM
-- REM likelihood_prob - Likelihood probability between 0 and 1
-- REM
CREATE TABLE sg_typ_hyp_ev_link (
 sgt_hyp_db_site     INTEGER      NOT NULL,
 sgt_hyp_db_id       INTEGER      NOT NULL,
 sgt_hyp_event_id    INTEGER      NOT NULL,
 caused_db_site      INTEGER      NOT NULL,
 caused_db_id        INTEGER      NOT NULL,
 caused_event_id     INTEGER      NOT NULL,
 likelihood_prob     FLOAT,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sgt_hyp_db_site, sgt_hyp_db_id, sgt_hyp_event_id, caused_db_site, caused_db_id, caused_event_id),
    FOREIGN KEY (sgt_hyp_db_site, sgt_hyp_db_id, sgt_hyp_event_id) REFERENCES sg_typ_hyp_event(sgt_hyp_db_site, sgt_hyp_db_id, sgt_hyp_event_id),
    FOREIGN KEY (caused_db_site, caused_db_id, caused_event_id) REFERENCES sg_typ_hyp_event(sgt_hyp_db_site, sgt_hyp_db_id, sgt_hyp_event_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #243 -- as_typ_hyp_ev_link
-- REM
-- REM Hypothetical Asset Type Event Cause,Effect Links in an Event Causal Network
-- REM
-- REM
-- REM likelihood_prob - Likelihood probability between 0 and 1
-- REM
CREATE TABLE as_typ_hyp_ev_link (
 ast_hyp_db_site     INTEGER      NOT NULL,
 ast_hyp_db_id       INTEGER      NOT NULL,
 ast_hyp_event_id    INTEGER      NOT NULL,
 caused_db_site      INTEGER      NOT NULL,
 caused_db_id        INTEGER      NOT NULL,
 caused_event_id     INTEGER      NOT NULL,
 likelihood_prob     FLOAT,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ast_hyp_db_site, ast_hyp_db_id, ast_hyp_event_id, caused_db_site, caused_db_id, caused_event_id),
    FOREIGN KEY (ast_hyp_db_site, ast_hyp_db_id, ast_hyp_event_id) REFERENCES as_typ_hyp_event(ast_hyp_db_site, ast_hyp_db_id, ast_hyp_event_id),
    FOREIGN KEY (caused_db_site, caused_db_id, caused_event_id) REFERENCES as_typ_hyp_event(ast_hyp_db_site, ast_hyp_db_id, ast_hyp_event_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #247 -- model_hyp_ev_link
-- REM
-- REM Hypothetical Model Event Cause,Effect Links in an Event Causal Network
-- REM
-- REM
-- REM likelihood_prob - Likelihood probability between 0 and 1
-- REM
CREATE TABLE model_hyp_ev_link (
 mod_hyp_db_site     INTEGER      NOT NULL,
 mod_hyp_db_id       INTEGER      NOT NULL,
 mod_hyp_event_id    INTEGER      NOT NULL,
 caused_db_site      INTEGER      NOT NULL,
 caused_db_id        INTEGER      NOT NULL,
 caused_event_id     INTEGER      NOT NULL,
 likelihood_prob     FLOAT,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (mod_hyp_db_site, mod_hyp_db_id, mod_hyp_event_id, caused_db_site, caused_db_id, caused_event_id),
    FOREIGN KEY (mod_hyp_db_site, mod_hyp_db_id, mod_hyp_event_id) REFERENCES model_hyp_event(mod_hyp_db_site, mod_hyp_db_id, mod_hyp_event_id),
    FOREIGN KEY (caused_db_site, caused_db_id, caused_event_id) REFERENCES model_hyp_event(mod_hyp_db_site, mod_hyp_db_id, mod_hyp_event_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #234 -- sg_hyp_ev_num_data
-- REM
-- REM Segment Hypothetical Event Numeric Data
-- REM
CREATE TABLE sg_hyp_ev_num_data (
 sg_hyp_db_site      INTEGER      NOT NULL,
 sg_hyp_db_id        INTEGER      NOT NULL,
 sg_hyp_event_id     INTEGER      NOT NULL,
 en_db_site          INTEGER      NOT NULL,
 en_db_id            INTEGER      NOT NULL,
 en_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          FLOAT        NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id, en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id) REFERENCES sg_hyp_event(sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id),
    FOREIGN KEY (en_db_site, en_db_id, en_type_code) REFERENCES ev_num_data_type(en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #235 -- as_hyp_ev_num_data
-- REM
-- REM Asset Hypothetical Event Numeric Data
-- REM
CREATE TABLE as_hyp_ev_num_data (
 as_hyp_db_site      INTEGER      NOT NULL,
 as_hyp_db_id        INTEGER      NOT NULL,
 as_hyp_event_id     INTEGER      NOT NULL,
 en_db_site          INTEGER      NOT NULL,
 en_db_id            INTEGER      NOT NULL,
 en_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (as_hyp_db_site, as_hyp_db_id, as_hyp_event_id, en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (as_hyp_db_site, as_hyp_db_id, as_hyp_event_id) REFERENCES as_hyp_event(as_hyp_db_site, as_hyp_db_id, as_hyp_event_id),
    FOREIGN KEY (en_db_site, en_db_id, en_type_code) REFERENCES ev_num_data_type(en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #244 -- sg_typ_hyp_ev_num_data
-- REM
-- REM Segment Type Hypothetical Event Numeric Data
-- REM
CREATE TABLE sg_typ_hyp_ev_num_data (
 sgt_hyp_db_site     INTEGER      NOT NULL,
 sgt_hyp_db_id       INTEGER      NOT NULL,
 sgt_hyp_event_id    INTEGER      NOT NULL,
 en_db_site          INTEGER      NOT NULL,
 en_db_id            INTEGER      NOT NULL,
 en_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          FLOAT        NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sgt_hyp_db_site, sgt_hyp_db_id, sgt_hyp_event_id, en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (sgt_hyp_db_site, sgt_hyp_db_id, sgt_hyp_event_id) REFERENCES sg_typ_hyp_event(sgt_hyp_db_site, sgt_hyp_db_id, sgt_hyp_event_id),
    FOREIGN KEY (en_db_site, en_db_id, en_type_code) REFERENCES ev_num_data_type(en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #245 -- as_typ_hyp_ev_num_data
-- REM
-- REM Asset Type Hypothetical Event Numeric Data
-- REM
CREATE TABLE as_typ_hyp_ev_num_data (
 ast_hyp_db_site     INTEGER      NOT NULL,
 ast_hyp_db_id       INTEGER      NOT NULL,
 ast_hyp_event_id    INTEGER      NOT NULL,
 en_db_site          INTEGER      NOT NULL,
 en_db_id            INTEGER      NOT NULL,
 en_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          FLOAT        NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ast_hyp_db_site, ast_hyp_db_id, ast_hyp_event_id, en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (ast_hyp_db_site, ast_hyp_db_id, ast_hyp_event_id) REFERENCES as_typ_hyp_event(ast_hyp_db_site, ast_hyp_db_id, ast_hyp_event_id),
    FOREIGN KEY (en_db_site, en_db_id, en_type_code) REFERENCES ev_num_data_type(en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #248 -- model_hyp_ev_num_data
-- REM
-- REM Model Hypothetical Event Numeric Data
-- REM
CREATE TABLE model_hyp_ev_num_data (
 mod_hyp_db_site     INTEGER      NOT NULL,
 mod_hyp_db_id       INTEGER      NOT NULL,
 mod_hyp_event_id    INTEGER      NOT NULL,
 en_db_site          INTEGER      NOT NULL,
 en_db_id            INTEGER      NOT NULL,
 en_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          FLOAT        NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (mod_hyp_db_site, mod_hyp_db_id, mod_hyp_event_id, en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (mod_hyp_db_site, mod_hyp_db_id, mod_hyp_event_id) REFERENCES model_hyp_event(mod_hyp_db_site, mod_hyp_db_id, mod_hyp_event_id),
    FOREIGN KEY (en_db_site, en_db_id, en_type_code) REFERENCES ev_num_data_type(en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #236 -- sg_hyp_ev_sg_func
-- REM
-- REM Segment Hypothetical Events Linked to Functions Affected
-- REM
CREATE TABLE sg_hyp_ev_sg_func (
 sg_hyp_db_site      INTEGER      NOT NULL,
 sg_hyp_db_id        INTEGER      NOT NULL,
 sg_hyp_event_id     INTEGER      NOT NULL,
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 name                VARCHAR(254),
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id, db_site, db_id, segment_site, segment_id, ordering_seq),
    FOREIGN KEY (sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id) REFERENCES sg_hyp_event(sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id),
    FOREIGN KEY (db_site, db_id, segment_site, segment_id, ordering_seq) REFERENCES segment_function(db_site, db_id, segment_site, segment_id, ordering_seq),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #237 -- as_hyp_ev_as_func
-- REM
-- REM Asset Hypothetical Events Linked to Functions Affected
-- REM
CREATE TABLE as_hyp_ev_as_func (
 as_hyp_db_site      INTEGER      NOT NULL,
 as_hyp_db_id        INTEGER      NOT NULL,
 as_hyp_event_id     INTEGER      NOT NULL,
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 name                VARCHAR(254),
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (as_hyp_db_site, as_hyp_db_id, as_hyp_event_id, db_site, db_id, asset_org_site, asset_id, ordering_seq),
    FOREIGN KEY (as_hyp_db_site, as_hyp_db_id, as_hyp_event_id) REFERENCES as_hyp_event(as_hyp_db_site, as_hyp_db_id, as_hyp_event_id),
    FOREIGN KEY (db_site, db_id, asset_org_site, asset_id, ordering_seq) REFERENCES asset_function(db_site, db_id, asset_org_site, asset_id, ordering_seq),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #266 -- sg_typ_hyp_ev_func
-- REM
-- REM Segment Type Hypothetical Events Linked To Functions Affected
-- REM
CREATE TABLE sg_typ_hyp_ev_func (
 sgt_hyp_db_site     INTEGER      NOT NULL,
 sgt_hyp_db_id       INTEGER      NOT NULL,
 sgt_hyp_event_id    INTEGER      NOT NULL,
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 sg_db_site          INTEGER      NOT NULL,
 sg_db_id            INTEGER      NOT NULL,
 sg_type_code        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 name                VARCHAR(254),
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sgt_hyp_db_site, sgt_hyp_db_id, sgt_hyp_event_id, db_site, db_id, sg_db_site, sg_db_id, sg_type_code, ordering_seq),
    FOREIGN KEY (sgt_hyp_db_site, sgt_hyp_db_id, sgt_hyp_event_id) REFERENCES sg_typ_hyp_event(sgt_hyp_db_site, sgt_hyp_db_id, sgt_hyp_event_id),
    FOREIGN KEY (db_site, db_id, sg_db_site, sg_db_id, sg_type_code, ordering_seq) REFERENCES sg_type_function(db_site, db_id, sg_db_site, sg_db_id, sg_type_code, ordering_seq),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #267 -- as_typ_hyp_ev_func
-- REM
-- REM Asset Type Hypothetical Events Linked To Functions Affected
-- REM
CREATE TABLE as_typ_hyp_ev_func (
 ast_hyp_db_site     INTEGER      NOT NULL,
 ast_hyp_db_id       INTEGER      NOT NULL,
 ast_hyp_event_id    INTEGER      NOT NULL,
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 as_db_site          INTEGER      NOT NULL,
 as_db_id            INTEGER      NOT NULL,
 as_type_code        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 name                VARCHAR(254),
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ast_hyp_db_site, ast_hyp_db_id, ast_hyp_event_id, db_site, db_id, as_db_site, as_db_id, as_type_code, ordering_seq),
    FOREIGN KEY (ast_hyp_db_site, ast_hyp_db_id, ast_hyp_event_id) REFERENCES as_typ_hyp_event(ast_hyp_db_site, ast_hyp_db_id, ast_hyp_event_id),
    FOREIGN KEY (db_site, db_id, as_db_site, as_db_id, as_type_code, ordering_seq) REFERENCES as_type_function(db_site, db_id, as_db_site, as_db_id, as_type_code, ordering_seq),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #269 -- model_hyp_ev_func
-- REM
-- REM Model Hypothetical Events Linked to Functions Affected
-- REM
CREATE TABLE model_hyp_ev_func (
 mod_hyp_db_site     INTEGER      NOT NULL,
 mod_hyp_db_id       INTEGER      NOT NULL,
 mod_hyp_event_id    INTEGER      NOT NULL,
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 mf_db_site          INTEGER      NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 model_number        VARCHAR(254) NOT NULL,
 revision_number     INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 name                VARCHAR(254),
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (mod_hyp_db_site, mod_hyp_db_id, mod_hyp_event_id, db_site, db_id, mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, ordering_seq),
    FOREIGN KEY (mod_hyp_db_site, mod_hyp_db_id, mod_hyp_event_id) REFERENCES model_hyp_event(mod_hyp_db_site, mod_hyp_db_id, mod_hyp_event_id),
    FOREIGN KEY (db_site, db_id, mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, ordering_seq) REFERENCES model_function(db_site, db_id, mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, ordering_seq),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #250 -- sg_proposed_event
-- REM
-- REM Proposed Segment Events including Diagnostic,Prognostic Event Outputs
-- REM
-- REM NOTE: severity_rank - Severity level of proposed event
-- REM
-- REM NOTE: gmt_proposed - Timestamp when proposed as an event	
-- REM
-- REM NOTE: pr_loc_hr_delta - Hours from GMT when proposed as an event
-- REM
-- REM NOTE: pr_loc_min_delta - Minutes from GMT when proposed as an event
-- REM
-- REM NOTE: by_org_asite, by_agent_id - Agent who proposed event
-- REM
-- REM NOTE: likelihood_prob - Likelihood probability between 0 and 1
-- REM
-- REM NOTE: est_gmt_start - Estimated GMT event started or will start
-- REM
-- REM NOTE: st_loc_hr_delta - Hours from GMT for local start time
-- REM
-- REM NOTE: st_loc_min_delta - Minutes from GMT for local start time
-- REM
-- REM NOTE: est_gmt_occur_end - Estimated GMT event ended or will end
-- REM 
-- REM NOTE: end_loc_hr_delta - Hours from GMT for local end time
-- REM
-- REM NOTE: end_loc_min_delta - Minutes from GMT for local end time
-- REM
-- REM NOTE: ch_patt_db_site, ch_patt_db_id, ch_patt_type_code - Change Pattern Code
-- REM
-- REM NOTE: name - Description
-- REM
-- REM NOTE: gmt_audited - GMT proposed event audited
-- REM 
-- REM NOTE: aud_loc_hr_delta - Hours from GMT for local audit time
-- REM 
-- REM NOTE: aud_loc_min_delta - Minutes from GMT for local audit time
-- REM
-- REM NOTE: aud_quality_code - Audit Quality Code (proposed event not inspected, 
-- REM       good/confirmed, bad/incorrect, or under review
-- REM
-- REM NOTE: aud_by_org_asite, aud_by_agent_id - Audited by Agent
-- REM
CREATE TABLE sg_proposed_event (
 sg_prop_db_site     INTEGER      NOT NULL,
 sg_prop_db_id       INTEGER      NOT NULL,
 sg_prop_event_id    INTEGER      NOT NULL,
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 severity_rank       INTEGER,
 gmt_proposed        VARCHAR(29),
 pr_loc_hr_delta     SMALLINT,
 pr_loc_min_delta    SMALLINT,
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 likelihood_prob     FLOAT,
 est_gmt_start       VARCHAR(29),
 st_loc_hr_delta     SMALLINT,
 st_loc_min_delta    SMALLINT,
 est_gmt_occur_end   VARCHAR(29),
 end_loc_hr_delta    SMALLINT,
 end_loc_min_delta   SMALLINT,
 ch_patt_db_site     INTEGER,
 ch_patt_db_id       INTEGER,
 ch_patt_type_code   INTEGER,
 name                VARCHAR(254),
 gmt_audited         VARCHAR(29),
 aud_loc_hr_delta    SMALLINT,
 aud_loc_min_delta   SMALLINT,
 aud_quality_code    SMALLINT,
 aud_by_org_asite    INTEGER,
 aud_by_agent_id     INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sg_prop_db_site, sg_prop_db_id, sg_prop_event_id),
    FOREIGN KEY (sg_prop_db_site, sg_prop_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment(segment_site, segment_id),
    FOREIGN KEY (ev_db_site, ev_db_id, event_type_code) REFERENCES sg_as_event_type(ev_db_site, ev_db_id, event_type_code),
    FOREIGN KEY (severity_rank) REFERENCES severity_type(severity_rank),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (ch_patt_db_site, ch_patt_db_id, ch_patt_type_code) REFERENCES change_patt_type(ch_patt_db_site, ch_patt_db_id, ch_patt_type_code),
    FOREIGN KEY (aud_quality_code) REFERENCES data_qual_type(dqual_type_code),
    FOREIGN KEY (aud_by_org_asite, aud_by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #251 -- as_proposed_event
-- REM
-- REM Proposed Asset Events including Diagnostic,Prognostic Event Outputs
-- REM
-- REM NOTE: severity_rank - Severity level of proposed event
-- REM
-- REM NOTE: gmt_proposed - Timestamp when proposed as an event	
-- REM
-- REM NOTE: pr_loc_hr_delta - Hours from GMT when proposed as an event
-- REM
-- REM NOTE: pr_loc_min_delta - Minutes from GMT when proposed as an event
-- REM
-- REM NOTE: by_org_asite, by_agent_id - Agent who proposed event
-- REM
-- REM NOTE: likelihood_prob - Likelihood probability between 0 and 1
-- REM
-- REM NOTE: est_gmt_start - Estimated GMT event started or will start
-- REM
-- REM NOTE: st_loc_hr_delta - Hours from GMT for local start time
-- REM
-- REM NOTE: st_loc_min_delta - Minutes from GMT for local start time
-- REM
-- REM NOTE: est_gmt_occur_end - Estimated GMT event ended or will end
-- REM 
-- REM NOTE: end_loc_hr_delta - Hours from GMT for local end time
-- REM
-- REM NOTE: end_loc_min_delta - Minutes from GMT for local end time
-- REM
-- REM NOTE: ch_patt_db_site, ch_patt_db_id, ch_patt_type_code - Change Pattern Code
-- REM
-- REM NOTE: name - Description
-- REM
-- REM NOTE: gmt_audited - GMT proposed event audited
-- REM 
-- REM NOTE: cf_loc_hr_delta - Hours from GMT for local audit time
-- REM 
-- REM NOTE: cf_loc_min_delta - Minutes from GMT for local audit time
-- REM
-- REM NOTE: aud_quality_code - Audit Quality Code (proposed event not inspected, 
-- REM       good/confirmed, bad/incorrect, or under review
-- REM
-- REM NOTE: cf_by_org_asite, cf_by_agent_id - Audited by Agent
-- REM
CREATE TABLE as_proposed_event (
 as_prop_db_site     INTEGER      NOT NULL,
 as_prop_db_id       INTEGER      NOT NULL,
 as_prop_event_id    INTEGER      NOT NULL,
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 severity_rank       INTEGER,
 gmt_proposed        VARCHAR(29),
 pr_loc_hr_delta     SMALLINT,
 pr_loc_min_delta    SMALLINT,
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 likelihood_prob     FLOAT,
 est_gmt_start       VARCHAR(29),
 st_loc_hr_delta     SMALLINT,
 st_loc_min_delta    SMALLINT,
 est_gmt_occur_end   VARCHAR(29),
 end_loc_hr_delta    SMALLINT,
 end_loc_min_delta   SMALLINT,
 ch_patt_db_site     INTEGER,
 ch_patt_db_id       INTEGER,
 ch_patt_type_code   INTEGER,
 name                VARCHAR(254),
 gmt_audited         VARCHAR(29),
 aud_loc_hr_delta    SMALLINT,
 aud_loc_min_delta   SMALLINT,
 aud_quality_code    SMALLINT,
 aud_by_org_asite    INTEGER,
 aud_by_agent_id     INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (as_prop_db_site, as_prop_db_id, as_prop_event_id),
    FOREIGN KEY (as_prop_db_site, as_prop_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset(asset_org_site, asset_id),
    FOREIGN KEY (ev_db_site, ev_db_id, event_type_code) REFERENCES sg_as_event_type(ev_db_site, ev_db_id, event_type_code),
    FOREIGN KEY (severity_rank) REFERENCES severity_type(severity_rank),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (ch_patt_db_site, ch_patt_db_id, ch_patt_type_code) REFERENCES change_patt_type(ch_patt_db_site, ch_patt_db_id, ch_patt_type_code),
    FOREIGN KEY (aud_quality_code) REFERENCES data_qual_type(dqual_type_code),
    FOREIGN KEY (aud_by_org_asite, aud_by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #252 -- sg_prop_ev_link
-- REM
-- REM Proposed Segment Event Cause,Effect Links in an Event Causal Network
-- REM
-- REM NOTE: likelihood_prob - Likelihood probability between 0 and 1
-- REM
CREATE TABLE sg_prop_ev_link (
 sg_prop_db_site     INTEGER      NOT NULL,
 sg_prop_db_id       INTEGER      NOT NULL,
 sg_prop_event_id    INTEGER      NOT NULL,
 caused_db_site      INTEGER      NOT NULL,
 caused_db_id        INTEGER      NOT NULL,
 caused_event_id     INTEGER      NOT NULL,
 likelihood_prob     FLOAT,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sg_prop_db_site, sg_prop_db_id, sg_prop_event_id, caused_db_site, caused_db_id, caused_event_id),
    FOREIGN KEY (sg_prop_db_site, sg_prop_db_id, sg_prop_event_id) REFERENCES sg_proposed_event(sg_prop_db_site, sg_prop_db_id, sg_prop_event_id),
    FOREIGN KEY (caused_db_site, caused_db_id, caused_event_id) REFERENCES sg_proposed_event(sg_prop_db_site, sg_prop_db_id, sg_prop_event_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #253 -- as_prop_ev_link
-- REM
-- REM Proposed Asset Event Cause,Effect Links in an Event Causal Network
-- REM
-- REM
-- REM NOTE: likelihood_prob - Likelihood probability between 0 and 1
-- REM
CREATE TABLE as_prop_ev_link (
 as_prop_db_site     INTEGER      NOT NULL,
 as_prop_db_id       INTEGER      NOT NULL,
 as_prop_event_id    INTEGER      NOT NULL,
 caused_db_site      INTEGER      NOT NULL,
 caused_db_id        INTEGER      NOT NULL,
 caused_event_id     INTEGER      NOT NULL,
 likelihood_prob     FLOAT,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (as_prop_db_site, as_prop_db_id, as_prop_event_id, caused_db_site, caused_db_id, caused_event_id),
    FOREIGN KEY (as_prop_db_site, as_prop_db_id, as_prop_event_id) REFERENCES as_proposed_event(as_prop_db_site, as_prop_db_id, as_prop_event_id),
    FOREIGN KEY (caused_db_site, caused_db_id, caused_event_id) REFERENCES as_proposed_event(as_prop_db_site, as_prop_db_id, as_prop_event_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #254 -- sg_prop_ev_ndat
-- REM
-- REM Segment Proposed Event Numeric Data
-- REM
CREATE TABLE sg_prop_ev_ndat (
 sg_prop_db_site     INTEGER      NOT NULL,
 sg_prop_db_id       INTEGER      NOT NULL,
 sg_prop_event_id    INTEGER      NOT NULL,
 en_db_site          INTEGER      NOT NULL,
 en_db_id            INTEGER      NOT NULL,
 en_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          FLOAT        NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sg_prop_db_site, sg_prop_db_id, sg_prop_event_id, en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (sg_prop_db_site, sg_prop_db_id, sg_prop_event_id) REFERENCES sg_proposed_event(sg_prop_db_site, sg_prop_db_id, sg_prop_event_id),
    FOREIGN KEY (en_db_site, en_db_id, en_type_code) REFERENCES ev_num_data_type(en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #255 -- as_prop_ev_ndat
-- REM
-- REM Asset Proposed Event Numeric Data
-- REM
CREATE TABLE as_prop_ev_ndat (
 as_prop_db_site     INTEGER      NOT NULL,
 as_prop_db_id       INTEGER      NOT NULL,
 as_prop_event_id    INTEGER      NOT NULL,
 en_db_site          INTEGER      NOT NULL,
 en_db_id            INTEGER      NOT NULL,
 en_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          FLOAT        NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (as_prop_db_site, as_prop_db_id, as_prop_event_id, en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (as_prop_db_site, as_prop_db_id, as_prop_event_id) REFERENCES as_proposed_event(as_prop_db_site, as_prop_db_id, as_prop_event_id),
    FOREIGN KEY (en_db_site, en_db_id, en_type_code) REFERENCES ev_num_data_type(en_db_site, en_db_id, en_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #262 -- sg_prop_ev_sg_func
-- REM
-- REM Proposed Segment Events Linked to Functions Affected
-- REM
CREATE TABLE sg_prop_ev_sg_func (
 sg_prop_db_site     INTEGER      NOT NULL,
 sg_prop_db_id       INTEGER      NOT NULL,
 sg_prop_event_id    INTEGER      NOT NULL,
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 name                VARCHAR(254),
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sg_prop_db_site, sg_prop_db_id, sg_prop_event_id, db_site, db_id, segment_site, segment_id, ordering_seq),
    FOREIGN KEY (sg_prop_db_site, sg_prop_db_id, sg_prop_event_id) REFERENCES sg_proposed_event(sg_prop_db_site, sg_prop_db_id, sg_prop_event_id),
    FOREIGN KEY (db_site, db_id, segment_site, segment_id, ordering_seq) REFERENCES segment_function(db_site, db_id, segment_site, segment_id, ordering_seq),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #263 -- as_prop_ev_as_func
-- REM
-- REM Proposed Asset Events Linked to Functions Affected
-- REM
CREATE TABLE as_prop_ev_as_func (
 as_prop_db_site     INTEGER      NOT NULL,
 as_prop_db_id       INTEGER      NOT NULL,
 as_prop_event_id    INTEGER      NOT NULL,
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 name                VARCHAR(254),
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (as_prop_db_site, as_prop_db_id, as_prop_event_id, db_site, db_id, asset_org_site, asset_id, ordering_seq),
    FOREIGN KEY (as_prop_db_site, as_prop_db_id, as_prop_event_id) REFERENCES as_proposed_event(as_prop_db_site, as_prop_db_id, as_prop_event_id),
    FOREIGN KEY (db_site, db_id, asset_org_site, asset_id, ordering_seq) REFERENCES asset_function(db_site, db_id, asset_org_site, asset_id, ordering_seq),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #256 -- sg_prop_ev_hyp_ev
-- REM
-- REM Proposed Segment Events Linked to Hypothetical Segment Events
-- REM
CREATE TABLE sg_prop_ev_hyp_ev (
 sg_prop_db_site     INTEGER      NOT NULL,
 sg_prop_db_id       INTEGER      NOT NULL,
 sg_prop_event_id    INTEGER      NOT NULL,
 sg_hypev_db_site    INTEGER      NOT NULL,
 sg_hypev_db_id      INTEGER      NOT NULL,
 sg_hyp_event_id     INTEGER      NOT NULL,
 name                VARCHAR(254),
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sg_prop_db_site, sg_prop_db_id, sg_prop_event_id, sg_hypev_db_site, sg_hypev_db_id, sg_hyp_event_id),
    FOREIGN KEY (sg_prop_db_site, sg_prop_db_id, sg_prop_event_id) REFERENCES sg_proposed_event(sg_prop_db_site, sg_prop_db_id, sg_prop_event_id),
    FOREIGN KEY (sg_hypev_db_site, sg_hypev_db_id, sg_hyp_event_id) REFERENCES sg_hyp_event(sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #257 -- as_prop_ev_hyp_ev
-- REM
-- REM Proposed Asset Events Linked to Hypothetical Asset Events
-- REM
CREATE TABLE as_prop_ev_hyp_ev (
 as_prop_db_site     INTEGER      NOT NULL,
 as_prop_db_id       INTEGER      NOT NULL,
 as_prop_event_id    INTEGER      NOT NULL,
 as_hypev_db_site    INTEGER      NOT NULL,
 as_hypev_db_id      INTEGER      NOT NULL,
 as_hyp_event_id     INTEGER      NOT NULL,
 name                VARCHAR(254),
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (as_prop_db_site, as_prop_db_id, as_prop_event_id, as_hypev_db_site, as_hypev_db_id, as_hyp_event_id),
    FOREIGN KEY (as_prop_db_site, as_prop_db_id, as_prop_event_id) REFERENCES as_proposed_event(as_prop_db_site, as_prop_db_id, as_prop_event_id),
    FOREIGN KEY (as_hypev_db_site, as_hypev_db_id, as_hyp_event_id) REFERENCES as_hyp_event(as_hyp_db_site, as_hyp_db_id, as_hyp_event_id),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #258 -- sg_prop_ev_sg_ev
-- REM
-- REM Proposed Segment Events Linked to Actual Segment Events - Event Evidence Link
-- REM
CREATE TABLE sg_prop_ev_sg_ev (
 sg_prop_db_site     INTEGER      NOT NULL,
 sg_prop_db_id       INTEGER      NOT NULL,
 sg_prop_event_id    INTEGER      NOT NULL,
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     VARCHAR(29)  NOT NULL,
 name                VARCHAR(254),
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sg_prop_db_site, sg_prop_db_id, sg_prop_event_id, segment_site, segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (sg_prop_db_site, sg_prop_db_id, sg_prop_event_id) REFERENCES sg_proposed_event(sg_prop_db_site, sg_prop_db_id, sg_prop_event_id),
    FOREIGN KEY (segment_site, segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start) REFERENCES segment_event(segment_site, segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #259 -- as_prop_ev_as_ev
-- REM
-- REM Proposed Asset Events Linked to Actual Asset Events - Event Evidence Link
-- REM
CREATE TABLE as_prop_ev_as_ev (
 as_prop_db_site     INTEGER      NOT NULL,
 as_prop_db_id       INTEGER      NOT NULL,
 as_prop_event_id    INTEGER      NOT NULL,
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     VARCHAR(29)  NOT NULL,
 name                VARCHAR(254),
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (as_prop_db_site, as_prop_db_id, as_prop_event_id, asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (as_prop_db_site, as_prop_db_id, as_prop_event_id) REFERENCES as_proposed_event(as_prop_db_site, as_prop_db_id, as_prop_event_id),
    FOREIGN KEY (asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start) REFERENCES asset_event(asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #296 -- sg_prop_ev_meas_ev
-- REM
-- REM Proposed Segment Events Associated With Measurement Events Which Substantiate the Proposed Event - Measurement Evidence Link
-- REM
CREATE TABLE sg_prop_ev_meas_ev (
 sg_prop_db_site     INTEGER      NOT NULL,
 sg_prop_db_id       INTEGER      NOT NULL,
 sg_prop_event_id    INTEGER      NOT NULL,
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 name                VARCHAR(254),
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sg_prop_db_site, sg_prop_db_id, sg_prop_event_id, meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (sg_prop_db_site, sg_prop_db_id, sg_prop_event_id) REFERENCES sg_proposed_event(sg_prop_db_site, sg_prop_db_id, sg_prop_event_id),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES meas_event(meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #297 -- as_prop_ev_meas_ev
-- REM
-- REM Proposed Asset Events Associated With Measurement Events Which Substantiate the Proposed Event - Measurement Evidence Link
-- REM
CREATE TABLE as_prop_ev_meas_ev (
 as_prop_db_site     INTEGER      NOT NULL,
 as_prop_db_id       INTEGER      NOT NULL,
 as_prop_event_id    INTEGER      NOT NULL,
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 name                VARCHAR(254),
 by_org_asite        INTEGER,
 by_agent_id         INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (as_prop_db_site, as_prop_db_id, as_prop_event_id, meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (as_prop_db_site, as_prop_db_id, as_prop_event_id) REFERENCES as_proposed_event(as_prop_db_site, as_prop_db_id, as_prop_event_id),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES meas_event(meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (by_org_asite, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

-- REM ////////////////////////////////////////////////////
-- REM
-- REM    Health and Estimated Life Assessment Tables
-- REM
-- REM ////////////////////////////////////////////////////
GO
-- REM #127 -- segment_health
-- REM
-- REM Segment Health Assessment History
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Agent who made the assessment / Doctor
-- REM
-- REM NOTE: hgrade_type_code - Health Grade Code
-- REM
-- REM NOTE: gmt_assessment - Assessment applies to this instant in time related to this segment
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Agent who made the assessment / "Doctor"
-- REM
-- REM NOTE: loc_hr_delta - Local hours from GMT for gmt_assessment
-- REM
-- REM NOTE: loc_min_delta - Local minutes from GMT for gmt_assessment
-- REM
-- REM NOTE: hgrade_float - Optional precise health grade float value between 0 & 10  (10 = perfect health)
-- REM 
-- REM NOTE: likelihood_prob - Likelihood probability between 0 and 1 that health assessment is accurate
-- REM
-- REM NOTE: gmt_created - Health assessment created on timestamp
-- REM
-- REM NOTE: cr_loc_hr_delta - Hours from GMT for creation timestamp
-- REM
-- REM NOTE: cr_loc_min_delta - Minutes from GMT for creation timestamp 
-- REM
-- REM NOTE: ch_patt_db_site, ch_patt_db_id, ch_patt_type_code - Change Pattern Code
-- REM
-- REM NOTE: gmt_audited - GMT proposed event audited
-- REM 
-- REM NOTE: aud_loc_hr_delta - Hours from GMT for local audit time
-- REM
-- REM NOTE: aud_loc_min_delta - Minutes from GMT for local audit time
-- REM
-- REM NOTE: aud_quality_code - Audit Quality Code (health assessment not inspected, good/confirmed,  bad/incorrect, or under review)
-- REM
-- REM NOTE: aud_by_org_asite, aud_by_agent_id - Audit Agent
CREATE TABLE segment_health (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 gmt_assessment      VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 loc_hr_delta        SMALLINT,
 loc_min_delta       SMALLINT,
 hgrade_type_code    INTEGER      NOT NULL,
 hgrade_float        FLOAT,
 likelihood_prob     FLOAT,
 gmt_created         VARCHAR(29),
 cr_loc_hr_delta     SMALLINT, 
 cr_loc_min_delta    SMALLINT,
 ch_patt_db_site     INTEGER,
 ch_patt_db_id       INTEGER, 
 ch_patt_type_code   INTEGER, 
 gmt_audited         VARCHAR(29), 
 aud_loc_hr_delta    SMALLINT,
 aud_loc_min_delta   SMALLINT,
 aud_quality_code    SMALLINT,
 aud_by_org_asite    INTEGER,
 aud_by_agent_id     INTEGER, 
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, gmt_assessment, by_agent_site, by_agent_id),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment(segment_site, segment_id),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (hgrade_type_code) REFERENCES health_grade_type(hgrade_type_code),
    FOREIGN KEY (ch_patt_db_site, ch_patt_db_id, ch_patt_type_code) REFERENCES change_patt_type (ch_patt_db_site, ch_patt_db_id, ch_patt_type_code),
    FOREIGN KEY (aud_quality_code) REFERENCES data_qual_type (dqual_type_code),
    FOREIGN KEY (aud_by_org_asite, aud_by_agent_id) REFERENCES agent (org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #129 -- asset_health
-- REM
-- REM Asset Health Assessment History
-- REM
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Agent who made the assessment / Doctor
-- REM
-- REM NOTE: hgrade_type_code - Health Grade Code
-- REM
CREATE TABLE asset_health (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 gmt_assessment      VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 loc_hr_delta        SMALLINT,
 loc_min_delta       SMALLINT,
 hgrade_type_code    INTEGER      NOT NULL,
 hgrade_float        FLOAT,
 likelihood_prob     FLOAT,
 gmt_created         VARCHAR(29),
 cr_loc_hr_delta     SMALLINT, 
 cr_loc_min_delta    SMALLINT,
 ch_patt_db_site     INTEGER,
 ch_patt_db_id       INTEGER, 
 ch_patt_type_code   INTEGER, 
 gmt_audited         VARCHAR(29), 
 aud_loc_hr_delta    SMALLINT,
 aud_loc_min_delta   SMALLINT,
 aud_quality_code    SMALLINT,
 aud_by_org_asite    INTEGER,
 aud_by_agent_id     INTEGER, 
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, gmt_assessment, by_agent_site, by_agent_id),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset(asset_org_site, asset_id),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (hgrade_type_code) REFERENCES health_grade_type(hgrade_type_code),
    FOREIGN KEY (ch_patt_db_site, ch_patt_db_id, ch_patt_type_code) REFERENCES change_patt_type (ch_patt_db_site, ch_patt_db_id, ch_patt_type_code),
    FOREIGN KEY (aud_quality_code) REFERENCES data_qual_type (dqual_type_code),
    FOREIGN KEY (aud_by_org_asite, aud_by_agent_id) REFERENCES agent (org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #298 -- sg_health_sg_event
-- REM
-- REM Actual Segment Events Associated With Segment Health Which Substantiate the Health Assessment
-- REM
CREATE TABLE sg_health_sg_event (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 gmt_assessment      VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 ev_sg_site          INTEGER      NOT NULL,
 ev_sg_id            INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     VARCHAR(29)  NOT NULL,
 name                VARCHAR(254),
 assoc_by_org_asite  INTEGER,
 assoc_by_agent_id   INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, gmt_assessment, by_agent_site, by_agent_id, ev_sg_site, ev_sg_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (segment_site, segment_id, gmt_assessment, by_agent_site, by_agent_id) REFERENCES segment_health(segment_site, segment_id, gmt_assessment, by_agent_site, by_agent_id),
    FOREIGN KEY (ev_sg_site, ev_sg_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start) REFERENCES segment_event(segment_site, segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (assoc_by_org_asite, assoc_by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #299 -- as_health_as_event
-- REM
-- REM Actual Asset Events Associated With Asset Health Which Substantiate the  Health Assessment
-- REM
CREATE TABLE as_health_as_event (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 gmt_assessment      VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 ev_as_org_site      INTEGER      NOT NULL,
 ev_as_id            INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     VARCHAR(29)  NOT NULL,
 name                VARCHAR(254),
 assoc_by_org_asite  INTEGER,
 assoc_by_agent_id   INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, gmt_assessment, by_agent_site, by_agent_id, ev_as_org_site, ev_as_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (asset_org_site, asset_id, gmt_assessment, by_agent_site, by_agent_id) REFERENCES asset_health(asset_org_site, asset_id, gmt_assessment, by_agent_site, by_agent_id),
    FOREIGN KEY (ev_as_org_site, ev_as_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start) REFERENCES asset_event(asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (assoc_by_org_asite, assoc_by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #300 -- sg_health_sg_prop_ev
-- REM
-- REM Proposed Segment Events Associated With Segment Health Which Substantiate the  Health Assessment
-- REM
CREATE TABLE sg_health_sg_prop_ev (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 gmt_assessment      VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 sg_prop_db_site     INTEGER      NOT NULL,
 sg_prop_db_id       INTEGER      NOT NULL,
 sg_prop_event_id    INTEGER      NOT NULL,
 name                VARCHAR(254),
 assoc_by_org_asite  INTEGER,
 assoc_by_agent_id   INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, gmt_assessment, by_agent_site, by_agent_id, sg_prop_db_site, sg_prop_db_id, sg_prop_event_id),
    FOREIGN KEY (segment_site, segment_id, gmt_assessment, by_agent_site, by_agent_id) REFERENCES segment_health(segment_site, segment_id, gmt_assessment, by_agent_site, by_agent_id),
    FOREIGN KEY (sg_prop_db_site, sg_prop_db_id, sg_prop_event_id) REFERENCES sg_proposed_event(sg_prop_db_site, sg_prop_db_id, sg_prop_event_id),
    FOREIGN KEY (assoc_by_org_asite, assoc_by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #301 -- as_health_as_prop_ev
-- REM
-- REM Proposed Asset Events Associated With Asset Health Which Substantiate the  Health Assessment
-- REM
CREATE TABLE as_health_as_prop_ev (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 gmt_assessment      VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 as_prop_db_site     INTEGER      NOT NULL,
 as_prop_db_id       INTEGER      NOT NULL,
 as_prop_event_id    INTEGER      NOT NULL,
 name                VARCHAR(254),
 assoc_by_org_asite  INTEGER,
 assoc_by_agent_id   INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, gmt_assessment, by_agent_site, by_agent_id, as_prop_db_site, as_prop_db_id, as_prop_event_id),
    FOREIGN KEY (asset_org_site, asset_id, gmt_assessment, by_agent_site, by_agent_id) REFERENCES asset_health(asset_org_site, asset_id, gmt_assessment, by_agent_site, by_agent_id),
    FOREIGN KEY (as_prop_db_site, as_prop_db_id, as_prop_event_id) REFERENCES as_proposed_event(as_prop_db_site, as_prop_db_id, as_prop_event_id),
    FOREIGN KEY (assoc_by_org_asite, assoc_by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #146 -- sg_remaining_life
-- REM
-- REM Segment Remaining Life Assessment History Assessment For Past/Present/Future
-- REM
-- REM NOTE: gmt_assessment - Remaining life assessment baseline timestamp from which to add estimated remaining useful life
-- REM 
-- REM NOTE: by_agent_site, by_agent_id - Agent who made the assessment / Doctor
-- REM
-- REM NOTE: loc_hr_delta - Local time, hour offset from GMT
-- REM
-- REM NOTE: loc_min_delta - Local time, minute offset from GMT
-- REM
-- REM NOTE: est_remaining_life - Estimated remaining life assuming no intervention
-- REM 
-- REM NOTE: erl_eu_db_site, erl_eu_db_id, erl_eu_type_code - Time units for est. remaining life
-- REM
-- REM NOTE: error_estimate - Error estimate (+/- X duration)
-- REM
-- REM NOTE: err_eu_db_site, err_eu_db_id, err_eu_type_code - Time units for error estimate
-- REM
-- REM NOTE: likelihood_prob - Likelihood probability between 0 and 1 that assessment is accurate
-- REM
-- REM NOTE: gmt_created - Life assessment created on timestamp
-- REM
-- REM NOTE: cr_loc_hr_delta - Hours from GMT for creation timestamp
-- REM
-- REM NOTE: cr_loc_min_delta - Minutes from GMT for creation timestamp
-- REM
CREATE TABLE sg_remaining_life (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 gmt_assessment      VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 loc_hr_delta        SMALLINT,
 loc_min_delta       SMALLINT,
 est_remaining_life  FLOAT,
 erl_eu_db_site      INTEGER,
 erl_eu_db_id        INTEGER,
 erl_eu_type_code    INTEGER,
 error_estimate      FLOAT,
 err_eu_db_site      INTEGER,
 err_eu_db_id        INTEGER,
 err_eu_type_code    INTEGER,
 likelihood_prob     FLOAT,
 gmt_created         VARCHAR(29),
 cr_loc_hr_delta     SMALLINT,
 cr_loc_min_delta    SMALLINT,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, gmt_assessment, by_agent_site, by_agent_id),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment(segment_site, segment_id),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (erl_eu_db_site, erl_eu_db_id, erl_eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (err_eu_db_site, err_eu_db_id, err_eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #147 -- as_remaining_life 
-- REM
-- REM Asset Remaining Life Assessment History  For Past/Present/Future
-- REM
-- REM NOTE: gmt_assessment - Remaining life assessment baseline timestamp from which to add estimated remaining useful life
-- REM 
-- REM NOTE: by_agent_site, by_agent_id - Agent who made the assessment / Doctor
-- REM
-- REM NOTE: loc_hr_delta - Local time, hour offset from GMT
-- REM
-- REM NOTE: loc_min_delta - Local time, minute offset from GMT
-- REM
-- REM NOTE: est_remaining_life - Estimated remaining life assuming no intervention
-- REM 
-- REM NOTE: erl_eu_db_site, erl_eu_db_id, erl_eu_type_code - Time units for est. remaining life
-- REM
-- REM NOTE: error_estimate - Error estimate (+/- X duration)
-- REM
-- REM NOTE: err_eu_db_site, err_eu_db_id, err_eu_type_code - Time units for error estimate
-- REM
-- REM NOTE: likelihood_prob - Likelihood probability between 0 and 1 that assessment is accurate
-- REM
-- REM NOTE: gmt_created - Life assessment created on timestamp
-- REM
-- REM NOTE: cr_loc_hr_delta - Hours from GMT for creation timestamp
-- REM
-- REM NOTE: cr_loc_min_delta - Minutes from GMT for creation timestamp
-- REM
CREATE TABLE as_remaining_life (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 gmt_assessment      VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 loc_hr_delta        SMALLINT,
 loc_min_delta       SMALLINT,
 est_remaining_life  FLOAT,
 erl_eu_db_site      INTEGER,
 erl_eu_db_id        INTEGER,
 erl_eu_type_code    INTEGER,
 error_estimate      FLOAT,
 err_eu_db_site      INTEGER,
 err_eu_db_id        INTEGER,
 err_eu_type_code    INTEGER,
 likelihood_prob     FLOAT,
 gmt_created         VARCHAR(29),
 cr_loc_hr_delta     SMALLINT,
 cr_loc_min_delta    SMALLINT,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, gmt_assessment, by_agent_site, by_agent_id),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset(asset_org_site, asset_id),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (erl_eu_db_site, erl_eu_db_id, erl_eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (err_eu_db_site, err_eu_db_id, err_eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

-- REM /////////////////////////////////////////
-- REM
-- REM          Recommendation Tables
-- REM
-- REM /////////////////////////////////////////
GO
-- REM #184 -- sg_recommendation
-- REM
-- REM Segment Recommendation
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator
-- REM
-- REM NOTE: name - Recommendation ID / Other Info.
-- REM
CREATE TABLE sg_recommendation (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 loc_hr_delta        SMALLINT,
 loc_min_delta       SMALLINT,
 priority_type_code  INTEGER,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment(segment_site, segment_id),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (priority_type_code) REFERENCES priority_type(priority_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #185 -- as_recommendation
-- REM
-- REM Asset Recommendation
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator
-- REM
-- REM NOTE: name - Recommendation ID / Other Info.
-- REM
CREATE TABLE as_recommendation (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 loc_hr_delta        SMALLINT,
 loc_min_delta       SMALLINT,
 priority_type_code  INTEGER,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset(asset_org_site, asset_id),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (priority_type_code) REFERENCES priority_type(priority_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #316 ol_recommendation 
-- REM
-- REM Ordered List Recommendation
-- REM
-- REM NOTE: by_agent_site - Originator
-- REM
-- REM NOTE: name - Recommendation ID / Other Info.
-- REM
-- REM NOTE: by_agent_site  - Originator
-- REM
-- REM NOTE: name - Recommendation ID / Other Info.
-- REM
CREATE TABLE ol_recommendation (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL, 
 by_agent_id         INTEGER      NOT NULL, 
 loc_hr_delta        SMALLINT,
 loc_min_delta	     SMALLINT, 
 priority_type_code  INTEGER, 
 name                VARCHAR(254), 
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id) REFERENCES ordered_list(ord_list_db_site, ord_list_db_id, ord_list_id),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (priority_type_code) REFERENCES priority_type(priority_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

GO
-- REM #274 -- sg_type_recomm
-- REM
-- REM Segment Type Recommendation - Purpose is To Be Associated With Hypothesized Events
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator
-- REM
CREATE TABLE sg_type_recomm (
 sg_db_site          INTEGER      NOT NULL,
 sg_db_id            INTEGER      NOT NULL,
 sg_type_code        INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 loc_hr_delta        SMALLINT,
 loc_min_delta       SMALLINT,
 priority_type_code  INTEGER,
 name                VARCHAR(254), 
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sg_db_site, sg_db_id, sg_type_code, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (sg_db_site, sg_db_id, sg_type_code) REFERENCES segment_type(sg_db_site, sg_db_id, sg_type_code),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (priority_type_code) REFERENCES priority_type(priority_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #275 -- as_type_recomm
-- REM
-- REM Asset Type Recommendation - Purpose is To Be Associated With Hypothesized Events
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator
-- REM
CREATE TABLE as_type_recomm (
 as_db_site          INTEGER      NOT NULL,
 as_db_id            INTEGER      NOT NULL,
 as_type_code        INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 loc_hr_delta        SMALLINT,
 loc_min_delta       SMALLINT,
 priority_type_code  INTEGER,
 name                VARCHAR(254), 
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (as_db_site, as_db_id, as_type_code, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (as_db_site, as_db_id, as_type_code) REFERENCES asset_type(as_db_site, as_db_id, as_type_code),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (priority_type_code) REFERENCES priority_type(priority_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #276 -- model_recomm
-- REM
-- REM Model Recommendation - Purpose is To Be Associated With Hypothesized Events
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator
-- REM
CREATE TABLE model_recomm (
 mf_db_site          INTEGER
       NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 model_number        VARCHAR(254) NOT NULL,
 revision_number     INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 loc_hr_delta        SMALLINT,
 loc_min_delta       SMALLINT,
 priority_type_code  INTEGER,
 name                VARCHAR(254), 
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number) REFERENCES model(mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (priority_type_code) REFERENCES priority_type(priority_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #130 -- sg_rec_remark
-- REM
-- REM Segment Recommendation Remarks
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator
-- REM
CREATE TABLE sg_rec_remark (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 remark_text         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id, ordering_seq),
    FOREIGN KEY (segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES sg_recommendation(segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #131 -- as_rec_remark
-- REM
-- REM Asset Recommendation Remarks
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator
-- REM
CREATE TABLE as_rec_remark (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 remark_text         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id, ordering_seq),
    FOREIGN KEY (asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES as_recommendation(asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #322 -- ol_rec_remark
-- REM
-- REM Ordered List Recommendation Remarks
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator
-- REM
CREATE TABLE ol_rec_remark (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 remark_text         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id, gmt_recommendation, by_agent_site, by_agent_id, ordering_seq),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES ol_recommendation(ord_list_db_site, ord_list_db_id, ord_list_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #277 -- sg_type_rec_remark
-- REM
-- REM Segment Type Recommendation Remarks
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator
-- REM
CREATE TABLE sg_type_rec_remark (
 sg_db_site          INTEGER      NOT NULL,
 sg_db_id            INTEGER      NOT NULL,
 sg_type_code        INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 remark_text         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sg_db_site, sg_db_id, sg_type_code, gmt_recommendation, by_agent_site, by_agent_id, ordering_seq),
    FOREIGN KEY (sg_db_site, sg_db_id, sg_type_code, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES sg_type_recomm(sg_db_site, sg_db_id, sg_type_code, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #278 -- as_type_rec_remark
-- REM
-- REM Asset Type Recommendation Remarks
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator
-- REM
CREATE TABLE as_type_rec_remark (
 as_db_site          INTEGER      NOT NULL,
 as_db_id            INTEGER      NOT NULL,
 as_type_code        INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 remark_text         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (as_db_site, as_db_id, as_type_code, gmt_recommendation, by_agent_site, by_agent_id, ordering_seq),
    FOREIGN KEY (as_db_site, as_db_id, as_type_code, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES as_type_recomm(as_db_site, as_db_id, as_type_code, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #279 -- model_rec_remark
-- REM
-- REM Segment Type Recommendation Remarks
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator
-- REM
CREATE TABLE model_rec_remark (
 mf_db_site          INTEGER      NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 model_number        VARCHAR(254) NOT NULL,
 revision_number     INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 remark_text         VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, gmt_recommendation, by_agent_site, by_agent_id, ordering_seq),
    FOREIGN KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES model_recomm(mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #311 -- sg_rec_blob
-- REM
-- REM Binary Data Related to a Segment Recommendation
-- REM
CREATE TABLE sg_rec_blob (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 bd_db_site          INTEGER      NOT NULL,
 bd_db_id            INTEGER      NOT NULL,
 bd_type_code        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 name                VARCHAR(254),
 assoc_file_name     VARCHAR(254),
 image_data          IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id, bd_db_site, bd_db_id, bd_type_code, ordering_seq),
    FOREIGN KEY (segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES sg_recommendation(segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (bd_db_site, bd_db_id, bd_type_code) REFERENCES blob_data_type(bd_db_site, bd_db_id, bd_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #312 -- as_rec_blob
-- REM
-- REM Binary Data Related to an Asset Recommendation
-- REM
CREATE TABLE as_rec_blob (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 bd_db_site          INTEGER      NOT NULL,
 bd_db_id            INTEGER      NOT NULL,
 bd_type_code        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 name                VARCHAR(254),
 assoc_file_name     VARCHAR(254),
 image_data          IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id, bd_db_site, bd_db_id, bd_type_code, ordering_seq),
    FOREIGN KEY (asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES as_recommendation(asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (bd_db_site, bd_db_id, bd_type_code) REFERENCES blob_data_type(bd_db_site, bd_db_id, bd_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #313 -- sg_type_rec_blob
-- REM
-- REM Binary Data Related to a Segment Type Recommendation
-- REM
CREATE TABLE sg_type_rec_blob (
 sg_db_site          INTEGER      NOT NULL,
 sg_db_id            INTEGER      NOT NULL,
 sg_type_code        INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 bd_db_site          INTEGER      NOT NULL,
 bd_db_id            INTEGER      NOT NULL,
 bd_type_code        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 name                VARCHAR(254),
 assoc_file_name     VARCHAR(254),
 image_data          IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sg_db_site, sg_db_id, sg_type_code, gmt_recommendation, by_agent_site, by_agent_id, bd_db_site, bd_db_id, bd_type_code, ordering_seq),
    FOREIGN KEY (sg_db_site, sg_db_id, sg_type_code, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES sg_type_recomm(sg_db_site, sg_db_id, sg_type_code, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (bd_db_site, bd_db_id, bd_type_code) REFERENCES blob_data_type(bd_db_site, bd_db_id, bd_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #314 -- as_type_rec_blob
-- REM
-- REM Binary Data Related to an Asset Type Recommendation
-- REM
CREATE TABLE as_type_rec_blob (
 as_db_site          INTEGER      NOT NULL,
 as_db_id            INTEGER      NOT NULL,
 as_type_code        INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 bd_db_site          INTEGER      NOT NULL,
 bd_db_id            INTEGER      NOT NULL,
 bd_type_code        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 name                VARCHAR(254),
 assoc_file_name     VARCHAR(254),
 image_data          IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (as_db_site, as_db_id, as_type_code, gmt_recommendation, by_agent_site, by_agent_id, bd_db_site, bd_db_id, bd_type_code, ordering_seq),
    FOREIGN KEY (as_db_site, as_db_id, as_type_code, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES as_type_recomm(as_db_site, as_db_id, as_type_code, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (bd_db_site, bd_db_id, bd_type_code) REFERENCES blob_data_type(bd_db_site, bd_db_id, bd_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #315 -- model_rec_blob
-- REM
-- REM Binary Data Related to a Model Recommendation
-- REM
CREATE TABLE model_rec_blob (
 mf_db_site          INTEGER      NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 model_number        VARCHAR(254) NOT NULL,
 revision_number     INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 bd_db_site          INTEGER      NOT NULL,
 bd_db_id            INTEGER      NOT NULL,
 bd_type_code        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 name                VARCHAR(254),
 assoc_file_name     VARCHAR(254),
 image_data          IMAGE,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, gmt_recommendation, by_agent_site, by_agent_id, bd_db_site, bd_db_id, bd_type_code, ordering_seq),
    FOREIGN KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES model_recomm(mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (bd_db_site, bd_db_id, bd_type_code) REFERENCES blob_data_type(bd_db_site, bd_db_id, bd_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #302 -- sg_rec_sg_health
-- REM
-- REM Segment Health Assessment Linked to Segment Recommendations
-- REM
CREATE TABLE sg_rec_sg_health (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 hth_sg_site         INTEGER      NOT NULL,
 hth_sg_id           INTEGER      NOT NULL,
 hth_gmt_assess      VARCHAR(29)  NOT NULL,
 hth_by_agent_site   INTEGER      NOT NULL,
 hth_by_agent_id     INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id, hth_sg_site, hth_sg_id, hth_gmt_assess, hth_by_agent_site, hth_by_agent_id),
    FOREIGN KEY (segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES sg_recommendation(segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (hth_sg_site, hth_sg_id, hth_gmt_assess, hth_by_agent_site, hth_by_agent_id) REFERENCES segment_health(segment_site, segment_id, gmt_assessment, by_agent_site, by_agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #303 -- as_rec_as_health
-- REM
-- REM Asset Health Assessment Linked to Asset Recommendations
-- REM
CREATE TABLE as_rec_as_health (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 hth_as_org_site     INTEGER      NOT NULL,
 hth_asset_id        INTEGER      NOT NULL,
 hth_gmt_assess      VARCHAR(29)  NOT NULL,
 hth_by_agent_site   INTEGER      NOT NULL,
 hth_by_agent_id     INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id, hth_as_org_site, hth_asset_id, hth_gmt_assess, hth_by_agent_site, hth_by_agent_id),
    FOREIGN KEY (asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES as_recommendation(asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (hth_as_org_site, hth_asset_id, hth_gmt_assess, hth_by_agent_site, hth_by_agent_id) REFERENCES asset_health(asset_org_site, asset_id, gmt_assessment, by_agent_site, by_agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #208 -- sg_rec_sg_event
-- REM
-- REM Actual Segment Events Linked to Segment Recommendations
-- REM
CREATE TABLE sg_rec_sg_event (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 ev_sg_site          INTEGER      NOT NULL,
 ev_sg_id            INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     VARCHAR(29)  NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id, ev_sg_site, ev_sg_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES sg_recommendation(segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (ev_sg_site, ev_sg_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start) REFERENCES segment_event(segment_site, segment_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #209 -- as_rec_as_event
-- REM
-- REM Actual Asset Events Linked to Asset Recommendations
-- REM
CREATE TABLE as_rec_as_event (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 ev_as_org_site      INTEGER      NOT NULL,
 ev_as_id            INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     VARCHAR(29)  NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id, ev_as_org_site, ev_as_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES as_recommendation(asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (ev_as_org_site, ev_as_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start) REFERENCES asset_event(asset_org_site, asset_id, ev_db_site, ev_db_id, event_type_code, gmt_event_start),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #270 -- sg_rec_sg_hyp_ev
-- REM
-- REM Hypothetical Service Segment Events Linked to Segment Recommendations
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator
-- REM
CREATE TABLE sg_rec_sg_hyp_ev (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 sg_hyp_db_site      INTEGER      NOT NULL,
 sg_hyp_db_id        INTEGER      NOT NULL,
 sg_hyp_event_id     INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id, sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id),
    FOREIGN KEY (segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES sg_recommendation(segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id) REFERENCES sg_hyp_event(sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #271 -- as_rec_as_hyp_ev
-- REM
-- REM Hypothetical Asset Events Linked to Asset Recommendations
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator
-- REM
CREATE TABLE as_rec_as_hyp_ev (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 as_hyp_db_site      INTEGER      NOT NULL,
 as_hyp_db_id        INTEGER      NOT NULL,
 as_hyp_event_id     INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id, as_hyp_db_site, as_hyp_db_id, as_hyp_event_id),
    FOREIGN KEY (asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES as_recommendation(asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (as_hyp_db_site, as_hyp_db_id, as_hyp_event_id) REFERENCES as_hyp_event(as_hyp_db_site, as_hyp_db_id, as_hyp_event_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #280 -- sg_type_rec_hyp_ev
-- REM
-- REM Hypothetical Segment Events Linked to Segment Type Recommendations
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator
-- REM
CREATE TABLE sg_type_rec_hyp_ev (
 sg_db_site          INTEGER      NOT NULL,
 sg_db_id            INTEGER      NOT NULL,
 sg_type_code        INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 sg_hyp_db_site      INTEGER      NOT NULL,
 sg_hyp_db_id        INTEGER      NOT NULL,
 sg_hyp_event_id     INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sg_db_site, sg_db_id, sg_type_code, gmt_recommendation, by_agent_site, by_agent_id, sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id),
    FOREIGN KEY (sg_db_site, sg_db_id, sg_type_code, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES sg_type_recomm(sg_db_site, sg_db_id, sg_type_code, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id) REFERENCES sg_hyp_event(sg_hyp_db_site, sg_hyp_db_id, sg_hyp_event_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #281 -- as_type_rec_hyp_ev
-- REM
-- REM Hypothetical Asset Events Linked to Asset Type Recommendations
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator
-- REM
CREATE TABLE as_type_rec_hyp_ev (
 as_db_site          INTEGER      NOT NULL,
 as_db_id            INTEGER      NOT NULL,
 as_type_code        INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 as_hyp_db_site      INTEGER      NOT NULL,
 as_hyp_db_id        INTEGER      NOT NULL,
 as_hyp_event_id     INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (as_db_site, as_db_id, as_type_code, gmt_recommendation, by_agent_site, by_agent_id, as_hyp_db_site, as_hyp_db_id, as_hyp_event_id),
    FOREIGN KEY (as_db_site, as_db_id, as_type_code, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES as_type_recomm(as_db_site, as_db_id, as_type_code, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (as_hyp_db_site, as_hyp_db_id, as_hyp_event_id) REFERENCES as_hyp_event(as_hyp_db_site, as_hyp_db_id, as_hyp_event_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #282 -- model_rec_hyp_ev
-- REM
-- REM Hypothetical Model Events Linked to Model Recommendations
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator
-- REM
CREATE TABLE model_rec_hyp_ev (
 mf_db_site          INTEGER      NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 model_number        VARCHAR(254) NOT NULL,
 revision_number     INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 mod_hyp_db_site     INTEGER      NOT NULL,
 mod_hyp_db_id       INTEGER      NOT NULL,
 mod_hyp_event_id    INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, gmt_recommendation, by_agent_site, by_agent_id, mod_hyp_db_site, mod_hyp_db_id, mod_hyp_event_id),
    FOREIGN KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES model_recomm(mf_db_site, mf_db_id, mf_duns_code, model_number, revision_number, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (mod_hyp_db_site, mod_hyp_db_id, mod_hyp_event_id) REFERENCES model_hyp_event(mod_hyp_db_site, mod_hyp_db_id, mod_hyp_event_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #272 -- sg_rec_sg_prop_ev
-- REM
-- REM Proposed Service Segment Events Linked to Segment Recommendations
-- REM
CREATE TABLE sg_rec_sg_prop_ev (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 sg_prop_db_site     INTEGER      NOT NULL,
 sg_prop_db_id       INTEGER      NOT NULL,
 sg_prop_event_id    INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id, sg_prop_db_site, sg_prop_db_id, sg_prop_event_id),
    FOREIGN KEY (segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES sg_recommendation(segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (sg_prop_db_site, sg_prop_db_id, sg_prop_event_id) REFERENCES sg_proposed_event(sg_prop_db_site, sg_prop_db_id, sg_prop_event_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #273 -- as_rec_as_prop_ev
-- REM
-- REM Proposed Asset Events Linked to Asset Recommendations
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator
-- REM
CREATE TABLE as_rec_as_prop_ev (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 as_prop_db_site     INTEGER      NOT NULL,
 as_prop_db_id       INTEGER      NOT NULL,
 as_prop_event_id    INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id, as_prop_db_site, as_prop_db_id, as_prop_event_id),
    FOREIGN KEY (asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES as_recommendation(asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (as_prop_db_site, as_prop_db_id, as_prop_event_id) REFERENCES as_proposed_event(as_prop_db_site, as_prop_db_id, as_prop_event_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #304 -- sg_rec_mevent
-- REM
-- REM Measurement Events Linked to Segment Recommendations
-- REM
CREATE TABLE sg_rec_mevent (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id, meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES sg_recommendation(segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES meas_event(meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #305 -- as_rec_mevent
-- REM
-- REM Measurement Events Linked to  Asset Recommendations
-- REM
CREATE TABLE as_rec_mevent (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           VARCHAR(29)  NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id, meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES as_recommendation(asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES meas_event(meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

-- REM //////////////////////////
-- REM
-- REM Work Management Tables
-- REM
-- REM //////////////////////////
GO
-- REM #136 -- work_request
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator  
-- REM
-- REM NOTE: start_before_gmt - Request for action to begin before this time
-- REM
-- REM NOTE: end_before_gmt - Request for action to end before this time
-- REM
-- REM NOTE: start_after_gmt - Request for action to start after this time
-- REM
-- REM NOTE: end_after_gmt - Request for action to end after this time
-- REM
-- REM NOTE: repeat_interval - Time interval to automatically have work 
-- REM       re-submitted for time-based actions
-- REM
-- REM NOTE: int_eu_db_site, int_eu_db_id, int_eu_type_code - Time interval 
-- REM       eng unit reference (hours, days, months, etc.)
-- REM
-- REM NOTE: from_sy_agent_site, from_sy_agent_id - System the request 
-- REM       generated from
-- REM
-- REM NOTE: user_tag_ident - Work Request or Work Requested Number
-- REM
-- REM NOTE: abbrev - User generated short description
-- REM
-- REM NOTE: name - User generated full description
-- REM
CREATE TABLE work_request (
 work_req_db_site    INTEGER      NOT NULL,
 work_req_db_id      INTEGER      NOT NULL,
 work_req_id         INTEGER      NOT NULL,
 wm_type_db_site     INTEGER      NOT NULL,
 wm_type_db_id       INTEGER      NOT NULL,
 wm_type_code        INTEGER      NOT NULL,
 gmt_created         VARCHAR(29),
 loc_hr_delta        SMALLINT,
 loc_min_delta       SMALLINT,
 by_agent_site       INTEGER,
 by_agent_id         INTEGER,
 start_before_gmt    VARCHAR(29),
 end_before_gmt      VARCHAR(29),
 start_after_gmt     VARCHAR(29),
 end_after_gmt       VARCHAR(29),
 repeat_interval     INTEGER,
 int_eu_db_site      INTEGER,
 int_eu_db_id        INTEGER,
 int_eu_type_code    INTEGER,
 from_sy_agent_site  INTEGER,
 from_sy_agent_id    INTEGER,
 to_agent_site       INTEGER,
 to_agent_id         INTEGER,
 priority_type_code  INTEGER,
 user_tag_ident      VARCHAR(254) NOT NULL,
 abbrev              VARCHAR(254),
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_req_db_site, work_req_db_id, work_req_id),
    FOREIGN KEY (work_req_db_site, work_req_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (wm_type_db_site, wm_type_db_id, wm_type_code) REFERENCES work_manage_type(wm_type_db_site, wm_type_db_id, wm_type_code),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (int_eu_db_site, int_eu_db_id, int_eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (from_sy_agent_site, from_sy_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (to_agent_site, to_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (priority_type_code) REFERENCES priority_type(priority_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #181 -- solution_package
-- REM
-- REM Package of Pre-defined Work and Associated Information to Be Done Based On a Need
-- REM
-- REM NOTE: user_tag_ident - User alpha-numeric solution package number
-- REM 
CREATE TABLE solution_package (
 sol_pack_db_site    INTEGER      NOT NULL,
 sol_pack_db_id      INTEGER      NOT NULL,
 sol_pack_id         INTEGER      NOT NULL,
 sol_db_site         INTEGER      NOT NULL,
 sol_db_id           INTEGER      NOT NULL,
 sol_type_code       INTEGER      NOT NULL,
 gmt_created         VARCHAR(29),
 loc_hr_delta        SMALLINT,
 loc_min_delta       SMALLINT,
 priority_type_code  INTEGER,
 user_tag_ident      VARCHAR(254) NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (sol_pack_db_site, sol_pack_db_id, sol_pack_id),
    FOREIGN KEY (sol_pack_db_site, sol_pack_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (sol_db_site, sol_db_id, sol_type_code) REFERENCES solution_pack_type(sol_db_site, sol_db_id, sol_type_code),
    FOREIGN KEY (priority_type_code) REFERENCES priority_type(priority_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #134 -- sg_req_for_work
-- REM
-- REM Request for Work for Segment
-- REM
-- REM NOTE: start_before_gmt - Request for action to begin before this time
-- REM
-- REM NOTE: end_before_gmt - Request for action to end before this time
-- REM 
-- REM NOTE: start_after_gmt - Request for action to start after this time
-- REM
-- REM NOTE: end_after_gmt - Request for action to end after this time
-- REM
-- REM NOTE: from_sy_agent_site - System the request generated from
-- REM
-- REM NOTE: repeat_interval - Time interval to automatically have work re-submitted for time-based actions
-- REM
-- REM NOTE: int_eu_db_site, int_eu_db_id, int_eu_type_code - Time interval eng unit reference (hours, days, months, etc.)
-- REM
-- REM NOTE: to_agent_site, to_agent_id - Agent to recieve the request work
-- REM
-- REM NOTE: sol_pack_db_site, sol_pack_db_id, sol_pack_id - Associated solution package
-- REM 
-- REM NOTE: rec_segment_site, rec_segment_id, rec_gmt_recomm, rec_by_agent_site, ec_by_agent_id - Associated segment recommendation
-- REM
-- REM NOTE: work_req_db_site, work_req_db_id, work_req_id - Associated Work Request in local or remote database
-- REM
-- REM NOTE: abbrev - User-generated short work description
-- REM
-- REM NOTE: name - User-generated full work description 
-- REM
CREATE TABLE sg_req_for_work (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 gmt_requested       VARCHAR(29)  NOT NULL,
 req_by_agent_site   INTEGER      NOT NULL,
 req_by_agent_id     INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 req_loc_hr_delta    SMALLINT,
 req_loc_min_delta   SMALLINT,
 wm_type_db_site     INTEGER      NOT NULL,
 wm_type_db_id       INTEGER      NOT NULL,
 wm_type_code        INTEGER      NOT NULL,
 task_db_site        INTEGER      NOT NULL,
 task_db_id          INTEGER      NOT NULL,
 task_type_code      INTEGER      NOT NULL,
 start_before_gmt    VARCHAR(29),
 end_before_gmt      VARCHAR(29),
 start_after_gmt     VARCHAR(29),
 end_after_gmt       VARCHAR(29),
 repeat_interval     INTEGER,
 int_eu_db_site      INTEGER, 
 int_eu_db_id        INTEGER, 
 int_eu_type_code    INTEGER, 
 from_sy_agent_site  INTEGER,
 from_sy_agent_id    INTEGER,
 to_agent_site       INTEGER,
 to_agent_id         INTEGER,
 priority_type_code  INTEGER,
 sol_pack_db_site    INTEGER, 
 sol_pack_db_id      INTEGER, 
 sol_pack_id         INTEGER,
 rec_segment_site    INTEGER, 
 rec_segment_id      INTEGER, 
 rec_gmt_recomm      VARCHAR(29), 
 rec_by_agent_site   INTEGER, 
 rec_by_agent_id     INTEGER, 
 work_req_db_site    INTEGER, 
 work_req_db_id      INTEGER, 
 work_req_id         INTEGER, 
 abbrev              VARCHAR(254) NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, gmt_requested, req_by_agent_site, req_by_agent_id, ordering_seq),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment(segment_site, segment_id),
    FOREIGN KEY (req_by_agent_site, req_by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (wm_type_db_site, wm_type_db_id, wm_type_code) REFERENCES work_manage_type(wm_type_db_site, wm_type_db_id, wm_type_code), 
    FOREIGN KEY (task_db_site, task_db_id, task_type_code) REFERENCES work_task_type(task_db_site, task_db_id, task_type_code),
    FOREIGN KEY (int_eu_db_site, int_eu_db_id, int_eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (from_sy_agent_site, from_sy_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (to_agent_site, to_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (priority_type_code) REFERENCES priority_type(priority_type_code),
    FOREIGN KEY (sol_pack_db_site, sol_pack_db_id, sol_pack_id) REFERENCES solution_package(sol_pack_db_site, sol_pack_db_id, sol_pack_id),
    FOREIGN KEY (rec_segment_site, rec_segment_id, rec_gmt_recomm, rec_by_agent_site, rec_by_agent_id) REFERENCES sg_recommendation(segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (work_req_db_site, work_req_db_id, work_req_id) REFERENCES work_request(work_req_db_site, work_req_db_id, work_req_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #135 -- as_req_for_work
-- REM
-- REM Request for Work for Asset
-- REM
-- REM NOTE: start_before_gmt - Request for action to begin before this time
-- REM
-- REM NOTE: end_before_gmt - Request for action to end before this time
-- REM 
-- REM NOTE: start_after_gmt - Request for action to start after this time
-- REM
-- REM NOTE: end_after_gmt - Request for action to end after this time
-- REM
-- REM NOTE: from_sy_agent_site - System the request generated from
-- REM
-- REM NOTE: repeat_interval - Time interval to automatically have work re-submitted for time-based actions
-- REM
-- REM NOTE: int_eu_db_site, int_eu_db_id, int_eu_type_code - Time interval eng unit reference (hours, days, months, etc.)
-- REM
-- REM NOTE: to_agent_site, to_agent_id - Agent to recieve the request work
-- REM
-- REM NOTE: sol_pack_db_site, sol_pack_db_id, sol_pack_id - Associated solution package
-- REM 
-- REM NOTE: rec_asset_org_site, rec_asset_id, rec_gmt_recomm, rec_by_agent_site, ec_by_agent_id - Associated asset recommendation
-- REM
-- REM NOTE: work_req_db_site, work_req_db_id, work_req_id - Associated Work Request in local or remote database
-- REM
-- REM NOTE: abbrev - User-generated short work description
-- REM
-- REM NOTE: name - User-generated full work description 
-- REM
CREATE TABLE as_req_for_work (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 gmt_requested       VARCHAR(29)  NOT NULL,
 req_by_agent_site   INTEGER      NOT NULL,
 req_by_agent_id     INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 req_loc_hr_delta    SMALLINT,
 req_min_hr_delta    SMALLINT,
 wm_type_db_site     INTEGER      NOT NULL,
 wm_type_db_id       INTEGER      NOT NULL,
 wm_type_code        INTEGER      NOT NULL,
 task_db_site        INTEGER      NOT NULL,
 task_db_id          INTEGER      NOT NULL,
 task_type_code      INTEGER      NOT NULL,
 start_before_gmt    VARCHAR(29),
 end_before_gmt      VARCHAR(29),
 start_after_gmt     VARCHAR(29),
 end_after_gmt       VARCHAR(29),
 repeat_interval     INTEGER,
 int_eu_db_site      INTEGER, 
 int_eu_db_id        INTEGER, 
 int_eu_type_code    INTEGER, 
 from_sy_agent_site  INTEGER,
 from_sy_agent_id    INTEGER,
 to_agent_site       INTEGER,
 to_agent_id         INTEGER,
 priority_type_code  INTEGER,
 sol_pack_db_site    INTEGER, 
 sol_pack_db_id      INTEGER, 
 sol_pack_id         INTEGER,
 rec_asset_org_site  INTEGER, 
 rec_asset_id        INTEGER, 
 rec_gmt_recomm      VARCHAR(29), 
 rec_by_agent_site   INTEGER, 
 rec_by_agent_id     INTEGER, 
 work_req_db_site    INTEGER, 
 work_req_db_id      INTEGER, 
 work_req_id         INTEGER, 
 abbrev              VARCHAR(254) NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, gmt_requested, req_by_agent_site, req_by_agent_id, ordering_seq),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset(asset_org_site, asset_id),
    FOREIGN KEY (req_by_agent_site, req_by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (wm_type_db_site, wm_type_db_id, wm_type_code) REFERENCES work_manage_type(wm_type_db_site, wm_type_db_id, wm_type_code), 
    FOREIGN KEY (task_db_site, task_db_id, task_type_code) REFERENCES work_task_type(task_db_site, task_db_id, task_type_code),
    FOREIGN KEY (int_eu_db_site, int_eu_db_id, int_eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (from_sy_agent_site, from_sy_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (to_agent_site, to_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (priority_type_code) REFERENCES priority_type(priority_type_code),
    FOREIGN KEY (sol_pack_db_site, sol_pack_db_id, sol_pack_id) REFERENCES solution_package(sol_pack_db_site, sol_pack_db_id, sol_pack_id),
    FOREIGN KEY (rec_asset_org_site, rec_asset_id, rec_gmt_recomm, rec_by_agent_site, rec_by_agent_id) REFERENCES as_recommendation(asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (work_req_db_site, work_req_db_id, work_req_id) REFERENCES work_request(work_req_db_site, work_req_db_id, work_req_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #148 -- ol_req_for_work
-- REM
-- REM Request for Work for Ordered List,Route
-- REM
-- REM NOTE: start_before_gmt - Request for action to begin before this time
-- REM
-- REM NOTE: end_before_gmt - Request for action to end before this time
-- REM 
-- REM NOTE: start_after_gmt - Request for action to start after this time
-- REM
-- REM NOTE: end_after_gmt - Request for action to end after this time
-- REM
-- REM NOTE: from_sy_agent_site - System the request generated from
-- REM
-- REM NOTE: repeat_interval - Time interval to automatically have work re-submitted for time-based actions
-- REM
-- REM NOTE: int_eu_db_site, int_eu_db_id, int_eu_type_code - Time interval eng unit reference (hours, days, months, etc.)
-- REM
-- REM NOTE: to_agent_site, to_agent_id - Agent to recieve the request work
-- REM
-- REM NOTE: sol_pack_db_site, sol_pack_db_id, sol_pack_id - Associated solution package
-- REM 
-- REM NOTE: rec_ord_db_site, rec_ord_db_id, rec_ord_list_id, rec_gmt_recomm, rec_by_agent_site, rec_by_agent_id - Associated ordered list recommendation
-- REM
-- REM NOTE: work_req_db_site, work_req_db_id, work_req_id - Associated Work Request in local or remote database
-- REM
-- REM NOTE: abbrev - User-generated short work description
-- REM
-- REM NOTE: name - User-generated full work description 
-- REM
CREATE TABLE ol_req_for_work (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 gmt_requested       VARCHAR(29)  NOT NULL,
 req_by_agent_site   INTEGER      NOT NULL,
 req_by_agent_id     INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 req_loc_hr_delta    SMALLINT,
 req_min_hr_delta    SMALLINT,
 wm_type_db_site     INTEGER      NOT NULL,
 wm_type_db_id       INTEGER      NOT NULL,
 wm_type_code        INTEGER      NOT NULL,
 task_db_site        INTEGER      NOT NULL,
 task_db_id          INTEGER      NOT NULL,
 task_type_code      INTEGER      NOT NULL,
 start_before_gmt    VARCHAR(29),
 end_before_gmt      VARCHAR(29),
 start_after_gmt     VARCHAR(29),
 end_after_gmt       VARCHAR(29),
 repeat_interval     INTEGER,
 int_eu_db_site      INTEGER, 
 int_eu_db_id        INTEGER, 
 int_eu_type_code    INTEGER, 
 from_sy_agent_site  INTEGER,
 from_sy_agent_id    INTEGER,
 to_agent_site       INTEGER,
 to_agent_id         INTEGER,
 priority_type_code  INTEGER,
 sol_pack_db_site    INTEGER, 
 sol_pack_db_id      INTEGER, 
 sol_pack_id         INTEGER,
 rec_ord_db_site     INTEGER, 
 rec_ord_db_id       INTEGER, 
 rec_ord_list_id     INTEGER, 
 rec_gmt_recomm      VARCHAR(29), 
 rec_by_agent_site   INTEGER, 
 rec_by_agent_id     INTEGER, 
 work_req_db_site    INTEGER, 
 work_req_db_id      INTEGER, 
 work_req_id         INTEGER, 
 abbrev              VARCHAR(254) NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id, gmt_requested, req_by_agent_site, req_by_agent_id, ordering_seq),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id) REFERENCES ordered_list(ord_list_db_site, ord_list_db_id, ord_list_id),
    FOREIGN KEY (req_by_agent_site, req_by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (wm_type_db_site, wm_type_db_id, wm_type_code) REFERENCES work_manage_type(wm_type_db_site, wm_type_db_id, wm_type_code), 
    FOREIGN KEY (task_db_site, task_db_id, task_type_code) REFERENCES work_task_type(task_db_site, task_db_id, task_type_code),
    FOREIGN KEY (int_eu_db_site, int_eu_db_id, int_eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (from_sy_agent_site, from_sy_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (to_agent_site, to_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (priority_type_code) REFERENCES priority_type(priority_type_code),
    FOREIGN KEY (sol_pack_db_site, sol_pack_db_id, sol_pack_id) REFERENCES solution_package(sol_pack_db_site, sol_pack_db_id, sol_pack_id),
    FOREIGN KEY (rec_ord_db_site, rec_ord_db_id, rec_ord_list_id, rec_gmt_recomm, rec_by_agent_site, rec_by_agent_id) REFERENCES ol_recommendation(ord_list_db_site, ord_list_db_id, ord_list_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (work_req_db_site, work_req_db_id, work_req_id) REFERENCES work_request(work_req_db_site, work_req_db_id, work_req_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

GO
-- REM #186 -- work_req_sg_recomm
-- REM
-- REM Associated Segment Recommendations for a Work Request
-- REM
CREATE TABLE work_req_sg_recomm (
 work_req_db_site    INTEGER      NOT NULL,
 work_req_db_id      INTEGER      NOT NULL,
 work_req_id         INTEGER      NOT NULL,
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_req_db_site, work_req_db_id, work_req_id, segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (work_req_db_site, work_req_db_id, work_req_id) REFERENCES work_request(work_req_db_site, work_req_db_id, work_req_id),
    FOREIGN KEY (segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES sg_recommendation(segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #197 -- work_req_as_recomm
-- REM
-- REM Associated Asset Recommendations for a Work Request
-- REM
CREATE TABLE work_req_as_recomm (
 work_req_db_site    INTEGER      NOT NULL,
 work_req_db_id      INTEGER      NOT NULL,
 work_req_id         INTEGER      NOT NULL,
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_req_db_site, work_req_db_id, work_req_id, asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (work_req_db_site, work_req_db_id, work_req_id) REFERENCES work_request(work_req_db_site, work_req_db_id, work_req_id),
    FOREIGN KEY (asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES as_recommendation(asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #183 -- work_req_sol_pack
-- REM
-- REM Associated Solution Packages For a Work Request
-- REM
CREATE TABLE work_req_sol_pack (
 work_req_db_site    INTEGER      NOT NULL,
 work_req_db_id      INTEGER      NOT NULL,
 work_req_id         INTEGER      NOT NULL,
 sol_pack_db_site    INTEGER      NOT NULL,
 sol_pack_db_id      INTEGER      NOT NULL,
 sol_pack_id         INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_req_db_site, work_req_db_id, work_req_id, sol_pack_db_site, sol_pack_db_id, sol_pack_id),
    FOREIGN KEY (work_req_db_site, work_req_db_id, work_req_id) REFERENCES work_request(work_req_db_site, work_req_db_id, work_req_id),
    FOREIGN KEY (sol_pack_db_site, sol_pack_db_id, sol_pack_id) REFERENCES solution_package(sol_pack_db_site, sol_pack_db_id, sol_pack_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #172 -- work_request_num_data
-- REM
-- REM Work Request Numeric Data
-- REM
CREATE TABLE work_request_num_data (
 work_req_db_site    INTEGER      NOT NULL,
 work_req_db_id      INTEGER      NOT NULL,
 work_req_id         INTEGER      NOT NULL,
 wn_db_site          INTEGER      NOT NULL,
 wn_db_id            INTEGER      NOT NULL,
 wn_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          FLOAT        NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_req_db_site, work_req_db_id, work_req_id, wn_db_site, wn_db_id, wn_type_code),
    FOREIGN KEY (work_req_db_site, work_req_db_id, work_req_id) REFERENCES work_request(work_req_db_site, work_req_db_id, work_req_id),
    FOREIGN KEY (wn_db_site, wn_db_id, wn_type_code) REFERENCES work_num_data_type(wn_db_site, wn_db_id, wn_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #173 -- work_request_chr_data
-- REM
-- REM Work Request Character Data
-- REM
CREATE TABLE work_request_chr_data (
 work_req_db_site    INTEGER      NOT NULL,
 work_req_db_id      INTEGER      NOT NULL,
 work_req_id         INTEGER      NOT NULL,
 wc_db_site          INTEGER      NOT NULL,
 wc_db_id            INTEGER      NOT NULL,
 wc_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_req_db_site, work_req_db_id, work_req_id, wc_db_site, wc_db_id, wc_type_code),
    FOREIGN KEY (work_req_db_site, work_req_db_id, work_req_id) REFERENCES work_request(work_req_db_site, work_req_db_id, work_req_id),
    FOREIGN KEY (wc_db_site, wc_db_id, wc_type_code) REFERENCES work_chr_data_type(wc_db_site, wc_db_id, wc_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #174 -- work_request_audit
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Agent who posted audit record
-- REM
-- REM NOTE: from_sy_agent_site, from_sy_agent_id - System audit record generated from
-- REM
CREATE TABLE work_request_audit (
 work_req_db_site    INTEGER      NOT NULL,
 work_req_db_id      INTEGER      NOT NULL,
 work_req_id         INTEGER      NOT NULL,
 waudit_db_site      INTEGER      NOT NULL,
 waudit_db_id        INTEGER      NOT NULL,
 waudit_type_code    INTEGER      NOT NULL,
 gmt_audit_posted    VARCHAR(29)  NOT NULL,
 loc_hr_delta        SMALLINT,
 loc_min_delta       SMALLINT,
 by_agent_site       INTEGER,
 by_agent_id         INTEGER,
 from_sy_agent_site  INTEGER,
 from_sy_agent_id    INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_req_db_site, work_req_db_id, work_req_id, waudit_db_site, waudit_db_id, waudit_type_code, gmt_audit_posted),
    FOREIGN KEY (work_req_db_site, work_req_db_id, work_req_id) REFERENCES work_request(work_req_db_site, work_req_db_id, work_req_id),
    FOREIGN KEY (waudit_db_site, waudit_db_id, waudit_type_code) REFERENCES work_audit_type(waudit_db_site, waudit_db_id, waudit_type_code),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (from_sy_agent_site, from_sy_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #139 -- work_order
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator  
-- REM
-- REM NOTE: start_before_gmt - Request for action to begin before this time
-- REM 
-- REM NOTE: end_before_gmt - Request for action to end before this time
-- REM
-- REM NOTE: start_after_gmt - Request for action to start after this time
-- REM
-- REM NOTE: end_after_gmt - Request for action to end after this time
-- REM
-- REM NOTE: repeat_interval - Time interval to automatically have 
-- REM       work re-submitted for time-based actions
-- REM
-- REM NOTE: int_eu_db_site, int_eu_db_id, int_eu_type_code - Time interval 
-- REM       eng unit reference (hours, days, months, etc.)
-- REM
-- REM NOTE: from_sy_agent_site, from_sy_agent_id - System generated from
-- REM
-- REM NOTE: user_tag_ident - User alpha-numeric work order number
-- REM
-- REM NOTE: abbrev - User generated short description
-- REM
-- REM NOTE: name - User generated full description
-- REM
CREATE TABLE work_order (
 work_order_db_site  INTEGER      NOT NULL,
 work_order_db_id    INTEGER      NOT NULL,
 work_order_id       INTEGER      NOT NULL,
 wm_type_db_site     INTEGER,
 wm_type_db_id       INTEGER,
 wm_type_code        INTEGER,
 gmt_created         VARCHAR(29),
 loc_hr_delta        SMALLINT,
 loc_min_delta       SMALLINT,
 by_agent_site       INTEGER,
 by_agent_id         INTEGER,
 start_before_gmt    VARCHAR(29),
 end_before_gmt      VARCHAR(29),
 start_after_gmt     VARCHAR(29),
 end_after_gmt       VARCHAR(29),
 repeat_interval     INTEGER,
 int_eu_db_site      INTEGER,
 int_eu_db_id        INTEGER,
 int_eu_type_code    INTEGER,
 from_sy_agent_site  INTEGER,
 from_sy_agent_id    INTEGER,
 to_agent_site       INTEGER,
 to_agent_id         INTEGER,
 priority_type_code  INTEGER,
 user_tag_ident      VARCHAR(254) NOT NULL,
 abbrev              VARCHAR(254),
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_order_db_site, work_order_db_id, work_order_id),
    FOREIGN KEY (work_order_db_site, work_order_db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (wm_type_db_site, wm_type_db_id, wm_type_code) REFERENCES work_manage_type(wm_type_db_site, wm_type_db_id, wm_type_code),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (int_eu_db_site, int_eu_db_id, int_eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (from_sy_agent_site, from_sy_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (to_agent_site, to_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (priority_type_code) REFERENCES priority_type(priority_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #159 -- work_order_child
-- REM
-- REM Relationship of Master Parent Work Order to Follow-on Work Orders
-- REM
CREATE TABLE work_order_child (
 work_order_db_site  INTEGER      NOT NULL,
 work_order_db_id    INTEGER      NOT NULL,
 work_order_id       INTEGER      NOT NULL,
 child_wo_db_site    INTEGER      NOT NULL,
 child_wo_db_id      INTEGER      NOT NULL,
 child_wo_id         INTEGER      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_order_db_site, work_order_db_id, work_order_id, child_wo_db_site, child_wo_db_id, child_wo_id),
    FOREIGN KEY (work_order_db_site, work_order_db_id, work_order_id) REFERENCES work_order(work_order_db_site, work_order_db_id, work_order_id),
    FOREIGN KEY (child_wo_db_site, child_wo_db_id, child_wo_id) REFERENCES work_order(work_order_db_site, work_order_db_id, work_order_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #175 -- work_order_num_data
-- REM
-- REM 
-- REM
CREATE TABLE work_order_num_data (
 work_order_db_site  INTEGER      NOT NULL,
 work_order_db_id    INTEGER      NOT NULL,
 work_order_id       INTEGER      NOT NULL,
 wn_db_site          INTEGER      NOT NULL,
 wn_db_id            INTEGER      NOT NULL,
 wn_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          FLOAT        NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_order_db_site, work_order_db_id, work_order_id, wn_db_site, wn_db_id, wn_type_code),
    FOREIGN KEY (work_order_db_site, work_order_db_id, work_order_id) REFERENCES work_order(work_order_db_site, work_order_db_id, work_order_id),
    FOREIGN KEY (wn_db_site, wn_db_id, wn_type_code) REFERENCES work_num_data_type(wn_db_site, wn_db_id, wn_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #176 -- work_order_chr_data
-- REM
-- REM 
-- REM
CREATE TABLE work_order_chr_data (
 work_order_db_site  INTEGER      NOT NULL,
 work_order_db_id    INTEGER      NOT NULL,
 work_order_id       INTEGER      NOT NULL,
 wc_db_site          INTEGER      NOT NULL,
 wc_db_id            INTEGER      NOT NULL,
 wc_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_order_db_site, work_order_db_id, work_order_id, wc_db_site, wc_db_id, wc_type_code),
    FOREIGN KEY (work_order_db_site, work_order_db_id, work_order_id) REFERENCES work_order(work_order_db_site, work_order_db_id, work_order_id),
    FOREIGN KEY (wc_db_site, wc_db_id, wc_type_code) REFERENCES work_chr_data_type(wc_db_site, wc_db_id, wc_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #177 -- work_order_audit
-- REM
-- REM 
-- REM
CREATE TABLE work_order_audit (
 work_order_db_site  INTEGER      NOT NULL,
 work_order_db_id    INTEGER      NOT NULL,
 work_order_id       INTEGER      NOT NULL,
 waudit_db_site      INTEGER      NOT NULL,
 waudit_db_id        INTEGER      NOT NULL,
 waudit_type_code    INTEGER      NOT NULL,
 gmt_audit_posted    VARCHAR(29)  NOT NULL,
 loc_hr_delta        SMALLINT,
 loc_min_delta       SMALLINT,
 by_agent_site       INTEGER,
 by_agent_id         INTEGER,
 from_sy_agent_site  INTEGER,
 from_sy_agent_id    INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_order_db_site, work_order_db_id, work_order_id, waudit_db_site, waudit_db_id, waudit_type_code, gmt_audit_posted),
    FOREIGN KEY (work_order_db_site, work_order_db_id, work_order_id) REFERENCES work_order(work_order_db_site, work_order_db_id, work_order_id),
    FOREIGN KEY (waudit_db_site, waudit_db_id, waudit_type_code) REFERENCES work_audit_type(waudit_db_site, waudit_db_id, waudit_type_code),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (from_sy_agent_site, from_sy_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #140 -- work_order_step
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Originator  
-- REM
-- REM NOTE: start_before_gmt - Request for action to begin before this time
-- REM
-- REM NOTE: end_before_gmt - Request for action to end before this time
-- REM
-- REM NOTE: start_after_gmt - Request for action to start after this time
-- REM
-- REM NOTE: end_after_gmt - Request for action to end after this time
-- REM
-- REM NOTE: from_sy_agent_site, from_sy_agent_id - System generated from
-- REM
-- REM NOTE: priority_type_code - 0 = lowest, 10 = highest
-- REM
-- REM NOTE: abbrev - User generated short description
-- REM
-- REM NOTE: name - User generated full description
-- REM
CREATE TABLE work_order_step (
 work_order_db_site  INTEGER      NOT NULL,
 work_order_db_id    INTEGER      NOT NULL,
 work_order_id       INTEGER      NOT NULL,
 work_ord_step_seq   INTEGER      NOT NULL,
 gmt_created         VARCHAR(29),
 loc_hr_delta        SMALLINT,
 loc_min_delta       SMALLINT,
 by_agent_site       INTEGER,
 by_agent_id         INTEGER,
 sol_pack_db_site    INTEGER,
 sol_pack_db_id      INTEGER,
 sol_pack_id         INTEGER,
 start_before_gmt    VARCHAR(29),
 end_before_gmt      VARCHAR(29),
 start_after_gmt     VARCHAR(29),
 end_after_gmt       VARCHAR(29),
 from_sy_agent_site  INTEGER,
 from_sy_agent_id    INTEGER,
 to_agent_site       INTEGER,
 to_agent_id         INTEGER,
 priority_type_code  INTEGER,
 user_tag_ident      VARCHAR(254) NOT NULL,
 abbrev              VARCHAR(254),
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq),
    FOREIGN KEY (work_order_db_site, work_order_db_id, work_order_id) REFERENCES work_order(work_order_db_site, work_order_db_id, work_order_id),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (sol_pack_db_site, sol_pack_db_id, sol_pack_id) REFERENCES solution_package(sol_pack_db_site, sol_pack_db_id, sol_pack_id),
    FOREIGN KEY (from_sy_agent_site, from_sy_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (to_agent_site, to_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (priority_type_code) REFERENCES priority_type(priority_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #178 -- wo_step_num_data
-- REM
-- REM null
-- REM
CREATE TABLE wo_step_num_data (
 work_order_db_site  INTEGER      NOT NULL,
 work_order_db_id    INTEGER      NOT NULL,
 work_order_id       INTEGER      NOT NULL,
 work_ord_step_seq   INTEGER      NOT NULL,
 wn_db_site          INTEGER      NOT NULL,
 wn_db_id            INTEGER      NOT NULL,
 wn_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          FLOAT        NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq, wn_db_site, wn_db_id, wn_type_code),
    FOREIGN KEY (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq) REFERENCES work_order_step(work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq),
    FOREIGN KEY (wn_db_site, wn_db_id, wn_type_code) REFERENCES work_num_data_type(wn_db_site, wn_db_id, wn_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #179 -- wo_step_chr_data
-- REM
-- REM null
-- REM
CREATE TABLE wo_step_chr_data (
 work_order_db_site  INTEGER      NOT NULL,
 work_order_db_id    INTEGER      NOT NULL,
 work_order_id       INTEGER      NOT NULL,
 work_ord_step_seq   INTEGER      NOT NULL,
 wc_db_site          INTEGER      NOT NULL,
 wc_db_id            INTEGER      NOT NULL,
 wc_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq, wc_db_site, wc_db_id, wc_type_code),
    FOREIGN KEY (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq) REFERENCES work_order_step(work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq),
    FOREIGN KEY (wc_db_site, wc_db_id, wc_type_code) REFERENCES work_chr_data_type(wc_db_site, wc_db_id, wc_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES eng_unit_type(eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #180 -- wo_step_audit
-- REM
-- REM NOTE: by_agent_site, by_agent_id - Agent who posted audit record
-- REM
-- REM NOTE: from_sy_agent_site, from_sy_agent_id - System audit record 
-- REM       generated from
-- REM
CREATE TABLE wo_step_audit (
 work_order_db_site  INTEGER      NOT NULL,
 work_order_db_id    INTEGER      NOT NULL,
 work_order_id       INTEGER      NOT NULL,
 work_ord_step_seq   INTEGER      NOT NULL,
 waudit_db_site      INTEGER      NOT NULL,
 waudit_db_id        INTEGER      NOT NULL,
 waudit_type_code    INTEGER      NOT NULL,
 gmt_audit_posted    VARCHAR(29)  NOT NULL,
 loc_hr_delta        SMALLINT,
 loc_min_delta       SMALLINT,
 by_agent_site       INTEGER,
 by_agent_id         INTEGER,
 from_sy_agent_site  INTEGER,
 from_sy_agent_id    INTEGER,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq, waudit_db_site, waudit_db_id, waudit_type_code, gmt_audit_posted),
    FOREIGN KEY (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq) REFERENCES work_order_step(work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq),
    FOREIGN KEY (waudit_db_site, waudit_db_id, waudit_type_code) REFERENCES work_audit_type(waudit_db_site, waudit_db_id, waudit_type_code),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (from_sy_agent_site, from_sy_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #201 -- wo_step_sg_recomm
-- REM
-- REM Associated Segment Recommendations for a Work Order Step
-- REM
CREATE TABLE wo_step_sg_recomm (
 work_order_db_site  INTEGER      NOT NULL,
 work_order_db_id    INTEGER      NOT NULL,
 work_order_id       INTEGER      NOT NULL,
 work_ord_step_seq   INTEGER      NOT NULL,
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq, segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq) REFERENCES work_order_step(work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq),
    FOREIGN KEY (segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES sg_recommendation(segment_site, segment_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #202 -- wo_step_as_recomm
-- REM
-- REM Associated Asset Recommendations for a Work Order Step
-- REM
CREATE TABLE wo_step_as_recomm (
 work_order_db_site  INTEGER      NOT NULL,
 work_order_db_id    INTEGER      NOT NULL,
 work_order_id       INTEGER      NOT NULL,
 work_ord_step_seq   INTEGER      NOT NULL,
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 gmt_recommendation  VARCHAR(29)  NOT NULL,
 by_agent_site       INTEGER      NOT NULL,
 by_agent_id         INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq, asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq) REFERENCES work_order_step(work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq),
    FOREIGN KEY (asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id) REFERENCES as_recommendation(asset_org_site, asset_id, gmt_recommendation, by_agent_site, by_agent_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
GO
-- REM #141 -- wo_step_work_req
-- REM
-- REM Work Requests Related to Work Order Steps
-- REM
CREATE TABLE wo_step_work_req (
 work_order_db_site  INTEGER      NOT NULL,
 work_order_db_id    INTEGER      NOT NULL,
 work_order_id       INTEGER      NOT NULL,
 work_ord_step_seq   INTEGER      NOT NULL,
 work_req_db_site    INTEGER      NOT NULL,
 work_req_db_id      INTEGER      NOT NULL,
 work_req_id         INTEGER      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq, work_req_db_site, work_req_db_id, work_req_id),
    FOREIGN KEY (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq) REFERENCES work_order_step(work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq),
    FOREIGN KEY (work_req_db_site, work_req_db_id, work_req_id) REFERENCES work_request(work_req_db_site, work_req_db_id, work_req_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #144 -- sg_completed_work
-- REM
-- REM Completed Work Tasks For Segments
-- REM
-- REM NOTE: gmt_completed - Actual completion time
-- REM
-- REM NOTE: cp_loc_hr_delta - Local completion time hours from GMT
-- REM
-- REM NOTE: cp_loc_min_delta - Local completion time minutes from GMT
-- REM
-- REM NOTE: gmt_started - Actual start time
-- REM
-- REM NOTE: st_loc_hr_delta - Local start time hours from GMT
-- REM
-- REM NOTE: st_loc_min_delta - Local start time minutes from GMT
-- REM
-- REM NOTE: by_agent_site, by_agent_id  - Agent accomplishing the work
-- REM
-- REM NOTE: from_sy_agent_site, from_sy_agent_id - System generated from
-- REM
-- REM NOTE: priority_type_code - 0 = lowest, 10 = highest
-- REM
-- REM NOTE: abbrev - User generated short work description
-- REM
-- REM NOTE: name - User generated full work description
-- REM 
-- REM NOTE: work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq - Associated Work Order Step
-- REM
CREATE TABLE sg_completed_work (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 task_db_site        INTEGER      NOT NULL,
 task_db_id          INTEGER      NOT NULL,
 task_type_code      INTEGER      NOT NULL,
 gmt_completed       VARCHAR(29)  NOT NULL,
 cp_loc_hr_delta     SMALLINT,
 cp_loc_min_delta    SMALLINT,
 gmt_started         VARCHAR(29),
 st_loc_hr_delta     SMALLINT,
 st_loc_min_delta    SMALLINT,
 by_agent_site       INTEGER,
 by_agent_id         INTEGER,
 from_sy_agent_site  INTEGER,
 from_sy_agent_id    INTEGER,
 priority_type_code  INTEGER,
 work_order_db_site  INTEGER,
 work_order_db_id    INTEGER, 
 work_order_id       INTEGER, 
 work_ord_step_seq   INTEGER,
 abbrev              VARCHAR(254) NOT NULL ,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, task_db_site, task_db_id, task_type_code, gmt_completed),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment(segment_site, segment_id),
    FOREIGN KEY (task_db_site, task_db_id, task_type_code) REFERENCES work_task_type(task_db_site, task_db_id, task_type_code),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (from_sy_agent_site, from_sy_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (priority_type_code) REFERENCES priority_type (priority_type_code),
    FOREIGN KEY (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq) REFERENCES work_order_step (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #145 -- as_completed_work
-- REM
-- REM Completed Work Tasks for Assets
-- REM
-- REM NOTE: gmt_completed - Actual completion time
-- REM
-- REM NOTE: cp_loc_hr_delta - Local completion time hours from GMT
-- REM
-- REM NOTE: cp_loc_min_delta - Local completion time minutes from GMT
-- REM
-- REM NOTE: gmt_started - Actual start time
-- REM
-- REM NOTE: st_loc_hr_delta - Local start time hours from GMT
-- REM
-- REM NOTE: st_loc_min_delta - Local start time minutes from GMT
-- REM
-- REM NOTE: by_agent_site, by_agent_id  - Agent accomplishing the work
-- REM
-- REM NOTE: from_sy_agent_site, from_sy_agent_id - System generated from
-- REM
-- REM NOTE: priority_type_code - 0 = lowest, 10 = highest
-- REM
-- REM NOTE: abbrev - User generated short work description
-- REM
-- REM NOTE: name - User generated full work description
-- REM 
-- REM NOTE: work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq - Associated Work Order Step
-- REM
CREATE TABLE as_completed_work (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 task_db_site        INTEGER      NOT NULL,
 task_db_id          INTEGER      NOT NULL,
 task_type_code      INTEGER      NOT NULL,
 gmt_completed       VARCHAR(29)  NOT NULL,
 cp_loc_hr_delta     SMALLINT,
 cp_loc_min_delta    SMALLINT,
 gmt_started         VARCHAR(29),
 st_loc_hr_delta     SMALLINT,
 st_loc_min_delta    SMALLINT,
 by_agent_site       INTEGER,
 by_agent_id         INTEGER,
 from_sy_agent_site  INTEGER,
 from_sy_agent_id    INTEGER,
 priority_type_code  INTEGER,
 work_order_db_site  INTEGER,
 work_order_db_id    INTEGER, 
 work_order_id       INTEGER, 
 work_ord_step_seq   INTEGER,
 abbrev              VARCHAR(254) NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, task_db_site, task_db_id, task_type_code, gmt_completed),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset(asset_org_site, asset_id),
    FOREIGN KEY (task_db_site, task_db_id, task_type_code) REFERENCES work_task_type(task_db_site, task_db_id, task_type_code),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (from_sy_agent_site, from_sy_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (priority_type_code) REFERENCES priority_type (priority_type_code),
    FOREIGN KEY (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq) REFERENCES work_order_step (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #187 -- ol_completed_work
-- REM
-- REM Completed Work Tasks For Ordered Lists
-- REM
-- REM NOTE: gmt_completed - Actual completion time
-- REM
-- REM NOTE: cp_loc_hr_delta - Local completion time hours from GMT
-- REM
-- REM NOTE: cp_loc_min_delta - Local completion time minutes from GMT
-- REM
-- REM NOTE: gmt_started - Actual start time
-- REM
-- REM NOTE: st_loc_hr_delta - Local start time hours from GMT
-- REM
-- REM NOTE: st_loc_min_delta - Local start time minutes from GMT
-- REM
-- REM NOTE: by_agent_site, by_agent_id  - Agent accomplishing the work
-- REM
-- REM NOTE: from_sy_agent_site, from_sy_agent_id - System generated from
-- REM
-- REM NOTE: priority_type_code - 0 = lowest, 10 = highest
-- REM
-- REM NOTE: abbrev - User generated short work description
-- REM
-- REM NOTE: name - User generated full work description
-- REM 
-- REM NOTE: work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq - Associated Work Order Step
-- REM
CREATE TABLE ol_completed_work (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 task_db_site        INTEGER      NOT NULL,
 task_db_id          INTEGER      NOT NULL,
 task_type_code      INTEGER      NOT NULL,
 gmt_completed       VARCHAR(29)  NOT NULL,
 cp_loc_hr_delta     SMALLINT,
 cp_loc_min_delta    SMALLINT,
 gmt_started         VARCHAR(29),
 st_loc_hr_delta     SMALLINT,
 st_loc_min_delta    SMALLINT,
 by_agent_site       INTEGER,
 by_agent_id         INTEGER,
 from_sy_agent_site  INTEGER,
 from_sy_agent_id    INTEGER,
 priority_type_code  INTEGER,
 work_order_db_site  INTEGER,
 work_order_db_id    INTEGER, 
 work_order_id       INTEGER, 
 work_ord_step_seq   INTEGER,
 abbrev              VARCHAR(254) NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id, task_db_site, task_db_id, task_type_code, gmt_completed),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id) REFERENCES ordered_list(ord_list_db_site, ord_list_db_id, ord_list_id),
    FOREIGN KEY (task_db_site, task_db_id, task_type_code) REFERENCES work_task_type(task_db_site, task_db_id, task_type_code),
    FOREIGN KEY (by_agent_site, by_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (from_sy_agent_site, from_sy_agent_id) REFERENCES agent(org_agent_site, agent_id),
    FOREIGN KEY (priority_type_code) REFERENCES priority_type (priority_type_code),
    FOREIGN KEY (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq) REFERENCES work_order_step (work_order_db_site, work_order_db_id, work_order_id, work_ord_step_seq),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #328 -- db_mim_Interface
-- REM
-- REM MIMOSA Interfaces Supported By A Database
-- REM
-- REM NOTE: gmt_last_refresh: Timestamp of last refresh date, if applicable
CREATE TABLE db_mim_interface (
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 interf_type_code    INTEGER      NOT NULL,
 gmt_snap_refresh    VARCHAR(29),
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (db_site, db_id, interf_type_code),
    FOREIGN KEY (db_site, db_id) REFERENCES site_database(db_site, db_id),
    FOREIGN KEY (interf_type_code) REFERENCES mim_interface_type(interf_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #329 -- Measurement Location Type Child Table
-- REM
-- REM The mloc_type_child table shows the parent-child relationships of 
-- REM measurement location types to each other.  For example, measurement 
-- REM location type "Speed, Shaft, Input Shaft" is the child of measurement 
-- REM location type "Speed, Shaft" which is the child of measurement location 
-- REM type "Speed".  The model allows for more than one measurement location 
-- REM type to be the child of more than one measurment location type.
-- REM 
-- REM The mandatory ordering sequence specifies the order in which child 
-- REM measurement location types appear when as application requests "all 
-- REM children" of a particular measurment location type.
-- REM
CREATE TABLE mloc_type_child (
 ml_db_site          INTEGER      NOT NULL,
 ml_db_id            INTEGER      NOT NULL,
 ml_type_code        INTEGER      NOT NULL,
 child_ml_db_site    INTEGER      NOT NULL,
 child_ml_db_id      INTEGER      NOT NULL,
 child_ml_type_code  INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ml_db_site, ml_db_id, ml_type_code, child_ml_db_site, child_ml_db_id, child_ml_type_code),
    FOREIGN KEY (ml_db_site, ml_db_id, ml_type_code) REFERENCES meas_loc_type (ml_db_site, ml_db_id, ml_type_code),
    FOREIGN KEY (child_ml_db_site, child_ml_db_id, child_ml_type_code) REFERENCES meas_loc_type (ml_db_site, ml_db_id, ml_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #330 -- as_sol_pack
-- REM
-- REM Associated Solution Packages For an Asset
-- REM
CREATE TABLE as_sol_pack (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 sol_pack_db_site    INTEGER      NOT NULL,
 sol_pack_db_id      INTEGER      NOT NULL,
 sol_pack_id         INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (asset_org_site, asset_id, sol_pack_db_site, sol_pack_db_id, sol_pack_id),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset (asset_org_site, asset_id),
    FOREIGN KEY (sol_pack_db_site, sol_pack_db_id, sol_pack_id) REFERENCES solution_package(sol_pack_db_site, sol_pack_db_id, sol_pack_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #331 -- sg_sol_pack
-- REM
-- REM Associated Solution Packages For a Segment
-- REM
CREATE TABLE sg_sol_pack (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 sol_pack_db_site    INTEGER      NOT NULL,
 sol_pack_db_id      INTEGER      NOT NULL,
 sol_pack_id         INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (segment_site, segment_id, sol_pack_db_site, sol_pack_db_id, sol_pack_id),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment (segment_site, segment_id),
    FOREIGN KEY (sol_pack_db_site, sol_pack_db_id, sol_pack_id) REFERENCES solution_package(sol_pack_db_site, sol_pack_db_id, sol_pack_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #332 -- ol_sol_pack
-- REM
-- REM Associated Solution Packages For an Ordered List
-- REM
CREATE TABLE ol_sol_pack (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 sol_pack_db_site    INTEGER      NOT NULL,
 sol_pack_db_id      INTEGER      NOT NULL,
 sol_pack_id         INTEGER      NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, sol_pack_db_site, sol_pack_db_id, sol_pack_id),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id) REFERENCES ordered_list (ord_list_db_site, ord_list_db_id, ord_list_id),
    FOREIGN KEY (sol_pack_db_site, sol_pack_db_id, sol_pack_id) REFERENCES solution_package(sol_pack_db_site, sol_pack_db_id, sol_pack_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
-- REM #334 -- Measurement Location Association Table
-- REM
-- REM This table contains measurement locations which are related to one
-- REM another.  Xxamples of its use is to associate a vibration measurement
-- REM location to its corresponding tachometer signal measurement location
-- REM and for multi-channel locations which are related to each other
-- REM
-- REM
CREATE TABLE meas_loc_assoc (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 related_mloc_site   INTEGER      NOT NULL,
 related_mloc_id     INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    VARCHAR(29),
 last_upd_db_site    INTEGER,
 last_upd_db_id      INTEGER,
 rstat_type_code     SMALLINT,
    PRIMARY KEY (meas_loc_site, meas_loc_id, related_mloc_site, related_mloc_id),
    FOREIGN KEY (meas_loc_site, meas_loc_id) REFERENCES meas_location (meas_loc_site, meas_loc_id),
    FOREIGN KEY (related_mloc_site, related_mloc_id) REFERENCES meas_location (meas_loc_site, meas_loc_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
GO
